AcceptCall class

Inheritance

Constructors

AcceptCall({required int callId, required CallProtocol protocol})
Accepts an incoming call
const

Properties

callId → int
callId Call identifier
final
hashCode → int
The hash code for this object.
no setterinherited
protocol → CallProtocol
protocol The call protocols supported by the application
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? callId, CallProtocol? protocol}) → AcceptCall
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String