AcceptTermsOfService class

Inheritance

Constructors

AcceptTermsOfService({required String termsOfServiceId})
Accepts Telegram terms of services
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
termsOfServiceId → String
termsOfServiceId Terms of service identifier
final

Methods

copyWith({String? termsOfServiceId}) → AcceptTermsOfService
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String