AddApplicationChangelog class

Inheritance

Constructors

AddApplicationChangelog({required String previousApplicationVersion})
Adds server-provided application changelog as messages to the chat 777000 (Telegram) or as a stories; for official applications only. Returns a 404 error if nothing changed
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
previousApplicationVersion → String
previousApplicationVersion The previous application version
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? previousApplicationVersion}) → AddApplicationChangelog
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String