AddChatFolderByInviteLink class

Inheritance

Constructors

AddChatFolderByInviteLink({required String inviteLink, required List<int> chatIds})
Adds a chat folder by an invite link
const

Properties

chatIds → List<int>
chatIds Identifiers of the chats added to the chat folder. The chats are automatically joined if they aren't joined yet
final
hashCode → int
The hash code for this object.
no setterinherited
inviteLink Invite link for the chat folder
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? inviteLink, List<int>? chatIds}) → AddChatFolderByInviteLink
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String