AddChatMember class

Inheritance

Constructors

AddChatMember({required int chatId, required int userId, required int forwardLimit})
Adds a new member to a chat. Members can't be added to private or secret chats
const

Properties

chatId → int
chatId Chat identifier
final
forwardLimit → int
forwardLimit The number of earlier messages from the chat to be forwarded to the new member; up to 100. Ignored for supergroups and channels, or if the added user is a bot
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userId → int
userId Identifier of the user
final

Methods

copyWith({int? chatId, int? userId, int? forwardLimit}) → AddChatMember
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String