AddLocalMessage class

Inheritance

Constructors

AddLocalMessage({required int chatId, required MessageSender senderId, MessageReplyTo? replyTo, required bool disableNotification, required InputMessageContent inputMessageContent})
Adds a local message to a chat. The message is persistent across application restarts only if the message database is used. Returns the added message
const

Properties

chatId → int
chatId Target chat
final
disableNotification → bool
disableNotification Pass true to disable notification for the message
final
hashCode → int
The hash code for this object.
no setterinherited
inputMessageContent → InputMessageContent
inputMessageContent The content of the message to be added
final
replyTo → MessageReplyTo?
replyTo Identifier of the replied message or story; pass null if none
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
senderId → MessageSender
senderId Identifier of the sender of the message
final

Methods

copyWith({int? chatId, MessageSender? senderId, MessageReplyTo? replyTo, bool? disableNotification, InputMessageContent? inputMessageContent}) → AddLocalMessage
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String