AddMessageReaction class

Inheritance

Constructors

AddMessageReaction({required int chatId, required int messageId, required ReactionType reactionType, required bool isBig, required bool updateRecentReactions})
Adds a reaction to a message. Use getMessageAvailableReactions to receive the list of available reactions for the message
const

Properties

chatId → int
chatId Identifier of the chat to which the message belongs
final
hashCode → int
The hash code for this object.
no setterinherited
isBig → bool
isBig Pass true if the reaction is added with a big animation
final
messageId → int
messageId Identifier of the message
final
reactionType → ReactionType
reactionType Type of the reaction to add
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updateRecentReactions → bool
updateRecentReactions Pass true if the reaction needs to be added to recent reactions
final

Methods

copyWith({int? chatId, int? messageId, ReactionType? reactionType, bool? isBig, bool? updateRecentReactions}) → AddMessageReaction
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String