AddNetworkStatistics class

Inheritance

Constructors

AddNetworkStatistics({required NetworkStatisticsEntry entry})
Adds the specified data to data usage statistics. Can be called before authorization
const

Properties

entry → NetworkStatisticsEntry
entry The network statistics entry with the data to be added to statistics
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({NetworkStatisticsEntry? entry}) → AddNetworkStatistics
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String