AddProxy class

Inheritance

Constructors

AddProxy({required String server, required int port, required bool enable, required ProxyType type})
Adds a proxy server for network requests. Can be called before authorization
const

Properties

enable → bool
enable Pass true to immediately enable the proxy
final
hashCode → int
The hash code for this object.
no setterinherited
port → int
port Proxy server port
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
server → String
server Proxy server IP address
final
type → ProxyType
type Proxy type
final

Methods

copyWith({String? server, int? port, bool? enable, ProxyType? type}) → AddProxy
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String