AddStickerToSet class

Inheritance

Constructors

AddStickerToSet({required int userId, required String name, required InputSticker sticker})
Adds a new sticker to a set; for bots only
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
name Sticker set name
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sticker → InputSticker
sticker Sticker to add to the set
final
userId → int
userId Sticker set owner
final

Methods

copyWith({int? userId, String? name, InputSticker? sticker}) → AddStickerToSet
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String