AddedReaction class

Inheritance

Constructors

AddedReaction({required ReactionType type, required MessageSender senderId, required int date})
Represents a reaction applied to a message
const
AddedReaction.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
date → int
date Point in time (Unix timestamp) when the reaction was added
final
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
senderId → MessageSender
senderId Identifier of the chat member, applied the reaction
final
type → ReactionType
type Type of the reaction
final

Methods

copyWith({ReactionType? type, MessageSender? senderId, int? date}) → AddedReaction
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String