AddedReactions class

Inheritance

Constructors

AddedReactions({required int totalCount, required List<AddedReaction> reactions, required String nextOffset, dynamic extra, int? clientId})
Represents a list of reactions added to a message
const
AddedReactions.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
nextOffset → String
nextOffset The offset for the next request. If empty, there are no more results
final
reactions → List<AddedReaction>
reactions The list of added reactions
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalCount → int
totalCount The total number of found reactions
final

Methods

copyWith({int? totalCount, List<AddedReaction>? reactions, String? nextOffset, dynamic extra, int? clientId}) → AddedReactions
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String