AnimatedChatPhoto class

Inheritance

Constructors

AnimatedChatPhoto({required int length, required File file, required double mainFrameTimestamp})
Animated variant of a chat photo in MPEG4 format
const
AnimatedChatPhoto.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
file → File
file Information about the animation file
final
hashCode → int
The hash code for this object.
no setterinherited
length → int
length Animation width and height
final
mainFrameTimestamp → double
mainFrameTimestamp Timestamp of the frame, used as a static chat photo
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? length, File? file, double? mainFrameTimestamp}) → AnimatedChatPhoto
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String