Animation class

Inheritance

Constructors

Animation({required int duration, required int width, required int height, required String fileName, required String mimeType, required bool hasStickers, Minithumbnail? minithumbnail, Thumbnail? thumbnail, required File animation})
Describes an animation file. The animation must be encoded in GIF or MPEG4 format
const
Animation.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

animation → File
animation File containing the animation
final
clientId → int?
client identifier
no setterinherited
duration → int
duration Duration of the animation, in seconds; as defined by the sender
final
extra → dynamic
callback sign
no setterinherited
fileName → String
fileName Original name of the file; as defined by the sender
final
hashCode → int
The hash code for this object.
no setterinherited
hasStickers → bool
hasStickers True, if stickers were added to the animation. The list of corresponding sticker set can be received using getAttachedStickerSets
final
height → int
height Height of the animation
final
mimeType → String
mimeType MIME type of the file, usually "image/gif" or "video/mp4"
final
minithumbnail → Minithumbnail?
minithumbnail Animation minithumbnail; may be null
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thumbnail → Thumbnail?
thumbnail Animation thumbnail in JPEG or MPEG4 format; may be null
final
width → int
width Width of the animation
final

Methods

copyWith({int? duration, int? width, int? height, String? fileName, String? mimeType, bool? hasStickers, Minithumbnail? minithumbnail, Thumbnail? thumbnail, File? animation}) → Animation
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String