AnswerCallbackQuery class

Inheritance

Constructors

AnswerCallbackQuery({required int callbackQueryId, required String text, required bool showAlert, required String url, required int cacheTime})
Sets the result of a callback query; for bots only
const

Properties

cacheTime → int
cacheTime Time during which the result of the query can be cached, in seconds
final
callbackQueryId → int
callbackQueryId Identifier of the callback query
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showAlert → bool
showAlert Pass true to show an alert to the user instead of a toast notification
final
text → String
text Text of the answer
final
url → String
url URL to be opened
final

Methods

copyWith({int? callbackQueryId, String? text, bool? showAlert, String? url, int? cacheTime}) → AnswerCallbackQuery
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String