AnswerPreCheckoutQuery class

Inheritance

Constructors

AnswerPreCheckoutQuery({required int preCheckoutQueryId, required String errorMessage})
Sets the result of a pre-checkout query; for bots only
const

Properties

errorMessage → String
errorMessage An error message, empty on success
final
hashCode → int
The hash code for this object.
no setterinherited
preCheckoutQueryId → int
preCheckoutQueryId Identifier of the pre-checkout query
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? preCheckoutQueryId, String? errorMessage}) → AnswerPreCheckoutQuery
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String