AnswerWebAppQuery class

Inheritance

Constructors

AnswerWebAppQuery({required String webAppQueryId, required InputInlineQueryResult result})
Sets the result of interaction with a Web App and sends corresponding message on behalf of the user to the chat from which the query originated; for bots only
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
result → InputInlineQueryResult
result The result of the query
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
webAppQueryId → String
webAppQueryId Identifier of the Web App query
final

Methods

copyWith({String? webAppQueryId, InputInlineQueryResult? result}) → AnswerWebAppQuery
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String