AssignAppStoreTransaction class

Inheritance

Constructors

AssignAppStoreTransaction({required String receipt, required StorePaymentPurpose purpose})
Informs server about a purchase through App Store. For official applications only
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
purpose → StorePaymentPurpose
purpose Transaction purpose
final
receipt → String
receipt App Store receipt
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? receipt, StorePaymentPurpose? purpose}) → AssignAppStoreTransaction
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String