AssignGooglePlayTransaction class

Inheritance

Constructors

AssignGooglePlayTransaction({required String packageName, required String storeProductId, required String purchaseToken, required StorePaymentPurpose purpose})
Informs server about a purchase through Google Play. For official applications only
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
packageName → String
packageName Application package name
final
purchaseToken → String
purchaseToken Google Play purchase token
final
purpose → StorePaymentPurpose
purpose Transaction purpose
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storeProductId → String
storeProductId Identifier of the purchased store product
final

Methods

copyWith({String? packageName, String? storeProductId, String? purchaseToken, StorePaymentPurpose? purpose}) → AssignGooglePlayTransaction
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String