AuthenticationCodeTypeFirebaseAndroid class

Inheritance

Constructors

AuthenticationCodeTypeFirebaseAndroid({required String nonce, required int length})
An authentication code is delivered via Firebase Authentication to the official Android application
const
AuthenticationCodeTypeFirebaseAndroid.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
length → int
length Length of the code
final
nonce → String
nonce Nonce to pass to the SafetyNet Attestation API
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? nonce, int? length}) → AuthenticationCodeTypeFirebaseAndroid
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String