AuthorizationStateWaitEmailAddress class

Inheritance

Constructors

AuthorizationStateWaitEmailAddress({required bool allowAppleId, required bool allowGoogleId, dynamic extra, int? clientId})
TDLib needs the user's email address to authorize. Call setAuthenticationEmailAddress to provide the email address, or directly call checkAuthenticationEmailCode with Apple authorizationStateWaitEmailAddress/Google authorizationStateWaitEmailAddress token if allowed
const
AuthorizationStateWaitEmailAddress.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

allowAppleId → bool
allowAppleId True, if authorization through Apple authorizationStateWaitEmailAddress is allowed
final
allowGoogleId → bool
allowGoogleId True, if authorization through Google authorizationStateWaitEmailAddress is allowed
final
clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? allowAppleId, bool? allowGoogleId, dynamic extra, int? clientId}) → AuthorizationStateWaitEmailAddress
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String