AuthorizationStateWaitEmailCode class

Inheritance

Constructors

AuthorizationStateWaitEmailCode({required bool allowAppleId, required bool allowGoogleId, required EmailAddressAuthenticationCodeInfo codeInfo, EmailAddressResetState? emailAddressResetState, dynamic extra, int? clientId})
TDLib needs the user's authentication code sent to an email address to authorize. Call checkAuthenticationEmailCode to provide the code
const
AuthorizationStateWaitEmailCode.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

allowAppleId → bool
allowAppleId True, if authorization through Apple authorizationStateWaitEmailCode is allowed
final
allowGoogleId → bool
allowGoogleId True, if authorization through Google authorizationStateWaitEmailCode is allowed
final
clientId → int?
clientId client identifier
final
codeInfo → EmailAddressAuthenticationCodeInfo
codeInfo Information about the sent authentication code
final
emailAddressResetState → EmailAddressResetState?
emailAddressResetState Reset state of the email address; may be null if the email address can't be reset
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? allowAppleId, bool? allowGoogleId, EmailAddressAuthenticationCodeInfo? codeInfo, EmailAddressResetState? emailAddressResetState, dynamic extra, int? clientId}) → AuthorizationStateWaitEmailCode
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String