AutoDownloadSettings class

Inheritance

Constructors

AutoDownloadSettings({required bool isAutoDownloadEnabled, required int maxPhotoFileSize, required int maxVideoFileSize, required int maxOtherFileSize, required int videoUploadBitrate, required bool preloadLargeVideos, required bool preloadNextAudio, required bool preloadStories, required bool useLessDataForCalls})
Contains auto-download settings
const
AutoDownloadSettings.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isAutoDownloadEnabled → bool
isAutoDownloadEnabled True, if the auto-download is enabled
final
maxOtherFileSize → int
maxOtherFileSize The maximum size of other file types to be auto-downloaded, in bytes
final
maxPhotoFileSize → int
maxPhotoFileSize The maximum size of a photo file to be auto-downloaded, in bytes
final
maxVideoFileSize → int
maxVideoFileSize The maximum size of a video file to be auto-downloaded, in bytes
final
preloadLargeVideos → bool
preloadLargeVideos True, if the beginning of video files needs to be preloaded for instant playback
final
preloadNextAudio → bool
preloadNextAudio True, if the next audio track needs to be preloaded while the user is listening to an audio file
final
preloadStories → bool
preloadStories True, if stories needs to be preloaded
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
useLessDataForCalls → bool
useLessDataForCalls True, if "use less data for calls" option needs to be enabled
final
videoUploadBitrate → int
videoUploadBitrate The maximum suggested bitrate for uploaded videos, in kbit/s
final

Methods

copyWith({bool? isAutoDownloadEnabled, int? maxPhotoFileSize, int? maxVideoFileSize, int? maxOtherFileSize, int? videoUploadBitrate, bool? preloadLargeVideos, bool? preloadNextAudio, bool? preloadStories, bool? useLessDataForCalls}) → AutoDownloadSettings
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String