AutosaveSettings class

Inheritance

Constructors

AutosaveSettings({required ScopeAutosaveSettings privateChatSettings, required ScopeAutosaveSettings groupSettings, required ScopeAutosaveSettings channelSettings, required List<AutosaveSettingsException> exceptions, dynamic extra, int? clientId})
Describes autosave settings
const
AutosaveSettings.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

channelSettings → ScopeAutosaveSettings
channelSettings Default autosave settings for channel chats
final
clientId → int?
clientId client identifier
final
exceptions → List<AutosaveSettingsException>
exceptions Autosave settings for specific chats
final
extra → dynamic
extra callback sign
final
groupSettings → ScopeAutosaveSettings
groupSettings Default autosave settings for basic group and supergroup chats
final
hashCode → int
The hash code for this object.
no setterinherited
privateChatSettings → ScopeAutosaveSettings
privateChatSettings Default autosave settings for private chats
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({ScopeAutosaveSettings? privateChatSettings, ScopeAutosaveSettings? groupSettings, ScopeAutosaveSettings? channelSettings, List<AutosaveSettingsException>? exceptions, dynamic extra, int? clientId}) → AutosaveSettings
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String