AvailableReactions class

Inheritance

Constructors

AvailableReactions({required List<AvailableReaction> topReactions, required List<AvailableReaction> recentReactions, required List<AvailableReaction> popularReactions, required bool allowCustomEmoji, dynamic extra, int? clientId})
Represents a list of reactions that can be added to a message
const
AvailableReactions.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

allowCustomEmoji → bool
allowCustomEmoji True, if custom emoji reactions could be added by Telegram Premium subscribers
final
clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
popularReactions → List<AvailableReaction>
popularReactions List of popular reactions
final
recentReactions → List<AvailableReaction>
recentReactions List of recently used reactions
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
topReactions → List<AvailableReaction>
topReactions List of reactions to be shown at the top
final

Methods

copyWith({List<AvailableReaction>? topReactions, List<AvailableReaction>? recentReactions, List<AvailableReaction>? popularReactions, bool? allowCustomEmoji, dynamic extra, int? clientId}) → AvailableReactions
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String