Background class

Inheritance

Constructors

Background({required int id, required bool isDefault, required bool isDark, required String name, Document? document, required BackgroundType type, dynamic extra, int? clientId})
Describes a chat background
const
Background.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
document → Document?
document Document with the background; may be null. Null only for filled backgrounds
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
id → int
id Unique background identifier
final
isDark → bool
isDark True, if the background is dark and is recommended to be used with dark theme
final
isDefault → bool
isDefault True, if this is one of default backgrounds
final
name → String
name Unique background name
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → BackgroundType
type Type of the background
final

Methods

copyWith({int? id, bool? isDefault, bool? isDark, String? name, Document? document, BackgroundType? type, dynamic extra, int? clientId}) → Background
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String