BackgroundTypePattern class

Inheritance

Constructors

BackgroundTypePattern({required BackgroundFill fill, required int intensity, required bool isInverted, required bool isMoving})
A PNG or TGV (gzipped subset of SVG with MIME type "application/x-tgwallpattern") pattern to be combined with the background fill chosen by the user
const
BackgroundTypePattern.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
fill → BackgroundFill
fill Fill of the background
final
hashCode → int
The hash code for this object.
no setterinherited
intensity → int
intensity Intensity of the pattern when it is shown above the filled background; 0-100.
final
isInverted → bool
isInverted True, if the background fill must be applied only to the pattern itself. All other pixels are black in this case. For dark themes only
final
isMoving → bool
isMoving True, if the background needs to be slightly moved when device is tilted
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({BackgroundFill? fill, int? intensity, bool? isInverted, bool? isMoving}) → BackgroundTypePattern
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String