BackgroundTypeWallpaper class

Inheritance

Constructors

BackgroundTypeWallpaper({required bool isBlurred, required bool isMoving})
A wallpaper in JPEG format
const
BackgroundTypeWallpaper.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isBlurred → bool
isBlurred True, if the wallpaper must be downscaled to fit in 450x450 square and then box-blurred with radius 12
final
isMoving → bool
isMoving True, if the background needs to be slightly moved when device is tilted
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? isBlurred, bool? isMoving}) → BackgroundTypeWallpaper
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String