BankCardInfo class

Inheritance

Constructors

BankCardInfo({required String title, required List<BankCardActionOpenUrl> actions, dynamic extra, int? clientId})
Information about a bank card
const
BankCardInfo.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

actions → List<BankCardActionOpenUrl>
actions Actions that can be done with the bank card number
final
clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
title Title of the bank card description
final

Methods

copyWith({String? title, List<BankCardActionOpenUrl>? actions, dynamic extra, int? clientId}) → BankCardInfo
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String