BlockMessageSenderFromReplies class

Inheritance

Constructors

BlockMessageSenderFromReplies({required int messageId, required bool deleteMessage, required bool deleteAllMessages, required bool reportSpam})
Blocks an original sender of a message in the Replies chat
const

Properties

deleteAllMessages → bool
deleteAllMessages Pass true to delete all messages from the same sender
final
deleteMessage → bool
deleteMessage Pass true to delete the message
final
hashCode → int
The hash code for this object.
no setterinherited
messageId → int
messageId The identifier of an incoming message in the Replies chat
final
reportSpam → bool
reportSpam Pass true to report the sender to the Telegram moderators
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? messageId, bool? deleteMessage, bool? deleteAllMessages, bool? reportSpam}) → BlockMessageSenderFromReplies
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String