BotCommands class

Inheritance

Constructors

BotCommands({required int botUserId, required List<BotCommand> commands, dynamic extra, int? clientId})
Contains a list of bot commands
const
BotCommands.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

botUserId → int
botUserId Bot's user identifier
final
clientId → int?
clientId client identifier
final
commands → List<BotCommand>
commands List of bot commands
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? botUserId, List<BotCommand>? commands, dynamic extra, int? clientId}) → BotCommands
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String