BotInfo class

Inheritance

Constructors

BotInfo({required String shortDescription, required String description, Photo? photo, Animation? animation, BotMenuButton? menuButton, required List<BotCommand> commands, ChatAdministratorRights? defaultGroupAdministratorRights, ChatAdministratorRights? defaultChannelAdministratorRights, InternalLinkType? editCommandsLink, InternalLinkType? editDescriptionLink, InternalLinkType? editDescriptionMediaLink, InternalLinkType? editSettingsLink})
Contains information about a bot
const
BotInfo.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

animation → Animation?
animation Animation shown in the chat with the bot if the chat is empty; may be null
final
clientId → int?
client identifier
no setterinherited
commands → List<BotCommand>
commands List of the bot commands
final
defaultChannelAdministratorRights → ChatAdministratorRights?
defaultChannelAdministratorRights Default administrator rights for adding the bot to channels; may be null
final
defaultGroupAdministratorRights → ChatAdministratorRights?
defaultGroupAdministratorRights Default administrator rights for adding the bot to basic group and supergroup chats; may be null
final
description → String
description The text shown in the chat with the bot if the chat is empty
final
editCommandsLink The internal link, which can be used to edit bot commands; may be null
final
editDescriptionLink The internal link, which can be used to edit bot description; may be null
final
editDescriptionMediaLink The internal link, which can be used to edit the photo or animation shown in the chat with the bot if the chat is empty; may be null
final
editSettingsLink The internal link, which can be used to edit bot settings; may be null
final
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
menuButton Information about a button to show instead of the bot commands menu button; may be null if ordinary bot commands menu must be shown
final
photo → Photo?
photo Photo shown in the chat with the bot if the chat is empty; may be null
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shortDescription → String
shortDescription The text that is shown on the bot's profile page and is sent together with the link when users share the bot
final

Methods

copyWith({String? shortDescription, String? description, Photo? photo, Animation? animation, BotMenuButton? menuButton, List<BotCommand>? commands, ChatAdministratorRights? defaultGroupAdministratorRights, ChatAdministratorRights? defaultChannelAdministratorRights, InternalLinkType? editCommandsLink, InternalLinkType? editDescriptionLink, InternalLinkType? editDescriptionMediaLink, InternalLinkType? editSettingsLink}) → BotInfo
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String