BotMenuButton class

Inheritance

Constructors

BotMenuButton({required String text, required String url, dynamic extra, int? clientId})
Describes a button to be shown instead of bot commands menu button
const
BotMenuButton.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String
text Text of the button
final
url → String
url URL to be passed to openWebApp
final

Methods

copyWith({String? text, String? url, dynamic extra, int? clientId}) → BotMenuButton
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String