Call class

Inheritance

Constructors

Call({required int id, required int userId, required bool isOutgoing, required bool isVideo, required CallState state})
Describes a call
const
Call.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → int
id Call identifier, not persistent
final
isOutgoing → bool
isOutgoing True, if the call is outgoing
final
isVideo → bool
isVideo True, if the call is a video call
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → CallState
state Call state
final
userId → int
userId Peer user identifier
final

Methods

copyWith({int? id, int? userId, bool? isOutgoing, bool? isVideo, CallState? state}) → Call
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String