CallServer class

Inheritance

Constructors

CallServer({required int id, required String ipAddress, required String ipv6Address, required int port, required CallServerType type})
Describes a server for relaying call data
const
CallServer.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → int
id Server identifier
final
ipAddress → String
ipAddress Server IPv4 address
final
ipv6Address → String
ipv6Address Server IPv6 address
final
port → int
port Server port number
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → CallServerType
type Server type
final

Methods

copyWith({int? id, String? ipAddress, String? ipv6Address, int? port, CallServerType? type}) → CallServer
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String