CallServerTypeTelegramReflector class

Inheritance

Constructors

CallServerTypeTelegramReflector({required String peerTag, required bool isTcp})
A Telegram call reflector
const
CallServerTypeTelegramReflector.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isTcp → bool
isTcp True, if the server uses TCP instead of UDP
final
peerTag → String
peerTag A peer tag to be used with the reflector
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? peerTag, bool? isTcp}) → CallServerTypeTelegramReflector
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String