CallServerTypeWebrtc class

Inheritance

Constructors

CallServerTypeWebrtc({required String username, required String password, required bool supportsTurn, required bool supportsStun})
A WebRTC server
const
CallServerTypeWebrtc.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
password → String
password Authentication password
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supportsStun → bool
supportsStun True, if the server supports STUN
final
supportsTurn → bool
supportsTurn True, if the server supports TURN
final
username → String
username Username to be used for authentication
final

Methods

copyWith({String? username, String? password, bool? supportsTurn, bool? supportsStun}) → CallServerTypeWebrtc
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String