CallStateDiscarded class

Inheritance

Constructors

CallStateDiscarded({required CallDiscardReason reason, required bool needRating, required bool needDebugInformation, required bool needLog})
The call has ended successfully
const
CallStateDiscarded.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
needDebugInformation → bool
needDebugInformation True, if the call debug information must be sent to the server
final
needLog → bool
needLog True, if the call log must be sent to the server
final
needRating → bool
needRating True, if the call rating must be sent to the server
final
reason → CallDiscardReason
reason The reason, why the call has ended
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({CallDiscardReason? reason, bool? needRating, bool? needDebugInformation, bool? needLog}) → CallStateDiscarded
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String