CallStateError class

Inheritance

Constructors

CallStateError({required TdError error})
The call has ended with an error
const
CallStateError.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
error → TdError
error Error. An error with the code 4005000 will be returned if an outgoing call is missed because of an expired timeout
final
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({TdError? error}) → CallStateError
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String