CallbackQueryPayloadGame class

Inheritance

Constructors

CallbackQueryPayloadGame({required String gameShortName})
The payload for a game callback button
const
CallbackQueryPayloadGame.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
gameShortName → String
gameShortName A short name of the game that was attached to the callback button
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? gameShortName}) → CallbackQueryPayloadGame
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String