CancelDownloadFile class

Inheritance

Constructors

CancelDownloadFile({required int fileId, required bool onlyIfPending})
Stops the downloading of a file. If a file has already been downloaded, does nothing
const

Properties

fileId → int
fileId Identifier of a file to stop downloading
final
hashCode → int
The hash code for this object.
no setterinherited
onlyIfPending → bool
onlyIfPending Pass true to stop downloading only if it hasn't been started, i.e. request hasn't been sent to server
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? fileId, bool? onlyIfPending}) → CancelDownloadFile
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String