ChangePhoneNumber class

Inheritance

Constructors

ChangePhoneNumber({required String phoneNumber, PhoneNumberAuthenticationSettings? settings})
Changes the phone number of the user and sends an authentication code to the user's new phone number; for official Android and iOS applications only. On success, returns information about the sent code
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
phoneNumber → String
phoneNumber The new phone number of the user in international format
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
settings → PhoneNumberAuthenticationSettings?
settings Settings for the authentication of the user's phone number; pass null to use default settings
final

Methods

copyWith({String? phoneNumber, PhoneNumberAuthenticationSettings? settings}) → ChangePhoneNumber
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String