ChangeStickerSet class

Inheritance

Constructors

ChangeStickerSet({required int setId, required bool isInstalled, required bool isArchived})
Installs/uninstalls or activates/archives a sticker set
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
isArchived → bool
isArchived The new value of is_archived. A sticker set can't be installed and archived simultaneously
final
isInstalled → bool
isInstalled The new value of is_installed
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
setId → int
setId Identifier of the sticker set
final

Methods

copyWith({int? setId, bool? isInstalled, bool? isArchived}) → ChangeStickerSet
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String