ChatActionUploadingVideoNote class

Inheritance

Constructors

ChatActionUploadingVideoNote({required int progress})
The user is uploading a video note
const
ChatActionUploadingVideoNote.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
progress → int
progress Upload progress, as a percentage
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? progress}) → ChatActionUploadingVideoNote
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String