ChatAvailableReactionsSome class

Inheritance

Constructors

ChatAvailableReactionsSome({required List<ReactionType> reactions})
Only specific reactions are available in the chat
const
ChatAvailableReactionsSome.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
reactions → List<ReactionType>
reactions The list of reactions
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<ReactionType>? reactions}) → ChatAvailableReactionsSome
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String