ChatBackground class

Inheritance

Constructors

ChatBackground({required Background background, required int darkThemeDimming})
Describes a background set for a specific chat
const
ChatBackground.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

background → Background
background The background
final
clientId → int?
client identifier
no setterinherited
darkThemeDimming → int
darkThemeDimming Dimming of the background in dark themes, as a percentage; 0-100
final
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Background? background, int? darkThemeDimming}) → ChatBackground
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String