ChatEvent class

Inheritance

Constructors

ChatEvent({required int id, required int date, required MessageSender memberId, required ChatEventAction action})
Represents a chat event
const
ChatEvent.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

action → ChatEventAction
action The action
final
clientId → int?
client identifier
no setterinherited
date → int
date Point in time (Unix timestamp) when the event happened
final
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → int
id Chat event identifier
final
memberId → MessageSender
memberId Identifier of the user or chat who performed the action
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? id, int? date, MessageSender? memberId, ChatEventAction? action}) → ChatEvent
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String