ChatEventActiveUsernamesChanged class

Inheritance

Constructors

ChatEventActiveUsernamesChanged({required List<String> oldUsernames, required List<String> newUsernames})
The chat active usernames were changed
const
ChatEventActiveUsernamesChanged.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
newUsernames → List<String>
newUsernames New list of active usernames
final
oldUsernames → List<String>
oldUsernames Previous list of active usernames
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<String>? oldUsernames, List<String>? newUsernames}) → ChatEventActiveUsernamesChanged
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String