ChatEventInviteLinkEdited class

Inheritance

Constructors

ChatEventInviteLinkEdited({required ChatInviteLink oldInviteLink, required ChatInviteLink newInviteLink})
A chat invite link was edited
const
ChatEventInviteLinkEdited.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
newInviteLink New information about the invite link
final
oldInviteLink Previous information about the invite link
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({ChatInviteLink? oldInviteLink, ChatInviteLink? newInviteLink}) → ChatEventInviteLinkEdited
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String