ChatEventMemberPromoted class

Inheritance

Constructors

ChatEventMemberPromoted({required int userId, required ChatMemberStatus oldStatus, required ChatMemberStatus newStatus})
A chat member has gained/lost administrator status, or the list of their administrator privileges has changed
const
ChatEventMemberPromoted.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
newStatus → ChatMemberStatus
newStatus New status of the chat member
final
oldStatus → ChatMemberStatus
oldStatus Previous status of the chat member
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userId → int
userId Affected chat member user identifier
final

Methods

copyWith({int? userId, ChatMemberStatus? oldStatus, ChatMemberStatus? newStatus}) → ChatEventMemberPromoted
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String