ChatEventMemberRestricted class

Inheritance

Constructors

ChatEventMemberRestricted({required MessageSender memberId, required ChatMemberStatus oldStatus, required ChatMemberStatus newStatus})
A chat member was restricted/unrestricted or banned/unbanned, or the list of their restrictions has changed
const
ChatEventMemberRestricted.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
memberId → MessageSender
memberId Affected chat member identifier
final
newStatus → ChatMemberStatus
newStatus New status of the chat member
final
oldStatus → ChatMemberStatus
oldStatus Previous status of the chat member
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({MessageSender? memberId, ChatMemberStatus? oldStatus, ChatMemberStatus? newStatus}) → ChatEventMemberRestricted
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String