ChatEventMessageEdited class

Inheritance

Constructors

ChatEventMessageEdited({required Message oldMessage, required Message newMessage})
A message was edited
const
ChatEventMessageEdited.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
newMessage → Message
newMessage The message after it was edited
final
oldMessage → Message
oldMessage The original message before the edit
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Message? oldMessage, Message? newMessage}) → ChatEventMessageEdited
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String