ChatEventPermissionsChanged class

Inheritance

Constructors

ChatEventPermissionsChanged({required ChatPermissions oldPermissions, required ChatPermissions newPermissions})
The chat permissions was changed
const
ChatEventPermissionsChanged.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
newPermissions → ChatPermissions
newPermissions New chat permissions
final
oldPermissions → ChatPermissions
oldPermissions Previous chat permissions
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({ChatPermissions? oldPermissions, ChatPermissions? newPermissions}) → ChatEventPermissionsChanged
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String