ChatEventStickerSetChanged class

Inheritance

Constructors

ChatEventStickerSetChanged({required int oldStickerSetId, required int newStickerSetId})
The supergroup sticker set was changed
const
ChatEventStickerSetChanged.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
newStickerSetId → int
newStickerSetId New identifier of the chat sticker set; 0 if none
final
oldStickerSetId → int
oldStickerSetId Previous identifier of the chat sticker set; 0 if none
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? oldStickerSetId, int? newStickerSetId}) → ChatEventStickerSetChanged
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String