ChatEventTitleChanged class

Inheritance

Constructors

ChatEventTitleChanged({required String oldTitle, required String newTitle})
The chat title was changed
const
ChatEventTitleChanged.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
newTitle → String
newTitle New chat title
final
oldTitle → String
oldTitle Previous chat title
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? oldTitle, String? newTitle}) → ChatEventTitleChanged
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String