ChatFolder class

Inheritance

Constructors

ChatFolder({required String title, ChatFolderIcon? icon, required bool isShareable, required List<int> pinnedChatIds, required List<int> includedChatIds, required List<int> excludedChatIds, required bool excludeMuted, required bool excludeRead, required bool excludeArchived, required bool includeContacts, required bool includeNonContacts, required bool includeBots, required bool includeGroups, required bool includeChannels, dynamic extra, int? clientId})
Represents a folder for user chats
const
ChatFolder.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
excludeArchived → bool
excludeArchived True, if archived chats need to be excluded
final
excludedChatIds → List<int>
excludedChatIds The chat identifiers of always excluded chats in the folder. There can be up to getOption("chat_folder_chosen_chat_count_max") always excluded non-secret chats and the same number of secret chats, but the limit can be increased with Telegram Premium
final
excludeMuted → bool
excludeMuted True, if muted chats need to be excluded
final
excludeRead → bool
excludeRead True, if read chats need to be excluded
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
icon → ChatFolderIcon?
icon The chosen icon for the chat folder; may be null. If null, use getChatFolderDefaultIconName to get default icon name for the folder
final
includeBots → bool
includeBots True, if bots need to be included
final
includeChannels → bool
includeChannels True, if channels need to be included
final
includeContacts → bool
includeContacts True, if contacts need to be included
final
includedChatIds → List<int>
includedChatIds The chat identifiers of always included chats in the folder. There can be up to getOption("chat_folder_chosen_chat_count_max") pinned and always included non-secret chats and the same number of secret chats, but the limit can be increased with Telegram Premium
final
includeGroups → bool
includeGroups True, if basic groups and supergroups need to be included
final
includeNonContacts → bool
includeNonContacts True, if non-contact users need to be included
final
isShareable → bool
isShareable True, if at least one link has been created for the folder
final
pinnedChatIds → List<int>
pinnedChatIds The chat identifiers of pinned chats in the folder. There can be up to getOption("chat_folder_chosen_chat_count_max") pinned and always included non-secret chats and the same number of secret chats, but the limit can be increased with Telegram Premium
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
title The title of the folder; 1-12 characters without line feeds
final

Methods

copyWith({String? title, ChatFolderIcon? icon, bool? isShareable, List<int>? pinnedChatIds, List<int>? includedChatIds, List<int>? excludedChatIds, bool? excludeMuted, bool? excludeRead, bool? excludeArchived, bool? includeContacts, bool? includeNonContacts, bool? includeBots, bool? includeGroups, bool? includeChannels, dynamic extra, int? clientId}) → ChatFolder
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String