ChatFolderInfo class

Inheritance

Constructors

ChatFolderInfo({required int id, required String title, required ChatFolderIcon icon, required bool isShareable, required bool hasMyInviteLinks, dynamic extra, int? clientId})
Contains basic information about a chat folder
const
ChatFolderInfo.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
hasMyInviteLinks True, if the chat folder has invite links created by the current user
final
icon → ChatFolderIcon
icon The chosen or default icon for the chat folder
final
id → int
id Unique chat folder identifier
final
isShareable → bool
isShareable True, if at least one link has been created for the folder
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
title The title of the folder; 1-12 characters without line feeds
final

Methods

copyWith({int? id, String? title, ChatFolderIcon? icon, bool? isShareable, bool? hasMyInviteLinks, dynamic extra, int? clientId}) → ChatFolderInfo
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String