ChatFolderInviteLink class

Inheritance

Constructors

ChatFolderInviteLink({required String inviteLink, required String name, required List<int> chatIds, dynamic extra, int? clientId})
Contains a chat folder invite link
const
ChatFolderInviteLink.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

chatIds → List<int>
chatIds Identifiers of chats, included in the link
final
clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
inviteLink The chat folder invite link
final
name → String
name Name of the link
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? inviteLink, String? name, List<int>? chatIds, dynamic extra, int? clientId}) → ChatFolderInviteLink
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String