ChatInviteLinkCount class

Inheritance

Constructors

ChatInviteLinkCount({required int userId, required int inviteLinkCount, required int revokedInviteLinkCount})
Describes a chat administrator with a number of active and revoked chat invite links
const
ChatInviteLinkCount.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
inviteLinkCount → int
inviteLinkCount Number of active invite links
final
revokedInviteLinkCount → int
revokedInviteLinkCount Number of revoked invite links
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userId → int
userId Administrator's user identifier
final

Methods

copyWith({int? userId, int? inviteLinkCount, int? revokedInviteLinkCount}) → ChatInviteLinkCount
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String