ChatInviteLinkInfo class

Inheritance

Constructors

ChatInviteLinkInfo({required int chatId, required int accessibleFor, required ChatType type, required String title, ChatPhotoInfo? photo, required String description, required int memberCount, required List<int> memberUserIds, required bool createsJoinRequest, required bool isPublic, dynamic extra, int? clientId})
Contains information about a chat invite link
const
ChatInviteLinkInfo.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

accessibleFor → int
accessibleFor If non-zero, the amount of time for which read access to the chat will remain available, in seconds
final
chatId → int
chatId Chat identifier of the invite link; 0 if the user has no access to the chat before joining
final
clientId → int?
clientId client identifier
final
createsJoinRequest → bool
createsJoinRequest True, if the link only creates join request
final
description → String
description Chat description
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
isPublic → bool
isPublic True, if the chat is a public supergroup or channel, i.e. it has a username or it is a location-based supergroup
final
memberCount → int
memberCount Number of members in the chat
final
memberUserIds → List<int>
memberUserIds User identifiers of some chat members that may be known to the current user
final
photo → ChatPhotoInfo?
photo Chat photo; may be null
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
title Title of the chat
final
type → ChatType
type Type of the chat
final

Methods

copyWith({int? chatId, int? accessibleFor, ChatType? type, String? title, ChatPhotoInfo? photo, String? description, int? memberCount, List<int>? memberUserIds, bool? createsJoinRequest, bool? isPublic, dynamic extra, int? clientId}) → ChatInviteLinkInfo
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String