ChatInviteLinkMember class

Inheritance

Constructors

ChatInviteLinkMember({required int userId, required int joinedChatDate, required bool viaChatFolderInviteLink, required int approverUserId})
Describes a chat member joined a chat via an invite link
const
ChatInviteLinkMember.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

approverUserId → int
approverUserId User identifier of the chat administrator, approved user join request
final
clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
joinedChatDate → int
joinedChatDate Point in time (Unix timestamp) when the user joined the chat
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userId → int
userId User identifier
final
viaChatFolderInviteLink True, if the user has joined the chat using an invite link for a chat folder
final

Methods

copyWith({int? userId, int? joinedChatDate, bool? viaChatFolderInviteLink, int? approverUserId}) → ChatInviteLinkMember
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String