ChatJoinRequest class

Inheritance

Constructors

ChatJoinRequest({required int userId, required int date, required String bio})
Describes a user that sent a join request and waits for administrator approval
const
ChatJoinRequest.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

bio → String
bio A short bio of the user
final
clientId → int?
client identifier
no setterinherited
date → int
date Point in time (Unix timestamp) when the user sent the join request
final
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userId → int
userId User identifier
final

Methods

copyWith({int? userId, int? date, String? bio}) → ChatJoinRequest
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String