ChatMemberStatusCreator class

Inheritance

Constructors

ChatMemberStatusCreator({required String customTitle, required bool isAnonymous, required bool isMember})
The user is the owner of the chat and has all the administrator privileges
const
ChatMemberStatusCreator.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
customTitle → String
customTitle A custom title of the owner; 0-16 characters without emojis; applicable to supergroups only
final
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isAnonymous → bool
isAnonymous True, if the creator isn't shown in the chat member list and sends messages anonymously; applicable to supergroups only
final
isMember → bool
isMember True, if the user is a member of the chat
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? customTitle, bool? isAnonymous, bool? isMember}) → ChatMemberStatusCreator
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String