ChatMemberStatusRestricted class

Inheritance

Constructors

ChatMemberStatusRestricted({required bool isMember, required int restrictedUntilDate, required ChatPermissions permissions})
The user is under certain restrictions in the chat. Not supported in basic groups and channels
const
ChatMemberStatusRestricted.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isMember → bool
isMember True, if the user is a member of the chat
final
permissions → ChatPermissions
permissions User permissions in the chat
final
restrictedUntilDate → int
restrictedUntilDate Point in time (Unix timestamp) when restrictions will be lifted from the user; 0 if never. If the user is restricted for more than 366 days or for less than 30 seconds from the current time, the user is considered to be restricted forever
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? isMember, int? restrictedUntilDate, ChatPermissions? permissions}) → ChatMemberStatusRestricted
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String