ChatMessageSender class

Inheritance

Constructors

ChatMessageSender({required MessageSender sender, required bool needsPremium})
Represents a message sender, which can be used to send messages in a chat
const
ChatMessageSender.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
needsPremium → bool
needsPremium True, if Telegram Premium is needed to use the message sender
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sender → MessageSender
sender Available message senders
final

Methods

copyWith({MessageSender? sender, bool? needsPremium}) → ChatMessageSender
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String