ChatPhotoSticker class

Inheritance

Constructors

ChatPhotoSticker({required ChatPhotoStickerType type, required BackgroundFill backgroundFill})
Information about the sticker, which was used to create the chat photo. The sticker is shown at the center of the photo and occupies at most 67% of it
const
ChatPhotoSticker.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

backgroundFill → BackgroundFill
backgroundFill The fill to be used as background for the sticker; rotation angle in backgroundFillGradient isn't supported
final
clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → ChatPhotoStickerType
type Type of the sticker
final

Methods

copyWith({ChatPhotoStickerType? type, BackgroundFill? backgroundFill}) → ChatPhotoSticker
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String