ChatPosition class

Inheritance

Constructors

ChatPosition({required ChatList list, required int order, required bool isPinned, ChatSource? source})
Describes a position of a chat in a chat list
const
ChatPosition.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isPinned → bool
isPinned True, if the chat is pinned in the chat list
final
list → ChatList
list The chat list
final
order → int
order A parameter used to determine order of the chat in the chat list. Chats must be sorted by the pair (order, chat.id) in descending order
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → ChatSource?
source Source of the chat in the chat list; may be null
final

Methods

copyWith({ChatList? list, int? order, bool? isPinned, ChatSource? source}) → ChatPosition
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String