ChatStatisticsAdministratorActionsInfo class

Inheritance

Constructors

ChatStatisticsAdministratorActionsInfo({required int userId, required int deletedMessageCount, required int bannedUserCount, required int restrictedUserCount})
Contains statistics about administrator actions done by a user
const
ChatStatisticsAdministratorActionsInfo.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

bannedUserCount → int
bannedUserCount Number of users banned by the administrator
final
clientId → int?
client identifier
no setterinherited
deletedMessageCount → int
deletedMessageCount Number of messages deleted by the administrator
final
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
restrictedUserCount → int
restrictedUserCount Number of users restricted by the administrator
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userId → int
userId Administrator user identifier
final

Methods

copyWith({int? userId, int? deletedMessageCount, int? bannedUserCount, int? restrictedUserCount}) → ChatStatisticsAdministratorActionsInfo
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String