ChatStatisticsInviterInfo class

Inheritance

Constructors

ChatStatisticsInviterInfo({required int userId, required int addedMemberCount})
Contains statistics about number of new members invited by a user
const
ChatStatisticsInviterInfo.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

addedMemberCount → int
addedMemberCount Number of new members invited by the user
final
clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userId → int
userId User identifier
final

Methods

copyWith({int? userId, int? addedMemberCount}) → ChatStatisticsInviterInfo
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String