ChatStatisticsMessageInteractionInfo class

Inheritance

Constructors

ChatStatisticsMessageInteractionInfo({required int messageId, required int viewCount, required int forwardCount})
Contains statistics about interactions with a message
const
ChatStatisticsMessageInteractionInfo.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
forwardCount → int
forwardCount Number of times the message was forwarded
final
hashCode → int
The hash code for this object.
no setterinherited
messageId → int
messageId Message identifier
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
viewCount → int
viewCount Number of times the message was viewed
final

Methods

copyWith({int? messageId, int? viewCount, int? forwardCount}) → ChatStatisticsMessageInteractionInfo
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String