Chats class

Inheritance

Constructors

Chats({required int totalCount, required List<int> chatIds, dynamic extra, int? clientId})
Represents a list of chats
const
Chats.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

chatIds → List<int>
chatIds List of chat identifiers
final
clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalCount → int
totalCount Approximate total number of chats found
final

Methods

copyWith({int? totalCount, List<int>? chatIds, dynamic extra, int? clientId}) → Chats
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String