ChatsNearby class

Inheritance

Constructors

ChatsNearby({required List<ChatNearby> usersNearby, required List<ChatNearby> supergroupsNearby, dynamic extra, int? clientId})
Represents a list of chats located nearby
const
ChatsNearby.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supergroupsNearby → List<ChatNearby>
supergroupsNearby List of location-based supergroups nearby
final
usersNearby → List<ChatNearby>
usersNearby List of users nearby
final

Methods

copyWith({List<ChatNearby>? usersNearby, List<ChatNearby>? supergroupsNearby, dynamic extra, int? clientId}) → ChatsNearby
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String