CheckChatInviteLink class

Inheritance

Constructors

CheckChatInviteLink({required String inviteLink})
Checks the validity of an invite link for a chat and returns information about the corresponding chat
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
inviteLink Invite link to be checked
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? inviteLink}) → CheckChatInviteLink
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String