CheckPasswordRecoveryCode class

Inheritance

Constructors

CheckPasswordRecoveryCode({required String recoveryCode})
Checks whether a 2-step verification password recovery code sent to an email address is valid
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
recoveryCode → String
recoveryCode Recovery code to check
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? recoveryCode}) → CheckPasswordRecoveryCode
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String