CheckPhoneNumberVerificationCode class

Inheritance

Constructors

CheckPhoneNumberVerificationCode({required String code})
Checks the phone number verification code for Telegram Passport
const

Properties

code → String
code Verification code to check
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? code}) → CheckPhoneNumberVerificationCode
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String