CheckRecoveryEmailAddressCode class

Inheritance

Constructors

CheckRecoveryEmailAddressCode({required String code})
Checks the 2-step verification recovery email address verification code
const

Properties

code → String
code Verification code to check
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? code}) → CheckRecoveryEmailAddressCode
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String