ClearAutosaveSettingsExceptions class

Inheritance

Constructors

ClearAutosaveSettingsExceptions()
Clears the list of all autosave settings exceptions. The method is guaranteed to work only after at least one call to getAutosaveSettings
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith() → ClearAutosaveSettingsExceptions
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String