ClickAnimatedEmojiMessage class

Inheritance

Constructors

ClickAnimatedEmojiMessage({required int chatId, required int messageId})
Informs TDLib that a message with an animated emoji was clicked by the user. Returns a big animated sticker to be played or a 404 error if usual animation needs to be played
const

Properties

chatId → int
chatId Chat identifier of the message
final
hashCode → int
The hash code for this object.
no setterinherited
messageId → int
messageId Identifier of the clicked message
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? messageId}) → ClickAnimatedEmojiMessage
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String