ClickChatSponsoredMessage class

Inheritance

Constructors

ClickChatSponsoredMessage({required int chatId, required int messageId})
Informs TDLib that the user opened the sponsored chat via the button, the name, the photo, or a mention in the sponsored message
const

Properties

chatId → int
chatId Chat identifier of the sponsored message
final
hashCode → int
The hash code for this object.
no setterinherited
messageId → int
messageId Identifier of the sponsored message
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? messageId}) → ClickChatSponsoredMessage
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String