CloseWebApp class

Inheritance

Constructors

CloseWebApp({required int webAppLaunchId})
Informs TDLib that a previously opened Web App was closed
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
webAppLaunchId → int
webAppLaunchId Identifier of Web App launch, received from openWebApp
final

Methods

copyWith({int? webAppLaunchId}) → CloseWebApp
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String