ConnectedWebsite class

Inheritance

Constructors

ConnectedWebsite({required int id, required String domainName, required int botUserId, required String browser, required String platform, required int logInDate, required int lastActiveDate, required String ip, required String location})
Contains information about one website the current user is logged in with Telegram
const
ConnectedWebsite.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

botUserId → int
botUserId User identifier of a bot linked with the website
final
browser → String
browser The version of a browser used to log in
final
clientId → int?
client identifier
no setterinherited
domainName → String
domainName The domain name of the website
final
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → int
id Website identifier
final
ip → String
ip IP address from which the user was logged in, in human-readable format
final
lastActiveDate → int
lastActiveDate Point in time (Unix timestamp) when obtained authorization was last used
final
location → String
location Human-readable description of a country and a region from which the user was logged in, based on the IP address
final
logInDate → int
logInDate Point in time (Unix timestamp) when the user was logged in
final
platform → String
platform Operating system the browser is running on
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? id, String? domainName, int? botUserId, String? browser, String? platform, int? logInDate, int? lastActiveDate, String? ip, String? location}) → ConnectedWebsite
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String