Contact class

Inheritance

Constructors

Contact({required String phoneNumber, required String firstName, required String lastName, required String vcard, required int userId})
Describes a user contact
const
Contact.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
firstName → String
firstName First name of the user; 1-255 characters in length
final
hashCode → int
The hash code for this object.
no setterinherited
lastName → String
lastName Last name of the user
final
phoneNumber → String
phoneNumber Phone number of the user
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userId → int
userId Identifier of the user, if known; 0 otherwise
final
vcard → String
vcard Additional data about the user in a form of vCard; 0-2048 bytes in length
final

Methods

copyWith({String? phoneNumber, String? firstName, String? lastName, String? vcard, int? userId}) → Contact
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String