CountryInfo class

Inheritance

Constructors

CountryInfo({required String countryCode, required String name, required String englishName, required bool isHidden, required List<String> callingCodes})
Contains information about a country
const
CountryInfo.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

callingCodes → List<String>
callingCodes List of country calling codes
final
clientId → int?
client identifier
no setterinherited
countryCode → String
countryCode A two-letter ISO 3166-1 alpha-2 country code
final
englishName → String
englishName English name of the country
final
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isHidden → bool
isHidden True, if the country must be hidden from the list of all countries
final
name → String
name Native name of the country
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? countryCode, String? name, String? englishName, bool? isHidden, List<String>? callingCodes}) → CountryInfo
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String