CreateCall class

Inheritance

Constructors

CreateCall({required int userId, required CallProtocol protocol, required bool isVideo})
Creates a new call
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
isVideo → bool
isVideo Pass true to create a video call
final
protocol → CallProtocol
protocol The call protocols supported by the application
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userId → int
userId Identifier of the user to be called
final

Methods

copyWith({int? userId, CallProtocol? protocol, bool? isVideo}) → CreateCall
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String