CreateChatInviteLink class

Inheritance

Constructors

CreateChatInviteLink({required int chatId, required String name, required int expirationDate, required int memberLimit, required bool createsJoinRequest})
Creates a new invite link for a chat. Available for basic groups, supergroups, and channels. Requires administrator privileges and can_invite_users right in the chat
const

Properties

chatId → int
chatId Chat identifier
final
createsJoinRequest → bool
createsJoinRequest Pass true if users joining the chat via the link need to be approved by chat administrators. In this case, member_limit must be 0
final
expirationDate → int
expirationDate Point in time (Unix timestamp) when the link will expire; pass 0 if never
final
hashCode → int
The hash code for this object.
no setterinherited
memberLimit → int
memberLimit The maximum number of chat members that can join the chat via the link simultaneously; 0-99999; pass 0 if not limited
final
name → String
name Invite link name; 0-32 characters
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, String? name, int? expirationDate, int? memberLimit, bool? createsJoinRequest}) → CreateChatInviteLink
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String