CreateInvoiceLink class

Inheritance

Constructors

CreateInvoiceLink({required InputMessageContent invoice})
Creates a link for the given invoice; for bots only
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
invoice → InputMessageContent
invoice Information about the invoice of the type inputMessageInvoice
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({InputMessageContent? invoice}) → CreateInvoiceLink
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String