CreateNewSecretChat class

Inheritance

Constructors

CreateNewSecretChat({required int userId})
Creates a new secret chat. Returns the newly created chat
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userId → int
userId Identifier of the target user
final

Methods

copyWith({int? userId}) → CreateNewSecretChat
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String