CreateNewStickerSet class

Inheritance

Constructors

CreateNewStickerSet({required int userId, required String title, required String name, required StickerFormat stickerFormat, required StickerType stickerType, required bool needsRepainting, required List<InputSticker> stickers, required String source})
Creates a new sticker set. Returns the newly created sticker set
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
name Sticker set name. Can contain only English letters, digits and underscores. Must end with *"by
final
needsRepainting → bool
needsRepainting Pass true if stickers in the sticker set must be repainted; for custom emoji sticker sets only
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → String
source Source of the sticker set; may be empty if unknown
final
stickerFormat → StickerFormat
stickerFormat Format of the stickers in the set
final
stickers → List<InputSticker>
stickers List of stickers to be added to the set; must be non-empty. All stickers must have the same format. For TGS stickers, uploadStickerFile must be used before the sticker is shown
final
stickerType → StickerType
stickerType Type of the stickers in the set
final
title → String
title Sticker set title; 1-64 characters
final
userId → int
userId Sticker set owner; ignored for regular users
final

Methods

copyWith({int? userId, String? title, String? name, StickerFormat? stickerFormat, StickerType? stickerType, bool? needsRepainting, List<InputSticker>? stickers, String? source}) → CreateNewStickerSet
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String