CreateSupergroupChat class

Inheritance

Constructors

CreateSupergroupChat({required int supergroupId, required bool force})
Returns an existing chat corresponding to a known supergroup or channel
const

Properties

force → bool
force Pass true to create the chat without a network request. In this case all information about the chat except its type, title and photo can be incorrect
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supergroupId → int
supergroupId Supergroup or channel identifier
final

Methods

copyWith({int? supergroupId, bool? force}) → CreateSupergroupChat
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String