DeleteAllCallMessages class

Inheritance

Constructors

DeleteAllCallMessages({required bool revoke})
Deletes all call messages
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
revoke → bool
revoke Pass true to delete the messages for all users
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? revoke}) → DeleteAllCallMessages
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String