DeleteChatFolder class

Inheritance

Constructors

DeleteChatFolder({required int chatFolderId, required List<int> leaveChatIds})
Deletes existing chat folder
const

Properties

chatFolderId → int
chatFolderId Chat folder identifier
final
hashCode → int
The hash code for this object.
no setterinherited
leaveChatIds → List<int>
leaveChatIds Identifiers of the chats to leave. The chats must be pinned or always included in the folder
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatFolderId, List<int>? leaveChatIds}) → DeleteChatFolder
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String