DeleteChatHistory class

Inheritance

Constructors

DeleteChatHistory({required int chatId, required bool removeFromChatList, required bool revoke})
Deletes all messages in the chat. Use chat.can_be_deleted_only_for_self and chat.can_be_deleted_for_all_users fields to find whether and how the method can be applied to the chat
const

Properties

chatId → int
chatId Chat identifier
final
hashCode → int
The hash code for this object.
no setterinherited
removeFromChatList → bool
removeFromChatList Pass true to remove the chat from all chat lists
final
revoke → bool
revoke Pass true to delete chat history for all users
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, bool? removeFromChatList, bool? revoke}) → DeleteChatHistory
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String