DeleteMessages class

Inheritance

Constructors

DeleteMessages({required int chatId, required List<int> messageIds, required bool revoke})
Deletes messages
const

Properties

chatId → int
chatId Chat identifier
final
hashCode → int
The hash code for this object.
no setterinherited
messageIds → List<int>
messageIds Identifiers of the messages to be deleted
final
revoke → bool
revoke Pass true to delete messages for all chat members. Always true for supergroups, channels and secret chats
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, List<int>? messageIds, bool? revoke}) → DeleteMessages
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String