DeletePassportElement class

Inheritance

Constructors

DeletePassportElement({required PassportElementType type})
Deletes a Telegram Passport element
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → PassportElementType
type Element type
final

Methods

copyWith({PassportElementType? type}) → DeletePassportElement
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String