DeleteProfilePhoto class

Inheritance

Constructors

DeleteProfilePhoto({required int profilePhotoId})
Deletes a profile photo
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
profilePhotoId → int
profilePhotoId Identifier of the profile photo to delete
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? profilePhotoId}) → DeleteProfilePhoto
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String