DeviceTokenApplePushVoIP class

Inheritance

Constructors

DeviceTokenApplePushVoIP({required String deviceToken, required bool isAppSandbox, required bool encrypt})
A token for Apple Push Notification service VoIP notifications
const
DeviceTokenApplePushVoIP.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
deviceToken → String
deviceToken Device token; may be empty to deregister a device
final
encrypt → bool
encrypt True, if push notifications must be additionally encrypted
final
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isAppSandbox → bool
isAppSandbox True, if App Sandbox is enabled
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? deviceToken, bool? isAppSandbox, bool? encrypt}) → DeviceTokenApplePushVoIP
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String