DeviceTokenUbuntuPush class

Inheritance

Constructors

DeviceTokenUbuntuPush({required String token})
A token for Ubuntu Push Client service
const
DeviceTokenUbuntuPush.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
token → String
token Token; may be empty to deregister a device
final

Methods

copyWith({String? token}) → DeviceTokenUbuntuPush
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String