DeviceTokenWindowsPush class

Inheritance

Constructors

DeviceTokenWindowsPush({required String accessToken})
A token for Windows Push Notification Services
const
DeviceTokenWindowsPush.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

accessToken → String
accessToken The access token that will be used to send notifications; may be empty to deregister a device
final
clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? accessToken}) → DeviceTokenWindowsPush
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String