DiceStickersSlotMachine class

Inheritance

Constructors

DiceStickersSlotMachine({required Sticker background, required Sticker lever, required Sticker leftReel, required Sticker centerReel, required Sticker rightReel})
Animated stickers to be combined into a slot machine
const
DiceStickersSlotMachine.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

background → Sticker
background The animated sticker with the slot machine background. The background animation must start playing after all reel animations finish
final
centerReel → Sticker
centerReel The animated sticker with the center reel
final
clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
leftReel → Sticker
leftReel The animated sticker with the left reel
final
lever → Sticker
lever The animated sticker with the lever animation. The lever animation must play once in the initial dice state
final
rightReel → Sticker
rightReel The animated sticker with the right reel
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Sticker? background, Sticker? lever, Sticker? leftReel, Sticker? centerReel, Sticker? rightReel}) → DiceStickersSlotMachine
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String