DiscardCall class

Inheritance

Constructors

DiscardCall({required int callId, required bool isDisconnected, required int duration, required bool isVideo, required int connectionId})
Discards a call
const

Properties

callId → int
callId Call identifier
final
connectionId → int
connectionId Identifier of the connection used during the call
final
duration → int
duration The call duration, in seconds
final
hashCode → int
The hash code for this object.
no setterinherited
isDisconnected → bool
isDisconnected Pass true if the user was disconnected
final
isVideo → bool
isVideo Pass true if the call was a video call
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? callId, bool? isDisconnected, int? duration, bool? isVideo, int? connectionId}) → DiscardCall
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String