DownloadedFileCounts class

Inheritance

Constructors

DownloadedFileCounts({required int activeCount, required int pausedCount, required int completedCount})
Contains number of being downloaded and recently downloaded files found
const
DownloadedFileCounts.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

activeCount → int
activeCount Number of active file downloads found, including paused
final
clientId → int?
client identifier
no setterinherited
completedCount → int
completedCount Number of completed file downloads found
final
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
pausedCount → int
pausedCount Number of paused file downloads found
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? activeCount, int? pausedCount, int? completedCount}) → DownloadedFileCounts
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String