DraftMessage class

Inheritance

Constructors

DraftMessage({required int replyToMessageId, required int date, required InputMessageContent inputMessageText})
Contains information about a message draft
const
DraftMessage.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
date → int
date Point in time (Unix timestamp) when the draft was created
final
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
inputMessageText → InputMessageContent
inputMessageText Content of the message draft; must be of the type inputMessageText
final
replyToMessageId → int
replyToMessageId Identifier of the replied message; 0 if none
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? replyToMessageId, int? date, InputMessageContent? inputMessageText}) → DraftMessage
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String