EditCustomLanguagePackInfo class

Inheritance

Constructors

EditCustomLanguagePackInfo({required LanguagePackInfo info})
Edits information about a custom local language pack in the current localization target. Can be called before authorization
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
info → LanguagePackInfo
info New information about the custom local language pack
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({LanguagePackInfo? info}) → EditCustomLanguagePackInfo
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String