EditInlineMessageLiveLocation class

Inheritance

Constructors

EditInlineMessageLiveLocation({required String inlineMessageId, ReplyMarkup? replyMarkup, Location? location, required int heading, required int proximityAlertRadius})
Edits the content of a live location in an inline message sent via a bot; for bots only
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
heading → int
heading The new direction in which the location moves, in degrees; 1-360. Pass 0 if unknown
final
inlineMessageId → String
inlineMessageId Inline message identifier
final
location → Location?
location New location content of the message; pass null to stop sharing the live location
final
proximityAlertRadius → int
proximityAlertRadius The new maximum distance for proximity alerts, in meters (0-100000). Pass 0 if the notification is disabled
final
replyMarkup → ReplyMarkup?
replyMarkup The new message reply markup; pass null if none
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? inlineMessageId, ReplyMarkup? replyMarkup, Location? location, int? heading, int? proximityAlertRadius}) → EditInlineMessageLiveLocation
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String