EditInlineMessageMedia class

Inheritance

Constructors

EditInlineMessageMedia({required String inlineMessageId, ReplyMarkup? replyMarkup, required InputMessageContent inputMessageContent})
Edits the content of a message with an animation, an audio, a document, a photo or a video in an inline message sent via a bot; for bots only
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
inlineMessageId → String
inlineMessageId Inline message identifier
final
inputMessageContent → InputMessageContent
inputMessageContent New content of the message. Must be one of the following types: inputMessageAnimation, inputMessageAudio, inputMessageDocument, inputMessagePhoto or inputMessageVideo
final
replyMarkup → ReplyMarkup?
replyMarkup The new message reply markup; pass null if none; for bots only
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? inlineMessageId, ReplyMarkup? replyMarkup, InputMessageContent? inputMessageContent}) → EditInlineMessageMedia
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String