EditInlineMessageReplyMarkup class

Inheritance

Constructors

EditInlineMessageReplyMarkup({required String inlineMessageId, ReplyMarkup? replyMarkup})
Edits the reply markup of an inline message sent via a bot; for bots only
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
inlineMessageId → String
inlineMessageId Inline message identifier
final
replyMarkup → ReplyMarkup?
replyMarkup The new message reply markup; pass null if none
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? inlineMessageId, ReplyMarkup? replyMarkup}) → EditInlineMessageReplyMarkup
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String