EditInlineMessageText class

Inheritance

Constructors

EditInlineMessageText({required String inlineMessageId, ReplyMarkup? replyMarkup, required InputMessageContent inputMessageContent})
Edits the text of an inline text or game message sent via a bot; for bots only
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
inlineMessageId → String
inlineMessageId Inline message identifier
final
inputMessageContent → InputMessageContent
inputMessageContent New text content of the message. Must be of type inputMessageText
final
replyMarkup → ReplyMarkup?
replyMarkup The new message reply markup; pass null if none
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? inlineMessageId, ReplyMarkup? replyMarkup, InputMessageContent? inputMessageContent}) → EditInlineMessageText
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String