EditMessageCaption class

Inheritance

Constructors

EditMessageCaption({required int chatId, required int messageId, ReplyMarkup? replyMarkup, FormattedText? caption})
Edits the message content caption. Returns the edited message after the edit is completed on the server side
const

Properties

caption → FormattedText?
caption New message content caption; 0-getOption("message_caption_length_max") characters; pass null to remove caption
final
chatId → int
chatId The chat the message belongs to
final
hashCode → int
The hash code for this object.
no setterinherited
messageId → int
messageId Identifier of the message
final
replyMarkup → ReplyMarkup?
replyMarkup The new message reply markup; pass null if none; for bots only
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? messageId, ReplyMarkup? replyMarkup, FormattedText? caption}) → EditMessageCaption
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String