EditMessageMedia class

Inheritance

Constructors

EditMessageMedia({required int chatId, required int messageId, ReplyMarkup? replyMarkup, required InputMessageContent inputMessageContent})
Edits the content of a message with an animation, an audio, a document, a photo or a video, including message caption. If only the caption needs to be edited, use editMessageCaption instead.. The media can't be edited if the message was set to self-destruct or to a self-destructing media. The type of message content in an album can't be changed with exception of replacing a photo with a video or vice versa. Returns the edited message after the edit is completed on the server side
const

Properties

chatId → int
chatId The chat the message belongs to
final
hashCode → int
The hash code for this object.
no setterinherited
inputMessageContent → InputMessageContent
inputMessageContent New content of the message. Must be one of the following types: inputMessageAnimation, inputMessageAudio, inputMessageDocument, inputMessagePhoto or inputMessageVideo
final
messageId → int
messageId Identifier of the message
final
replyMarkup → ReplyMarkup?
replyMarkup The new message reply markup; pass null if none; for bots only
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? messageId, ReplyMarkup? replyMarkup, InputMessageContent? inputMessageContent}) → EditMessageMedia
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String