EditMessageSchedulingState class

Inheritance

Constructors

EditMessageSchedulingState({required int chatId, required int messageId, MessageSchedulingState? schedulingState})
Edits the time when a scheduled message will be sent. Scheduling state of all messages in the same album or forwarded together with the message will be also changed
const

Properties

chatId → int
chatId The chat the message belongs to
final
hashCode → int
The hash code for this object.
no setterinherited
messageId → int
messageId Identifier of the message
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schedulingState → MessageSchedulingState?
schedulingState The new message scheduling state; pass null to send the message immediately
final

Methods

copyWith({int? chatId, int? messageId, MessageSchedulingState? schedulingState}) → EditMessageSchedulingState
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String