EditMessageText class

Inheritance

Constructors

EditMessageText({required int chatId, required int messageId, ReplyMarkup? replyMarkup, required InputMessageContent inputMessageContent})
Edits the text of a message (or a text of a game message). Returns the edited message after the edit is completed on the server side
const

Properties

chatId → int
chatId The chat the message belongs to
final
hashCode → int
The hash code for this object.
no setterinherited
inputMessageContent → InputMessageContent
inputMessageContent New text content of the message. Must be of type inputMessageText
final
messageId → int
messageId Identifier of the message
final
replyMarkup → ReplyMarkup?
replyMarkup The new message reply markup; pass null if none; for bots only
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? messageId, ReplyMarkup? replyMarkup, InputMessageContent? inputMessageContent}) → EditMessageText
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String