EmailAddressResetStatePending class

Inheritance

Constructors

EmailAddressResetStatePending({required int resetIn})
Email address reset has already been requested. Call resetAuthenticationEmailAddress to check whether immediate reset is possible
const
EmailAddressResetStatePending.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
resetIn → int
resetIn Left time before the email address will be reset, in seconds. updateAuthorizationState is not sent when this field changes
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? resetIn}) → EmailAddressResetStatePending
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String