EmojiCategory class

Inheritance

Constructors

EmojiCategory({required String name, required Sticker icon, required List<String> emojis})
Contains a list of similar emoji to search for in getStickers and searchStickers
const
EmojiCategory.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
emojis → List<String>
emojis List of emojis in the category
final
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
icon → Sticker
icon Custom emoji sticker, which represents icon of the category
final
name → String
name Name of the category
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? name, Sticker? icon, List<String>? emojis}) → EmojiCategory
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String