EmojiStatus class

Inheritance

Constructors

EmojiStatus({required int customEmojiId, required int expirationDate})
Describes a custom emoji to be shown instead of the Telegram Premium badge
const
EmojiStatus.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
customEmojiId → int
customEmojiId Identifier of the custom emoji in stickerFormatTgs format
final
expirationDate → int
expirationDate Point in time (Unix timestamp) when the status will expire; 0 if never
final
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? customEmojiId, int? expirationDate}) → EmojiStatus
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String