EncryptedCredentials class

Inheritance

Constructors

EncryptedCredentials({required String data, required String hash, required String secret})
Contains encrypted Telegram Passport data credentials
const
EncryptedCredentials.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
data → String
data The encrypted credentials
final
extra → dynamic
callback sign
no setterinherited
hash → String
hash The decrypted data hash
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secret → String
secret Secret for data decryption, encrypted with the service's public key
final

Methods

copyWith({String? data, String? hash, String? secret}) → EncryptedCredentials
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String