EncryptedPassportElement class

Inheritance

Constructors

EncryptedPassportElement({required PassportElementType type, required String data, required DatedFile frontSide, DatedFile? reverseSide, DatedFile? selfie, required List<DatedFile> translation, required List<DatedFile> files, required String value, required String hash})
Contains information about an encrypted Telegram Passport element; for bots only
const
EncryptedPassportElement.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
data → String
data Encrypted JSON-encoded data about the user
final
extra → dynamic
callback sign
no setterinherited
files → List<DatedFile>
files List of attached files
final
frontSide → DatedFile
frontSide The front side of an identity document
final
hash → String
hash Hash of the entire element
final
hashCode → int
The hash code for this object.
no setterinherited
reverseSide → DatedFile?
reverseSide The reverse side of an identity document; may be null
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selfie → DatedFile?
selfie Selfie with the document; may be null
final
translation → List<DatedFile>
translation List of files containing a certified English translation of the document
final
type → PassportElementType
type Type of Telegram Passport element
final
value → String
value Unencrypted data, phone number or email address
final

Methods

copyWith({PassportElementType? type, String? data, DatedFile? frontSide, DatedFile? reverseSide, DatedFile? selfie, List<DatedFile>? translation, List<DatedFile>? files, String? value, String? hash}) → EncryptedPassportElement
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String