FileDownload class

Inheritance

Constructors

FileDownload({required int fileId, required Message message, required int addDate, required int completeDate, required bool isPaused})
Describes a file added to file download list
const
FileDownload.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

addDate → int
addDate Point in time (Unix timestamp) when the file was added to the download list
final
clientId → int?
client identifier
no setterinherited
completeDate → int
completeDate Point in time (Unix timestamp) when the file downloading was completed; 0 if the file downloading isn't completed
final
extra → dynamic
callback sign
no setterinherited
fileId → int
fileId File identifier
final
hashCode → int
The hash code for this object.
no setterinherited
isPaused → bool
isPaused True, if downloading of the file is paused
final
message → Message
message The message with the file
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? fileId, Message? message, int? addDate, int? completeDate, bool? isPaused}) → FileDownload
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String