FinishFileGeneration class

Inheritance

Constructors

FinishFileGeneration({required int generationId, TdError? error})
Finishes the file generation
const

Properties

error → TdError?
error If passed, the file generation has failed and must be terminated; pass null if the file generation succeeded
final
generationId → int
generationId The identifier of the generation process
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? generationId, TdError? error}) → FinishFileGeneration
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String