ForumTopicIcon class

Inheritance

Constructors

ForumTopicIcon({required int color, required int customEmojiId})
Describes a forum topic icon
const
ForumTopicIcon.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
color → int
color Color of the topic icon in RGB format
final
customEmojiId → int
customEmojiId Unique identifier of the custom emoji shown on the topic icon; 0 if none
final
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? color, int? customEmojiId}) → ForumTopicIcon
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String