ForumTopics class

Inheritance

Constructors

ForumTopics({required int totalCount, required List<ForumTopic> topics, required int nextOffsetDate, required int nextOffsetMessageId, required int nextOffsetMessageThreadId, dynamic extra, int? clientId})
Describes a list of forum topics
const
ForumTopics.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
nextOffsetDate → int
nextOffsetDate Offset date for the next getForumTopics request
final
nextOffsetMessageId → int
nextOffsetMessageId Offset message identifier for the next getForumTopics request
final
nextOffsetMessageThreadId → int
nextOffsetMessageThreadId Offset message thread identifier for the next getForumTopics request
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
topics → List<ForumTopic>
topics List of forum topics
final
totalCount → int
totalCount Approximate total number of forum topics found
final

Methods

copyWith({int? totalCount, List<ForumTopic>? topics, int? nextOffsetDate, int? nextOffsetMessageId, int? nextOffsetMessageThreadId, dynamic extra, int? clientId}) → ForumTopics
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String