ForwardMessages class

Inheritance

Constructors

ForwardMessages({required int chatId, required int messageThreadId, required int fromChatId, required List<int> messageIds, MessageSendOptions? options, required bool sendCopy, required bool removeCaption, required bool onlyPreview})
Forwards previously sent messages. Returns the forwarded messages in the same order as the message identifiers passed in message_ids. If a message can't be forwarded, null will be returned instead of the message
const

Properties

chatId → int
chatId Identifier of the chat to which to forward messages
final
fromChatId → int
fromChatId Identifier of the chat from which to forward messages
final
hashCode → int
The hash code for this object.
no setterinherited
messageIds → List<int>
messageIds Identifiers of the messages to forward. Message identifiers must be in a strictly increasing order. At most 100 messages can be forwarded simultaneously
final
messageThreadId → int
messageThreadId If not 0, a message thread identifier in which the message will be sent; for forum threads only
final
onlyPreview → bool
onlyPreview Pass true to get fake messages instead of actually forwarding them
final
options → MessageSendOptions?
options Options to be used to send the messages; pass null to use default options
final
removeCaption → bool
removeCaption Pass true to remove media captions of message copies. Ignored if send_copy is false
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sendCopy → bool
sendCopy Pass true to copy content of the messages without reference to the original sender. Always true if the messages are forwarded to a secret chat or are local
final

Methods

copyWith({int? chatId, int? messageThreadId, int? fromChatId, List<int>? messageIds, MessageSendOptions? options, bool? sendCopy, bool? removeCaption, bool? onlyPreview}) → ForwardMessages
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String