FoundFileDownloads class

Inheritance

Constructors

FoundFileDownloads({required DownloadedFileCounts totalCounts, required List<FileDownload> files, required String nextOffset, dynamic extra, int? clientId})
Contains a list of downloaded files, found by a search
const
FoundFileDownloads.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
files → List<FileDownload>
files The list of files
final
hashCode → int
The hash code for this object.
no setterinherited
nextOffset → String
nextOffset The offset for the next request. If empty, there are no more results
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalCounts → DownloadedFileCounts
totalCounts Total number of suitable files, ignoring offset
final

Methods

copyWith({DownloadedFileCounts? totalCounts, List<FileDownload>? files, String? nextOffset, dynamic extra, int? clientId}) → FoundFileDownloads
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String