FoundMessages class

Inheritance

Constructors

FoundMessages({required int totalCount, required List<Message> messages, required String nextOffset, dynamic extra, int? clientId})
Contains a list of messages found by a search
const
FoundMessages.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
messages → List<Message>
messages List of messages
final
nextOffset → String
nextOffset The offset for the next request. If empty, there are no more results
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalCount → int
totalCount Approximate total number of messages found; -1 if unknown
final

Methods

copyWith({int? totalCount, List<Message>? messages, String? nextOffset, dynamic extra, int? clientId}) → FoundMessages
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String