Game class

Inheritance

Constructors

Game({required int id, required String shortName, required String title, required FormattedText text, required String description, required Photo photo, Animation? animation})
Describes a game. Use getInternalLink with internalLinkTypeGame to share the game
const
Game.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

animation → Animation?
animation Game animation; may be null
final
clientId → int?
client identifier
no setterinherited
description → String
description Game description
final
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → int
id Unique game identifier
final
photo → Photo
photo Game photo
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shortName → String
shortName Game short name
final
text → FormattedText
text Game text, usually containing scoreboards for a game
final
title → String
title Game title
final

Methods

copyWith({int? id, String? shortName, String? title, FormattedText? text, String? description, Photo? photo, Animation? animation}) → Game
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String