GetAnimatedEmoji class

Inheritance

Constructors

GetAnimatedEmoji({required String emoji})
Returns an animated emoji corresponding to a given emoji. Returns a 404 error if the emoji has no animated emoji
const

Properties

emoji → String
emoji The emoji
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? emoji}) → GetAnimatedEmoji
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String