GetBackgroundUrl class

Inheritance

Constructors

GetBackgroundUrl({required String name, required BackgroundType type})
Constructs a persistent HTTP URL for a background
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
name Background name
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → BackgroundType
type Background type
final

Methods

copyWith({String? name, BackgroundType? type}) → GetBackgroundUrl
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String