GetBankCardInfo class

Inheritance

Constructors

GetBankCardInfo({required String bankCardNumber})
Returns information about a bank card
const

Properties

bankCardNumber → String
bankCardNumber The bank card number
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? bankCardNumber}) → GetBankCardInfo
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String