GetBlockedMessageSenders class

Inheritance

Constructors

GetBlockedMessageSenders({required int offset, required int limit})
Returns users and chats that were blocked by the current user
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
limit → int
limit The maximum number of users and chats to return; up to 100
final
offset → int
offset Number of users and chats to skip in the result; must be non-negative
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? offset, int? limit}) → GetBlockedMessageSenders
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String