GetCallbackQueryAnswer class

Inheritance

Constructors

GetCallbackQueryAnswer({required int chatId, required int messageId, required CallbackQueryPayload payload})
Sends a callback query to a bot and returns an answer. Returns an error with code 502 if the bot fails to answer the query before the query timeout expires
const

Properties

chatId → int
chatId Identifier of the chat with the message
final
hashCode → int
The hash code for this object.
no setterinherited
messageId → int
messageId Identifier of the message from which the query originated
final
payload → CallbackQueryPayload
payload Query payload
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? messageId, CallbackQueryPayload? payload}) → GetCallbackQueryAnswer
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String