GetChatFolderChatsToLeave class

Inheritance

Constructors

GetChatFolderChatsToLeave({required int chatFolderId})
Returns identifiers of pinned or always included chats from a chat folder, which are suggested to be left when the chat folder is deleted
const

Properties

chatFolderId → int
chatFolderId Chat folder identifier
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatFolderId}) → GetChatFolderChatsToLeave
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String