GetChatInviteLinkMembers class

Inheritance

Constructors

GetChatInviteLinkMembers({required int chatId, required String inviteLink, ChatInviteLinkMember? offsetMember, required int limit})
Returns chat members joined a chat via an invite link. Requires administrator privileges and can_invite_users right in the chat for own links and owner privileges for other links
const

Properties

chatId → int
chatId Chat identifier
final
hashCode → int
The hash code for this object.
no setterinherited
inviteLink Invite link for which to return chat members
final
limit → int
limit The maximum number of chat members to return; up to 100
final
offsetMember → ChatInviteLinkMember?
offsetMember A chat member from which to return next chat members; pass null to get results from the beginning
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, String? inviteLink, ChatInviteLinkMember? offsetMember, int? limit}) → GetChatInviteLinkMembers
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String