GetChatMessageCount class

Inheritance

Constructors

GetChatMessageCount({required int chatId, required SearchMessagesFilter filter, required bool returnLocal})
Returns approximate number of messages of the specified type in the chat
const

Properties

chatId → int
chatId Identifier of the chat in which to count messages
final
filter → SearchMessagesFilter
filter Filter for message content; searchMessagesFilterEmpty is unsupported in this function
final
hashCode → int
The hash code for this object.
no setterinherited
returnLocal → bool
returnLocal Pass true to get the number of messages without sending network requests, or -1 if the number of messages is unknown locally
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, SearchMessagesFilter? filter, bool? returnLocal}) → GetChatMessageCount
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String