GetChatMessagePosition class

Inheritance

Constructors

GetChatMessagePosition({required int chatId, required int messageId, required SearchMessagesFilter filter, required int messageThreadId})
Returns approximate 1-based position of a message among messages, which can be found by the specified filter in the chat. Cannot be used in secret chats
const

Properties

chatId → int
chatId Identifier of the chat in which to find message position
final
filter → SearchMessagesFilter
filter Filter for message content; searchMessagesFilterEmpty, searchMessagesFilterUnreadMention, searchMessagesFilterUnreadReaction, and searchMessagesFilterFailedToSend are unsupported in this function
final
hashCode → int
The hash code for this object.
no setterinherited
messageId → int
messageId Message identifier
final
messageThreadId → int
messageThreadId If not 0, only messages in the specified thread will be considered; supergroups only
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? messageId, SearchMessagesFilter? filter, int? messageThreadId}) → GetChatMessagePosition
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String