GetExternalLink class

Inheritance

Constructors

GetExternalLink({required String link, required bool allowWriteAccess})
Returns an HTTP URL which can be used to automatically authorize the current user on a website after clicking an HTTP link. Use the method getExternalLinkInfo to find whether a prior user confirmation is needed
const

Properties

allowWriteAccess → bool
allowWriteAccess Pass true if the current user allowed the bot, returned in getExternalLinkInfo, to send them messages
final
hashCode → int
The hash code for this object.
no setterinherited
link The HTTP link
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? link, bool? allowWriteAccess}) → GetExternalLink
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String