GetFileDownloadedPrefixSize class

Inheritance

Constructors

GetFileDownloadedPrefixSize({required int fileId, required int offset})
Returns file downloaded prefix size from a given offset, in bytes
const

Properties

fileId → int
fileId Identifier of the file
final
hashCode → int
The hash code for this object.
no setterinherited
offset → int
offset Offset from which downloaded prefix size needs to be calculated
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? fileId, int? offset}) → GetFileDownloadedPrefixSize
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String