GetForumTopic class

Inheritance

Constructors

GetForumTopic({required int chatId, required int messageThreadId})
Returns information about a forum topic
const

Properties

chatId → int
chatId Identifier of the chat
final
hashCode → int
The hash code for this object.
no setterinherited
messageThreadId → int
messageThreadId Message thread identifier of the forum topic
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? messageThreadId}) → GetForumTopic
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String