GetGroupCallInviteLink class

Inheritance

Constructors

GetGroupCallInviteLink({required int groupCallId, required bool canSelfUnmute})
Returns invite link to a video chat in a public chat
const

Properties

canSelfUnmute → bool
canSelfUnmute Pass true if the invite link needs to contain an invite hash, passing which to joinGroupCall would allow the invited user to unmute themselves. Requires groupCall.can_be_managed group call flag
final
groupCallId → int
groupCallId Group call identifier
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? groupCallId, bool? canSelfUnmute}) → GetGroupCallInviteLink
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String