GetInstalledStickerSets class

Inheritance

Constructors

GetInstalledStickerSets({required StickerType stickerType})
Returns a list of installed sticker sets
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stickerType → StickerType
stickerType Type of the sticker sets to return
final

Methods

copyWith({StickerType? stickerType}) → GetInstalledStickerSets
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String