GetJsonString class

Inheritance

Constructors

GetJsonString({required JsonValue jsonValue})
Converts a JsonValue object to corresponding JSON-serialized string. Can be called synchronously
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
jsonValue → JsonValue
jsonValue The JsonValue object
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({JsonValue? jsonValue}) → GetJsonString
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String