GetLanguagePackInfo class

Inheritance

Constructors

GetLanguagePackInfo({required String languagePackId})
Returns information about a language pack. Returned language pack identifier may be different from a provided one. Can be called before authorization
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
languagePackId → String
languagePackId Language pack identifier
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? languagePackId}) → GetLanguagePackInfo
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String