GetLanguagePackStrings class

Inheritance

Constructors

GetLanguagePackStrings({required String languagePackId, required List<String> keys})
Returns strings from a language pack in the current localization target by their keys. Can be called before authorization
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
keys → List<String>
keys Language pack keys of the strings to be returned; leave empty to request all available strings
final
languagePackId → String
languagePackId Language pack identifier of the strings to be returned
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? languagePackId, List<String>? keys}) → GetLanguagePackStrings
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String