GetLoginUrlInfo class

Inheritance

Constructors

GetLoginUrlInfo({required int chatId, required int messageId, required int buttonId})
Returns information about a button of type inlineKeyboardButtonTypeLoginUrl. The method needs to be called when the user presses the button
const

Properties

buttonId → int
buttonId Button identifier
final
chatId → int
chatId Chat identifier of the message with the button
final
hashCode → int
The hash code for this object.
no setterinherited
messageId → int
messageId Message identifier of the message with the button
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? messageId, int? buttonId}) → GetLoginUrlInfo
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String