GetMessage class

Inheritance

Constructors

GetMessage({required int chatId, required int messageId})
Returns information about a message
const

Properties

chatId → int
chatId Identifier of the chat the message belongs to
final
hashCode → int
The hash code for this object.
no setterinherited
messageId → int
messageId Identifier of the message to get
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? messageId}) → GetMessage
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String