GetMessageEmbeddingCode class

Inheritance

Constructors

GetMessageEmbeddingCode({required int chatId, required int messageId, required bool forAlbum})
Returns an HTML code for embedding the message. Available only for messages in supergroups and channels with a username
const

Properties

chatId → int
chatId Identifier of the chat to which the message belongs
final
forAlbum → bool
forAlbum Pass true to return an HTML code for embedding of the whole media album
final
hashCode → int
The hash code for this object.
no setterinherited
messageId → int
messageId Identifier of the message
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? messageId, bool? forAlbum}) → GetMessageEmbeddingCode
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String