GetMessageFileType class

Inheritance

Constructors

GetMessageFileType({required String messageFileHead})
Returns information about a file with messages exported from another application
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
messageFileHead → String
messageFileHead Beginning of the message file; up to 100 first lines
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? messageFileHead}) → GetMessageFileType
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String