GetMessageLink class

Inheritance

Constructors

GetMessageLink({required int chatId, required int messageId, required int mediaTimestamp, required bool forAlbum, required bool inMessageThread})
Returns an HTTPS link to a message in a chat. Available only for already sent messages in supergroups and channels, or if message.can_get_media_timestamp_links and a media timestamp link is generated. This is an offline request
const

Properties

chatId → int
chatId Identifier of the chat to which the message belongs
final
forAlbum → bool
forAlbum Pass true to create a link for the whole media album
final
hashCode → int
The hash code for this object.
no setterinherited
inMessageThread → bool
inMessageThread Pass true to create a link to the message as a channel post comment, in a message thread, or a forum topic
final
mediaTimestamp → int
mediaTimestamp If not 0, timestamp from which the video/audio/video note/voice note playing must start, in seconds. The media can be in the message content or in its web page preview
final
messageId → int
messageId Identifier of the message
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? messageId, int? mediaTimestamp, bool? forAlbum, bool? inMessageThread}) → GetMessageLink
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String