GetMessageLinkInfo class

Inheritance

Constructors

GetMessageLinkInfo({required String url})
Returns information about a public or private message link. Can be called for any internal link of the type internalLinkTypeMessage
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → String
url The message link
final

Methods

copyWith({String? url}) → GetMessageLinkInfo
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String