GetNetworkStatistics class

Inheritance

Constructors

GetNetworkStatistics({required bool onlyCurrent})
Returns network data usage statistics. Can be called before authorization
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
onlyCurrent → bool
onlyCurrent Pass true to get statistics only for the current library launch
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? onlyCurrent}) → GetNetworkStatistics
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String