GetPassportAuthorizationForm class

Inheritance

Constructors

GetPassportAuthorizationForm({required int botUserId, required String scope, required String publicKey, required String nonce})
Returns a Telegram Passport authorization form for sharing data with a service
const

Properties

botUserId → int
botUserId User identifier of the service's bot
final
hashCode → int
The hash code for this object.
no setterinherited
nonce → String
nonce Unique request identifier provided by the service
final
publicKey → String
publicKey Service's public key
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope → String
scope Telegram Passport element types requested by the service
final

Methods

copyWith({int? botUserId, String? scope, String? publicKey, String? nonce}) → GetPassportAuthorizationForm
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String