GetPassportElement class

Inheritance

Constructors

GetPassportElement({required PassportElementType type, required String password})
Returns one of the available Telegram Passport elements
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
password → String
password The 2-step verification password of the current user
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → PassportElementType
type Telegram Passport element type
final

Methods

copyWith({PassportElementType? type, String? password}) → GetPassportElement
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String