GetPaymentForm class

Inheritance

Constructors

GetPaymentForm({required InputInvoice inputInvoice, ThemeParameters? theme})
Returns an invoice payment form. This method must be called when the user presses inlineKeyboardButtonBuy
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
inputInvoice → InputInvoice
inputInvoice The invoice
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
theme → ThemeParameters?
theme Preferred payment form theme; pass null to use the default theme
final

Methods

copyWith({InputInvoice? inputInvoice, ThemeParameters? theme}) → GetPaymentForm
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String