GetPremiumFeatures class

Inheritance

Constructors

GetPremiumFeatures({PremiumSource? source})
Returns information about features, available to Premium users
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → PremiumSource?
source Source of the request; pass null if the method is called from some non-standard source
final

Methods

copyWith({PremiumSource? source}) → GetPremiumFeatures
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String