GetRecentStickers class

Inheritance

Constructors

GetRecentStickers({required bool isAttached})
Returns a list of recently used stickers
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
isAttached → bool
isAttached Pass true to return stickers and masks that were recently attached to photos or video files; pass false to return recently sent stickers
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? isAttached}) → GetRecentStickers
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String