GetRecentlyVisitedTMeUrls class

Inheritance

Constructors

GetRecentlyVisitedTMeUrls({required String referrer})
Returns t.me URLs recently visited by a newly registered user
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
referrer → String
referrer Google Play referrer to identify the user
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? referrer}) → GetRecentlyVisitedTMeUrls
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String