GetRecoveryEmailAddress class

Inheritance

Constructors

GetRecoveryEmailAddress({required String password})
Returns a 2-step verification recovery email address that was previously set up. This method can be used to verify a password provided by the user
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
password → String
password The 2-step verification password for the current user
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? password}) → GetRecoveryEmailAddress
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String