GetSavedNotificationSound class

Inheritance

Constructors

GetSavedNotificationSound({required int notificationSoundId})
Returns saved notification sound by its identifier. Returns a 404 error if there is no saved notification sound with the specified identifier
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
notificationSoundId → int
notificationSoundId Identifier of the notification sound
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? notificationSoundId}) → GetSavedNotificationSound
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String