GetStickers class

Inheritance

Constructors

GetStickers({required StickerType stickerType, required String query, required int limit, required int chatId})
Returns stickers from the installed sticker sets that correspond to any of the given emoji or can be found by sticker-specific keywords. If the query is non-empty, then favorite, recently used or trending stickers may also be returned
const

Properties

chatId → int
chatId Chat identifier for which to return stickers. Available custom emoji stickers may be different for different chats
final
hashCode → int
The hash code for this object.
no setterinherited
limit → int
limit The maximum number of stickers to be returned
final
query → String
query Search query; a space-separated list of emoji or a keyword prefix. If empty, returns all known installed stickers
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stickerType → StickerType
stickerType Type of the stickers to return
final

Methods

copyWith({StickerType? stickerType, String? query, int? limit, int? chatId}) → GetStickers
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String