GetSuggestedFileName class

Inheritance

Constructors

GetSuggestedFileName({required int fileId, required String directory})
Returns suggested name for saving a file in a given directory
const

Properties

directory → String
directory Directory in which the file is supposed to be saved
final
fileId → int
fileId Identifier of the file
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? fileId, String? directory}) → GetSuggestedFileName
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String