GetSupergroup class

Inheritance

Constructors

GetSupergroup({required int supergroupId})
Returns information about a supergroup or a channel by its identifier. This is an offline request if the current user is not a bot
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supergroupId → int
supergroupId Supergroup or channel identifier
final

Methods

copyWith({int? supergroupId}) → GetSupergroup
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String