GetSupergroupMembers class

Inheritance

Constructors

GetSupergroupMembers({required int supergroupId, SupergroupMembersFilter? filter, required int offset, required int limit})
Returns information about members or banned users in a supergroup or channel. Can be used only if supergroupFullInfo.can_get_members == true; additionally, administrator privileges may be required for some filters
const

Properties

filter → SupergroupMembersFilter?
filter The type of users to return; pass null to use supergroupMembersFilterRecent
final
hashCode → int
The hash code for this object.
no setterinherited
limit → int
limit The maximum number of users be returned; up to 200
final
offset → int
offset Number of users to skip
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supergroupId → int
supergroupId Identifier of the supergroup or channel
final

Methods

copyWith({int? supergroupId, SupergroupMembersFilter? filter, int? offset, int? limit}) → GetSupergroupMembers
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String