GetTopChats class

Inheritance

Constructors

GetTopChats({required TopChatCategory category, required int limit})
Returns a list of frequently used chats. Supported only if the chat info database is enabled
const

Properties

category → TopChatCategory
category Category of chats to be returned
final
hashCode → int
The hash code for this object.
no setterinherited
limit → int
limit The maximum number of chats to be returned; up to 30
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({TopChatCategory? category, int? limit}) → GetTopChats
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String