GetWebAppLinkUrl class

Inheritance

Constructors

GetWebAppLinkUrl({required int chatId, required int botUserId, required String webAppShortName, required String startParameter, ThemeParameters? theme, required String applicationName, required bool allowWriteAccess})
Returns an HTTPS URL of a Web App to open after a link of the type internalLinkTypeWebApp is clicked
const

Properties

allowWriteAccess → bool
allowWriteAccess Pass true if the current user allowed the bot to send them messages
final
applicationName → String
applicationName Short name of the application; 0-64 English letters, digits, and underscores
final
botUserId → int
botUserId Identifier of the target bot
final
chatId → int
chatId Identifier of the chat in which the link was clicked; pass 0 if none
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startParameter → String
startParameter Start parameter from internalLinkTypeWebApp
final
theme → ThemeParameters?
theme Preferred Web App theme; pass null to use the default theme
final
webAppShortName → String
webAppShortName Short name of the Web App
final

Methods

copyWith({int? chatId, int? botUserId, String? webAppShortName, String? startParameter, ThemeParameters? theme, String? applicationName, bool? allowWriteAccess}) → GetWebAppLinkUrl
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String