GetWebAppUrl class

Inheritance

Constructors

GetWebAppUrl({required int botUserId, required String url, ThemeParameters? theme, required String applicationName})
Returns an HTTPS URL of a Web App to open after keyboardButtonTypeWebApp or inlineQueryResultsButtonTypeWebApp button is pressed
const

Properties

applicationName → String
applicationName Short name of the application; 0-64 English letters, digits, and underscores
final
botUserId → int
botUserId Identifier of the target bot
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
theme → ThemeParameters?
theme Preferred Web App theme; pass null to use the default theme
final
url → String
url The URL from the keyboardButtonTypeWebApp or inlineQueryResultsButtonTypeWebApp button
final

Methods

copyWith({int? botUserId, String? url, ThemeParameters? theme, String? applicationName}) → GetWebAppUrl
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String