GetWebPageInstantView class

Inheritance

Constructors

GetWebPageInstantView({required String url, required bool forceFull})
Returns an instant view version of a web page if available. Returns a 404 error if the web page has no instant view page
const

Properties

forceFull → bool
forceFull Pass true to get full instant view for the web page
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → String
url The web page URL
final

Methods

copyWith({String? url, bool? forceFull}) → GetWebPageInstantView
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String