GroupCallId class

Inheritance

Constructors

GroupCallId({required int id, dynamic extra, int? clientId})
Contains the group call identifier
const
GroupCallId.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
id → int
id Group call identifier
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? id, dynamic extra, int? clientId}) → GroupCallId
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String