GroupCallParticipantVideoInfo class

Inheritance

Constructors

GroupCallParticipantVideoInfo({required List<GroupCallVideoSourceGroup> sourceGroups, required String endpointId, required bool isPaused})
Contains information about a group call participant's video channel
const
GroupCallParticipantVideoInfo.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
endpointId → String
endpointId Video channel endpoint identifier
final
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isPaused → bool
isPaused True, if the video is paused. This flag needs to be ignored, if new video frames are received
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceGroups → List<GroupCallVideoSourceGroup>
sourceGroups List of synchronization source groups of the video
final

Methods

copyWith({List<GroupCallVideoSourceGroup>? sourceGroups, String? endpointId, bool? isPaused}) → GroupCallParticipantVideoInfo
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String