GroupCallRecentSpeaker class

Inheritance

Constructors

GroupCallRecentSpeaker({required MessageSender participantId, required bool isSpeaking})
Describes a recently speaking participant in a group call
const
GroupCallRecentSpeaker.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isSpeaking → bool
isSpeaking True, is the user has spoken recently
final
participantId → MessageSender
participantId Group call participant identifier
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({MessageSender? participantId, bool? isSpeaking}) → GroupCallRecentSpeaker
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String