GroupCallStream class

Inheritance

Constructors

GroupCallStream({required int channelId, required int scale, required int timeOffset})
Describes an available stream in a group call
const
GroupCallStream.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

channelId → int
channelId Identifier of an audio/video channel
final
clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scale → int
scale Scale of segment durations in the stream. The duration is 1000/(2**scale) milliseconds
final
timeOffset → int
timeOffset Point in time when the stream currently ends; Unix timestamp in milliseconds
final

Methods

copyWith({int? channelId, int? scale, int? timeOffset}) → GroupCallStream
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String