ImportMessages class

Inheritance

Constructors

ImportMessages({required int chatId, required InputFile messageFile, required List<InputFile> attachedFiles})
Imports messages exported from another app
const

Properties

attachedFiles → List<InputFile>
attachedFiles Files used in the imported messages. Only inputFileLocal and inputFileGenerated are supported. The files must not be previously uploaded
final
chatId → int
chatId Identifier of a chat to which the messages will be imported. It must be an identifier of a private chat with a mutual contact or an identifier of a supergroup chat with can_change_info administrator right
final
hashCode → int
The hash code for this object.
no setterinherited
messageFile → InputFile
messageFile File with messages to import. Only inputFileLocal and inputFileGenerated are supported. The file must not be previously uploaded
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, InputFile? messageFile, List<InputFile>? attachedFiles}) → ImportMessages
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String