InlineKeyboardButtonTypeSwitchInline class

Inheritance

Constructors

InlineKeyboardButtonTypeSwitchInline({required String query, required TargetChat targetChat})
A button that forces an inline query to the bot to be inserted in the input field
const
InlineKeyboardButtonTypeSwitchInline.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
query → String
query Inline query to be sent to the bot
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetChat → TargetChat
targetChat Target chat from which to send the inline query
final

Methods

copyWith({String? query, TargetChat? targetChat}) → InlineKeyboardButtonTypeSwitchInline
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String