InlineQueryResultAnimation class

Inheritance

Constructors

InlineQueryResultAnimation({required String id, required Animation animation, required String title})
Represents an animation file
const
InlineQueryResultAnimation.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

animation → Animation
animation Animation file
final
clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
id Unique identifier of the query result
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
title Animation title
final

Methods

copyWith({String? id, Animation? animation, String? title}) → InlineQueryResultAnimation
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String