InlineQueryResultArticle class

Inheritance

Constructors

InlineQueryResultArticle({required String id, required String url, required bool hideUrl, required String title, required String description, Thumbnail? thumbnail})
Represents a link to an article or web page
const
InlineQueryResultArticle.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
description → String
description A short description of the result
final
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hideUrl → bool
hideUrl True, if the URL must be not shown
final
id → String
id Unique identifier of the query result
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thumbnail → Thumbnail?
thumbnail Result thumbnail in JPEG format; may be null
final
title → String
title Title of the result
final
url → String
url URL of the result, if it exists
final

Methods

copyWith({String? id, String? url, bool? hideUrl, String? title, String? description, Thumbnail? thumbnail}) → InlineQueryResultArticle
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String