InlineQueryResultPhoto class

Inheritance

Constructors

InlineQueryResultPhoto({required String id, required Photo photo, required String title, required String description})
Represents a photo
const
InlineQueryResultPhoto.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
description → String
description A short description of the result, if known
final
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
id Unique identifier of the query result
final
photo → Photo
photo Photo
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
title Title of the result, if known
final

Methods

copyWith({String? id, Photo? photo, String? title, String? description}) → InlineQueryResultPhoto
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String