InlineQueryResultSticker class

Inheritance

Constructors

InlineQueryResultSticker({required String id, required Sticker sticker})
Represents a sticker
const
InlineQueryResultSticker.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
id Unique identifier of the query result
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sticker → Sticker
sticker Sticker
final

Methods

copyWith({String? id, Sticker? sticker}) → InlineQueryResultSticker
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String