InlineQueryResultVoiceNote class

Inheritance

Constructors

InlineQueryResultVoiceNote({required String id, required VoiceNote voiceNote, required String title})
Represents a voice note
const
InlineQueryResultVoiceNote.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
id Unique identifier of the query result
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
title Title of the voice note
final
voiceNote → VoiceNote
voiceNote Voice note
final

Methods

copyWith({String? id, VoiceNote? voiceNote, String? title}) → InlineQueryResultVoiceNote
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String