InputChatPhotoAnimation class

Inheritance

Constructors

InputChatPhotoAnimation({required InputFile animation, required double mainFrameTimestamp})
An animation in MPEG4 format; must be square, at most 10 seconds long, have width between 160 and 1280 and be at most 2MB in size
const
InputChatPhotoAnimation.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

animation → InputFile
animation Animation to be set as profile photo. Only inputFileLocal and inputFileGenerated are allowed
final
clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
mainFrameTimestamp → double
mainFrameTimestamp Timestamp of the frame, which will be used as static chat photo
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({InputFile? animation, double? mainFrameTimestamp}) → InputChatPhotoAnimation
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String