InputIdentityDocument class

Inheritance

Constructors

InputIdentityDocument({required String number, Date? expirationDate, required InputFile frontSide, InputFile? reverseSide, InputFile? selfie, required List<InputFile> translation})
An identity document to be saved to Telegram Passport
const
InputIdentityDocument.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
expirationDate → Date?
expirationDate Document expiration date; pass null if not applicable
final
extra → dynamic
callback sign
no setterinherited
frontSide → InputFile
frontSide Front side of the document
final
hashCode → int
The hash code for this object.
no setterinherited
number → String
number Document number; 1-24 characters
final
reverseSide → InputFile?
reverseSide Reverse side of the document; only for driver license and identity card; pass null otherwise
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selfie → InputFile?
selfie Selfie with the document; pass null if unavailable
final
translation → List<InputFile>
translation List of files containing a certified English translation of the document
final

Methods

copyWith({String? number, Date? expirationDate, InputFile? frontSide, InputFile? reverseSide, InputFile? selfie, List<InputFile>? translation}) → InputIdentityDocument
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String