InputInlineQueryResultAudio class

Inheritance

Constructors

InputInlineQueryResultAudio({required String id, required String title, required String performer, required String audioUrl, required int audioDuration, ReplyMarkup? replyMarkup, required InputMessageContent inputMessageContent})
Represents a link to an MP3 audio file
const
InputInlineQueryResultAudio.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

audioDuration → int
audioDuration Audio file duration, in seconds
final
audioUrl → String
audioUrl The URL of the audio file
final
clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
id Unique identifier of the query result
final
inputMessageContent → InputMessageContent
inputMessageContent The content of the message to be sent. Must be one of the following types: inputMessageText, inputMessageAudio, inputMessageInvoice, inputMessageLocation, inputMessageVenue or inputMessageContact
final
performer → String
performer Performer of the audio file
final
replyMarkup → ReplyMarkup?
replyMarkup The message reply markup; pass null if none. Must be of type replyMarkupInlineKeyboard or null
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
title Title of the audio file
final

Methods

copyWith({String? id, String? title, String? performer, String? audioUrl, int? audioDuration, ReplyMarkup? replyMarkup, InputMessageContent? inputMessageContent}) → InputInlineQueryResultAudio
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String