InputInlineQueryResultDocument class

Inheritance

Constructors

InputInlineQueryResultDocument({required String id, required String title, required String description, required String documentUrl, required String mimeType, required String thumbnailUrl, required int thumbnailWidth, required int thumbnailHeight, ReplyMarkup? replyMarkup, required InputMessageContent inputMessageContent})
Represents a link to a file
const
InputInlineQueryResultDocument.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
description → String
description Short description of the result, if known
final
documentUrl → String
documentUrl URL of the file
final
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
id Unique identifier of the query result
final
inputMessageContent → InputMessageContent
inputMessageContent The content of the message to be sent. Must be one of the following types: inputMessageText, inputMessageDocument, inputMessageInvoice, inputMessageLocation, inputMessageVenue or inputMessageContact
final
mimeType → String
mimeType MIME type of the file content; only "application/pdf" and "application/zip" are currently allowed
final
replyMarkup → ReplyMarkup?
replyMarkup The message reply markup; pass null if none. Must be of type replyMarkupInlineKeyboard or null
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thumbnailHeight → int
thumbnailHeight Height of the thumbnail
final
thumbnailUrl → String
thumbnailUrl The URL of the file thumbnail, if it exists
final
thumbnailWidth → int
thumbnailWidth Width of the thumbnail
final
title → String
title Title of the resulting file
final

Methods

copyWith({String? id, String? title, String? description, String? documentUrl, String? mimeType, String? thumbnailUrl, int? thumbnailWidth, int? thumbnailHeight, ReplyMarkup? replyMarkup, InputMessageContent? inputMessageContent}) → InputInlineQueryResultDocument
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String