InputInlineQueryResultGame class

Inheritance

Constructors

InputInlineQueryResultGame({required String id, required String gameShortName, ReplyMarkup? replyMarkup})
Represents a game
const
InputInlineQueryResultGame.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
gameShortName → String
gameShortName Short name of the game
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
id Unique identifier of the query result
final
replyMarkup → ReplyMarkup?
replyMarkup The message reply markup; pass null if none. Must be of type replyMarkupInlineKeyboard or null
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? id, String? gameShortName, ReplyMarkup? replyMarkup}) → InputInlineQueryResultGame
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String