InputInlineQueryResultLocation class

Inheritance

Constructors

InputInlineQueryResultLocation({required String id, required Location location, required int livePeriod, required String title, required String thumbnailUrl, required int thumbnailWidth, required int thumbnailHeight, ReplyMarkup? replyMarkup, required InputMessageContent inputMessageContent})
Represents a point on the map
const
InputInlineQueryResultLocation.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
id Unique identifier of the query result
final
inputMessageContent → InputMessageContent
inputMessageContent The content of the message to be sent. Must be one of the following types: inputMessageText, inputMessageInvoice, inputMessageLocation, inputMessageVenue or inputMessageContact
final
livePeriod → int
livePeriod Amount of time relative to the message sent time until the location can be updated, in seconds
final
location → Location
location Location result
final
replyMarkup → ReplyMarkup?
replyMarkup The message reply markup; pass null if none. Must be of type replyMarkupInlineKeyboard or null
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thumbnailHeight → int
thumbnailHeight Thumbnail height, if known
final
thumbnailUrl → String
thumbnailUrl URL of the result thumbnail, if it exists
final
thumbnailWidth → int
thumbnailWidth Thumbnail width, if known
final
title → String
title Title of the result
final

Methods

copyWith({String? id, Location? location, int? livePeriod, String? title, String? thumbnailUrl, int? thumbnailWidth, int? thumbnailHeight, ReplyMarkup? replyMarkup, InputMessageContent? inputMessageContent}) → InputInlineQueryResultLocation
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String