InputInlineQueryResultPhoto class

Inheritance

Constructors

InputInlineQueryResultPhoto({required String id, required String title, required String description, required String thumbnailUrl, required String photoUrl, required int photoWidth, required int photoHeight, ReplyMarkup? replyMarkup, required InputMessageContent inputMessageContent})
Represents link to a JPEG image
const
InputInlineQueryResultPhoto.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
description → String
description A short description of the result, if known
final
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
id Unique identifier of the query result
final
inputMessageContent → InputMessageContent
inputMessageContent The content of the message to be sent. Must be one of the following types: inputMessageText, inputMessagePhoto, inputMessageInvoice, inputMessageLocation, inputMessageVenue or inputMessageContact
final
photoHeight → int
photoHeight Height of the photo
final
photoUrl → String
photoUrl The URL of the JPEG photo (photo size must not exceed 5MB)
final
photoWidth → int
photoWidth Width of the photo
final
replyMarkup → ReplyMarkup?
replyMarkup The message reply markup; pass null if none. Must be of type replyMarkupInlineKeyboard or null
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thumbnailUrl → String
thumbnailUrl URL of the photo thumbnail, if it exists
final
title → String
title Title of the result, if known
final

Methods

copyWith({String? id, String? title, String? description, String? thumbnailUrl, String? photoUrl, int? photoWidth, int? photoHeight, ReplyMarkup? replyMarkup, InputMessageContent? inputMessageContent}) → InputInlineQueryResultPhoto
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String