InputInlineQueryResultSticker class

Inheritance

Constructors

InputInlineQueryResultSticker({required String id, required String thumbnailUrl, required String stickerUrl, required int stickerWidth, required int stickerHeight, ReplyMarkup? replyMarkup, required InputMessageContent inputMessageContent})
Represents a link to a WEBP, TGS, or WEBM sticker
const
InputInlineQueryResultSticker.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
id Unique identifier of the query result
final
inputMessageContent → InputMessageContent
inputMessageContent The content of the message to be sent. Must be one of the following types: inputMessageText, inputMessageSticker, inputMessageInvoice, inputMessageLocation, inputMessageVenue or inputMessageContact
final
replyMarkup → ReplyMarkup?
replyMarkup The message reply markup; pass null if none. Must be of type replyMarkupInlineKeyboard or null
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stickerHeight → int
stickerHeight Height of the sticker
final
stickerUrl → String
stickerUrl The URL of the WEBP, TGS, or WEBM sticker (sticker file size must not exceed 5MB)
final
stickerWidth → int
stickerWidth Width of the sticker
final
thumbnailUrl → String
thumbnailUrl URL of the sticker thumbnail, if it exists
final

Methods

copyWith({String? id, String? thumbnailUrl, String? stickerUrl, int? stickerWidth, int? stickerHeight, ReplyMarkup? replyMarkup, InputMessageContent? inputMessageContent}) → InputInlineQueryResultSticker
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String