InputInlineQueryResultVoiceNote class

Inheritance

Constructors

InputInlineQueryResultVoiceNote({required String id, required String title, required String voiceNoteUrl, required int voiceNoteDuration, ReplyMarkup? replyMarkup, required InputMessageContent inputMessageContent})
Represents a link to an opus-encoded audio file within an OGG container, single channel audio
const
InputInlineQueryResultVoiceNote.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
id Unique identifier of the query result
final
inputMessageContent → InputMessageContent
inputMessageContent The content of the message to be sent. Must be one of the following types: inputMessageText, inputMessageVoiceNote, inputMessageInvoice, inputMessageLocation, inputMessageVenue or inputMessageContact
final
replyMarkup → ReplyMarkup?
replyMarkup The message reply markup; pass null if none. Must be of type replyMarkupInlineKeyboard or null
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
title Title of the voice note
final
voiceNoteDuration → int
voiceNoteDuration Duration of the voice note, in seconds
final
voiceNoteUrl → String
voiceNoteUrl The URL of the voice note file
final

Methods

copyWith({String? id, String? title, String? voiceNoteUrl, int? voiceNoteDuration, ReplyMarkup? replyMarkup, InputMessageContent? inputMessageContent}) → InputInlineQueryResultVoiceNote
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String