InputInvoiceMessage class

Inheritance

Constructors

InputInvoiceMessage({required int chatId, required int messageId})
An invoice from a message of the type messageInvoice
const
InputInvoiceMessage.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

chatId → int
chatId Chat identifier of the message
final
clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
messageId → int
messageId Message identifier
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? messageId}) → InputInvoiceMessage
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String