InputMessageAudio class

Inheritance

Constructors

InputMessageAudio({required InputFile audio, InputThumbnail? albumCoverThumbnail, required int duration, required String title, required String performer, FormattedText? caption})
An audio message
const
InputMessageAudio.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

albumCoverThumbnail → InputThumbnail?
albumCoverThumbnail Thumbnail of the cover for the album; pass null to skip thumbnail uploading
final
audio → InputFile
audio Audio file to be sent
final
caption → FormattedText?
caption Audio caption; pass null to use an empty caption; 0-getOption("message_caption_length_max") characters
final
clientId → int?
client identifier
no setterinherited
duration → int
duration Duration of the audio, in seconds; may be replaced by the server
final
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
performer → String
performer Performer of the audio; 0-64 characters, may be replaced by the server
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
title Title of the audio; 0-64 characters; may be replaced by the server
final

Methods

copyWith({InputFile? audio, InputThumbnail? albumCoverThumbnail, int? duration, String? title, String? performer, FormattedText? caption}) → InputMessageAudio
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String