InputMessageDice class

Inheritance

Constructors

InputMessageDice({required String emoji, required bool clearDraft})
A dice message
const
InputMessageDice.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clearDraft → bool
clearDraft True, if the chat message draft must be deleted
final
clientId → int?
client identifier
no setterinherited
emoji → String
emoji Emoji on which the dice throw animation is based
final
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? emoji, bool? clearDraft}) → InputMessageDice
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String