InputMessageDocument class

Inheritance

Constructors

InputMessageDocument({required InputFile document, InputThumbnail? thumbnail, required bool disableContentTypeDetection, FormattedText? caption})
A document message (general file)
const
InputMessageDocument.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

caption → FormattedText?
caption Document caption; pass null to use an empty caption; 0-getOption("message_caption_length_max") characters
final
clientId → int?
client identifier
no setterinherited
disableContentTypeDetection → bool
disableContentTypeDetection If true, automatic file type detection will be disabled and the document will always be sent as file. Always true for files sent to secret chats
final
document → InputFile
document Document to be sent
final
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thumbnail → InputThumbnail?
thumbnail Document thumbnail; pass null to skip thumbnail uploading
final

Methods

copyWith({InputFile? document, InputThumbnail? thumbnail, bool? disableContentTypeDetection, FormattedText? caption}) → InputMessageDocument
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String