InputMessageForwarded class

Inheritance

Constructors

InputMessageForwarded({required int fromChatId, required int messageId, required bool inGameShare, MessageCopyOptions? copyOptions})
A forwarded message
const
InputMessageForwarded.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
copyOptions → MessageCopyOptions?
copyOptions Options to be used to copy content of the message without reference to the original sender; pass null to forward the message as usual
final
extra → dynamic
callback sign
no setterinherited
fromChatId → int
fromChatId Identifier for the chat this forwarded message came from
final
hashCode → int
The hash code for this object.
no setterinherited
inGameShare → bool
inGameShare True, if a game message is being shared from a launched game; applies only to game messages
final
messageId → int
messageId Identifier of the message to forward
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? fromChatId, int? messageId, bool? inGameShare, MessageCopyOptions? copyOptions}) → InputMessageForwarded
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String