InputMessageLocation class

Inheritance

Constructors

InputMessageLocation({required Location location, required int livePeriod, required int heading, required int proximityAlertRadius})
A message with a location
const
InputMessageLocation.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
heading → int
heading For live locations, a direction in which the location moves, in degrees; 1-360. Pass 0 if unknown
final
livePeriod → int
livePeriod Period for which the location can be updated, in seconds; must be between 60 and 86400 for a live location and 0 otherwise
final
location → Location
location Location to be sent
final
proximityAlertRadius → int
proximityAlertRadius For live locations, a maximum distance to another chat member for proximity alerts, in meters (0-100000). Pass 0 if the notification is disabled. Can't be enabled in channels and Saved Messages
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Location? location, int? livePeriod, int? heading, int? proximityAlertRadius}) → InputMessageLocation
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String