InputMessagePoll class

Inheritance

Constructors

InputMessagePoll({required String question, required List<String> options, required bool isAnonymous, required PollType type, required int openPeriod, required int closeDate, required bool isClosed})
A message with a poll. Polls can't be sent to secret chats. Polls can be sent only to a private chat with a bot
const
InputMessagePoll.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
closeDate → int
closeDate Point in time (Unix timestamp) when the poll will automatically be closed; for bots only
final
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isAnonymous → bool
isAnonymous True, if the poll voters are anonymous. Non-anonymous polls can't be sent or forwarded to channels
final
isClosed → bool
isClosed True, if the poll needs to be sent already closed; for bots only
final
openPeriod → int
openPeriod Amount of time the poll will be active after creation, in seconds; for bots only
final
options → List<String>
options List of poll answer options, 2-10 strings 1-100 characters each
final
question → String
question Poll question; 1-255 characters (up to 300 characters for bots)
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → PollType
type Type of the poll
final

Methods

copyWith({String? question, List<String>? options, bool? isAnonymous, PollType? type, int? openPeriod, int? closeDate, bool? isClosed}) → InputMessagePoll
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String