InputMessageSticker class

Inheritance

Constructors

InputMessageSticker({required InputFile sticker, InputThumbnail? thumbnail, required int width, required int height, required String emoji})
A sticker message
const
InputMessageSticker.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
emoji → String
emoji Emoji used to choose the sticker
final
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
height → int
height Sticker height
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sticker → InputFile
sticker Sticker to be sent
final
thumbnail → InputThumbnail?
thumbnail Sticker thumbnail; pass null to skip thumbnail uploading
final
width → int
width Sticker width
final

Methods

copyWith({InputFile? sticker, InputThumbnail? thumbnail, int? width, int? height, String? emoji}) → InputMessageSticker
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String