InputMessageText class

Inheritance

Constructors

InputMessageText({required FormattedText text, required bool disableWebPagePreview, required bool clearDraft})
A text message
const
InputMessageText.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clearDraft → bool
clearDraft True, if a chat message draft must be deleted
final
clientId → int?
client identifier
no setterinherited
disableWebPagePreview → bool
disableWebPagePreview True, if rich web page previews for URLs in the message text must be disabled
final
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → FormattedText
text Formatted text to be sent; 1-getOption("message_text_length_max") characters. Only Bold, Italic, Underline, Strikethrough, Spoiler, CustomEmoji, Code, Pre, PreCode, TextUrl and MentionName entities are allowed to be specified manually
final

Methods

copyWith({FormattedText? text, bool? disableWebPagePreview, bool? clearDraft}) → InputMessageText
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String