InputMessageVideoNote class

Inheritance

Constructors

InputMessageVideoNote({required InputFile videoNote, InputThumbnail? thumbnail, required int duration, required int length})
A video note message
const
InputMessageVideoNote.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
duration → int
duration Duration of the video, in seconds
final
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
length → int
length Video width and height; must be positive and not greater than 640
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thumbnail → InputThumbnail?
thumbnail Video thumbnail; pass null to skip thumbnail uploading
final
videoNote → InputFile
videoNote Video note to be sent
final

Methods

copyWith({InputFile? videoNote, InputThumbnail? thumbnail, int? duration, int? length}) → InputMessageVideoNote
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String