InputMessageVoiceNote class

Inheritance

Constructors

InputMessageVoiceNote({required InputFile voiceNote, required int duration, required String waveform, FormattedText? caption})
A voice note message
const
InputMessageVoiceNote.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

caption → FormattedText?
caption Voice note caption; pass null to use an empty caption; 0-getOption("message_caption_length_max") characters
final
clientId → int?
client identifier
no setterinherited
duration → int
duration Duration of the voice note, in seconds
final
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
voiceNote → InputFile
voiceNote Voice note to be sent
final
waveform → String
waveform Waveform representation of the voice note in 5-bit format
final

Methods

copyWith({InputFile? voiceNote, int? duration, String? waveform, FormattedText? caption}) → InputMessageVoiceNote
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String