InputPassportElementEmailAddress class

Inheritance

Constructors

InputPassportElementEmailAddress({required String emailAddress})
A Telegram Passport element to be saved containing the user's email address
const
InputPassportElementEmailAddress.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
emailAddress → String
emailAddress The email address to be saved
final
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? emailAddress}) → InputPassportElementEmailAddress
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String