InputPassportElementError class

Inheritance

Constructors

InputPassportElementError({required PassportElementType type, required String message, required InputPassportElementErrorSource source})
Contains the description of an error in a Telegram Passport element; for bots only
const
InputPassportElementError.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
message → String
message Error message
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → InputPassportElementErrorSource
source Error source
final
type → PassportElementType
type Type of Telegram Passport element that has the error
final

Methods

copyWith({PassportElementType? type, String? message, InputPassportElementErrorSource? source}) → InputPassportElementError
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String