InputPassportElementErrorSourceTranslationFile class

Inheritance

Constructors

InputPassportElementErrorSourceTranslationFile({required String fileHash})
One of the files containing the translation of the document contains an error. The error is considered resolved when the file with the translation changes
const
InputPassportElementErrorSourceTranslationFile.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
fileHash → String
fileHash Current hash of the file containing the translation
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? fileHash}) → InputPassportElementErrorSourceTranslationFile
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String