InputStoryContentPhoto class

Inheritance

Constructors

InputStoryContentPhoto({required InputFile photo, required List<int> addedStickerFileIds})
A photo story
const
InputStoryContentPhoto.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

addedStickerFileIds → List<int>
addedStickerFileIds File identifiers of the stickers added to the photo, if applicable
final
clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
photo → InputFile
photo Photo to send. The photo must be at most 10 MB in size. The photo size must be 1080x1920
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({InputFile? photo, List<int>? addedStickerFileIds}) → InputStoryContentPhoto
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String