InternalLinkTypeBotStart class

Inheritance

Constructors

InternalLinkTypeBotStart({required String botUsername, required String startParameter, required bool autostart, dynamic extra, int? clientId})
The link is a link to a chat with a Telegram bot. Call searchPublicChat with the given bot username, check that the user is a bot, show START button in the chat with the bot,. and then call sendBotStartMessage with the given start parameter after the button is pressed
const
InternalLinkTypeBotStart.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

autostart → bool
autostart True, if sendBotStartMessage must be called automatically without showing the START button
final
botUsername → String
botUsername Username of the bot
final
clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startParameter → String
startParameter The parameter to be passed to sendBotStartMessage
final

Methods

copyWith({String? botUsername, String? startParameter, bool? autostart, dynamic extra, int? clientId}) → InternalLinkTypeBotStart
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String