InternalLinkTypeInstantView class

Inheritance

Constructors

InternalLinkTypeInstantView({required String url, required String fallbackUrl, dynamic extra, int? clientId})
The link must be opened in an Instant View. Call getWebPageInstantView with the given URL to process the link
const
InternalLinkTypeInstantView.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
fallbackUrl → String
fallbackUrl An URL to open if getWebPageInstantView fails
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → String
url URL to be passed to getWebPageInstantView
final

Methods

copyWith({String? url, String? fallbackUrl, dynamic extra, int? clientId}) → InternalLinkTypeInstantView
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String