InternalLinkTypeInvoice class

Inheritance

Constructors

InternalLinkTypeInvoice({required String invoiceName, dynamic extra, int? clientId})
The link is a link to an invoice. Call getPaymentForm with the given invoice name to process the link
const
InternalLinkTypeInvoice.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
invoiceName → String
invoiceName Name of the invoice
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? invoiceName, dynamic extra, int? clientId}) → InternalLinkTypeInvoice
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String