InternalLinkTypePassportDataRequest class

Inheritance

Constructors

InternalLinkTypePassportDataRequest({required int botUserId, required String scope, required String publicKey, required String nonce, required String callbackUrl, dynamic extra, int? clientId})
The link contains a request of Telegram passport data. Call getPassportAuthorizationForm with the given parameters to process the link if the link was received from outside of the application; otherwise, ignore it
const
InternalLinkTypePassportDataRequest.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

botUserId → int
botUserId User identifier of the service's bot
final
callbackUrl → String
callbackUrl An HTTP URL to open once the request is finished, canceled, or failed with the parameters tg_passport=success, tg_passport=cancel, or tg_passport=error&error=... respectively.. If empty, then onActivityResult method must be used to return response on Android, or the link tgbot{bot_user_id}://passport/success or tgbot{bot_user_id}://passport/cancel must be opened otherwise
final
clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
nonce → String
nonce Unique request identifier provided by the service
final
publicKey → String
publicKey Service's public key
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope → String
scope Telegram Passport element types requested by the service
final

Methods

copyWith({int? botUserId, String? scope, String? publicKey, String? nonce, String? callbackUrl, dynamic extra, int? clientId}) → InternalLinkTypePassportDataRequest
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String