InternalLinkTypePhoneNumberConfirmation class

Inheritance

Constructors

InternalLinkTypePhoneNumberConfirmation({required String hash, required String phoneNumber, dynamic extra, int? clientId})
The link can be used to confirm ownership of a phone number to prevent account deletion. Call sendPhoneNumberConfirmationCode with the given hash and phone number to process the link
const
InternalLinkTypePhoneNumberConfirmation.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hash → String
hash Hash value from the link
final
hashCode → int
The hash code for this object.
no setterinherited
phoneNumber → String
phoneNumber Phone number value from the link
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? hash, String? phoneNumber, dynamic extra, int? clientId}) → InternalLinkTypePhoneNumberConfirmation
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String