InternalLinkTypeStickerSet class

Inheritance

Constructors

InternalLinkTypeStickerSet({required String stickerSetName, required bool expectCustomEmoji, dynamic extra, int? clientId})
The link is a link to a sticker set. Call searchStickerSet with the given sticker set name to process the link and show the sticker set
const
InternalLinkTypeStickerSet.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
expectCustomEmoji → bool
expectCustomEmoji True, if the sticker set is expected to contain custom emoji
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stickerSetName → String
stickerSetName Name of the sticker set
final

Methods

copyWith({String? stickerSetName, bool? expectCustomEmoji, dynamic extra, int? clientId}) → InternalLinkTypeStickerSet
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String