InternalLinkTypeUserToken class

Inheritance

Constructors

InternalLinkTypeUserToken({required String token, dynamic extra, int? clientId})
The link is a link to a user by a temporary token. Call searchUserByToken with the given token to process the link
const
InternalLinkTypeUserToken.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
token → String
token The token
final

Methods

copyWith({String? token, dynamic extra, int? clientId}) → InternalLinkTypeUserToken
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String