InternalLinkTypeVideoChat class

Inheritance

Constructors

InternalLinkTypeVideoChat({required String chatUsername, required String inviteHash, required bool isLiveStream, dynamic extra, int? clientId})
The link is a link to a video chat. Call searchPublicChat with the given chat username, and then joinGroupCall with the given invite hash to process the link
const
InternalLinkTypeVideoChat.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

chatUsername → String
chatUsername Username of the chat with the video chat
final
clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
inviteHash → String
inviteHash If non-empty, invite hash to be used to join the video chat without being muted by administrators
final
isLiveStream → bool
isLiveStream True, if the video chat is expected to be a live stream in a channel or a broadcast group
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? chatUsername, String? inviteHash, bool? isLiveStream, dynamic extra, int? clientId}) → InternalLinkTypeVideoChat
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String