InternalLinkTypeWebApp class

Inheritance

Constructors

InternalLinkTypeWebApp({required String botUsername, required String webAppShortName, required String startParameter, dynamic extra, int? clientId})
The link is a link to a Web App. Call searchPublicChat with the given bot username, check that the user is a bot, then call searchWebApp with the received bot and the given web_app_short_name.. Process received foundWebApp by showing a confirmation dialog if needed, then calling getWebAppLinkUrl and opening the returned URL
const
InternalLinkTypeWebApp.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

botUsername → String
botUsername Username of the bot that owns the Web App
final
clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startParameter → String
startParameter Start parameter to be passed to getWebAppLinkUrl
final
webAppShortName → String
webAppShortName Short name of the Web App
final

Methods

copyWith({String? botUsername, String? webAppShortName, String? startParameter, dynamic extra, int? clientId}) → InternalLinkTypeWebApp
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String