JoinGroupCall class

Inheritance

Constructors

JoinGroupCall({required int groupCallId, MessageSender? participantId, required int audioSourceId, required String payload, required bool isMuted, required bool isMyVideoEnabled, required String inviteHash})
Joins an active group call. Returns join response payload for tgcalls
const

Properties

audioSourceId → int
audioSourceId Caller audio channel synchronization source identifier; received from tgcalls
final
groupCallId → int
groupCallId Group call identifier
final
hashCode → int
The hash code for this object.
no setterinherited
inviteHash → String
inviteHash If non-empty, invite hash to be used to join the group call without being muted by administrators
final
isMuted → bool
isMuted Pass true to join the call with muted microphone
final
isMyVideoEnabled → bool
isMyVideoEnabled Pass true if the user's video is enabled
final
participantId → MessageSender?
participantId Identifier of a group call participant, which will be used to join the call; pass null to join as self; video chats only
final
payload → String
payload Group call join payload; received from tgcalls
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? groupCallId, MessageSender? participantId, int? audioSourceId, String? payload, bool? isMuted, bool? isMyVideoEnabled, String? inviteHash}) → JoinGroupCall
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String