JsonValueObject class

Inheritance

Constructors

JsonValueObject({required List<JsonObjectMember> members, dynamic extra, int? clientId})
Represents a JSON object
const
JsonValueObject.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
members → List<JsonObjectMember>
members The list of object members
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<JsonObjectMember>? members, dynamic extra, int? clientId}) → JsonValueObject
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String