KeyboardButtonTypeRequestPoll class

Inheritance

Constructors

KeyboardButtonTypeRequestPoll({required bool forceRegular, required bool forceQuiz})
A button that allows the user to create and send a poll when pressed; available only in private chats
const
KeyboardButtonTypeRequestPoll.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
forceQuiz → bool
forceQuiz If true, only polls in quiz mode must be allowed to create
final
forceRegular → bool
forceRegular If true, only regular polls must be allowed to create
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? forceRegular, bool? forceQuiz}) → KeyboardButtonTypeRequestPoll
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String