KeyboardButtonTypeRequestUser class

Inheritance

Constructors

KeyboardButtonTypeRequestUser({required int id, required bool restrictUserIsBot, required bool userIsBot, required bool restrictUserIsPremium, required bool userIsPremium})
A button that requests a user to be shared by the current user; available only in private chats. Use the method shareUserWithBot to complete the request
const
KeyboardButtonTypeRequestUser.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → int
id Unique button identifier
final
restrictUserIsBot → bool
restrictUserIsBot True, if the shared user must or must not be a bot
final
restrictUserIsPremium → bool
restrictUserIsPremium True, if the shared user must or must not be a Telegram Premium user
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userIsBot → bool
userIsBot True, if the shared user must be a bot; otherwise, the shared user must no be a bot. Ignored if restrict_user_is_bot is false
final
userIsPremium → bool
userIsPremium True, if the shared user must be a Telegram Premium user; otherwise, the shared user must no be a Telegram Premium user. Ignored if restrict_user_is_premium is false
final

Methods

copyWith({int? id, bool? restrictUserIsBot, bool? userIsBot, bool? restrictUserIsPremium, bool? userIsPremium}) → KeyboardButtonTypeRequestUser
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String