KeyboardButtonTypeWebApp class

Inheritance

Constructors

KeyboardButtonTypeWebApp({required String url})
A button that opens a Web App by calling getWebAppUrl
const
KeyboardButtonTypeWebApp.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → String
url An HTTP URL to pass to getWebAppUrl
final

Methods

copyWith({String? url}) → KeyboardButtonTypeWebApp
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String