LabeledPricePart class

Inheritance

Constructors

LabeledPricePart({required String label, required int amount})
Portion of the price of a product (e.g., "delivery cost", "tax amount")
const
LabeledPricePart.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

amount → int
amount Currency amount in the smallest units of the currency
final
clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
label → String
label Label for this portion of the product price
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? label, int? amount}) → LabeledPricePart
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String