LanguagePackStringValuePluralized class

Inheritance

Constructors

LanguagePackStringValuePluralized({required String zeroValue, required String oneValue, required String twoValue, required String fewValue, required String manyValue, required String otherValue, dynamic extra, int? clientId})
A language pack string which has different forms based on the number of some object it mentions. See https://www.unicode.org/cldr/charts/latest/supplemental/language_plural_rules.html for more information
const
LanguagePackStringValuePluralized.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
fewValue → String
fewValue Value for few objects
final
hashCode → int
The hash code for this object.
no setterinherited
manyValue → String
manyValue Value for many objects
final
oneValue → String
oneValue Value for one object
final
otherValue → String
otherValue Default value
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
twoValue → String
twoValue Value for two objects
final
zeroValue → String
zeroValue Value for zero objects
final

Methods

copyWith({String? zeroValue, String? oneValue, String? twoValue, String? fewValue, String? manyValue, String? otherValue, dynamic extra, int? clientId}) → LanguagePackStringValuePluralized
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String