LoadGroupCallParticipants class

Inheritance

Constructors

LoadGroupCallParticipants({required int groupCallId, required int limit})
Loads more participants of a group call. The loaded participants will be received through updates. Use the field groupCall.loaded_all_participants to check whether all participants have already been loaded
const

Properties

groupCallId → int
groupCallId Group call identifier. The group call must be previously received through getGroupCall and must be joined or being joined
final
hashCode → int
The hash code for this object.
no setterinherited
limit → int
limit The maximum number of participants to load; up to 100
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? groupCallId, int? limit}) → LoadGroupCallParticipants
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String