LocalizationTargetInfo class

Inheritance

Constructors

LocalizationTargetInfo({required List<LanguagePackInfo> languagePacks, dynamic extra, int? clientId})
Contains information about the current localization target
const
LocalizationTargetInfo.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
languagePacks → List<LanguagePackInfo>
languagePacks List of available language packs for this application
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<LanguagePackInfo>? languagePacks, dynamic extra, int? clientId}) → LocalizationTargetInfo
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String