LogStreamFile class

Inheritance

Constructors

LogStreamFile({required String path, required int maxFileSize, required bool redirectStderr, dynamic extra, int? clientId})
The log is written to a file
const
LogStreamFile.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
maxFileSize → int
maxFileSize The maximum size of the file to where the internal TDLib log is written before the file will automatically be rotated, in bytes
final
path → String
path Path to the file to where the internal TDLib log will be written
final
redirectStderr → bool
redirectStderr Pass true to additionally redirect stderr to the log file. Ignored on Windows
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? path, int? maxFileSize, bool? redirectStderr, dynamic extra, int? clientId}) → LogStreamFile
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String