LogTags class

Inheritance

Constructors

LogTags({required List<String> tags, dynamic extra, int? clientId})
Contains a list of available TDLib internal log tags
const
LogTags.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags → List<String>
tags List of log tags
final

Methods

copyWith({List<String>? tags, dynamic extra, int? clientId}) → LogTags
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String