LoginUrlInfoRequestConfirmation class

Inheritance

Constructors

LoginUrlInfoRequestConfirmation({required String url, required String domain, required int botUserId, required bool requestWriteAccess, dynamic extra, int? clientId})
An authorization confirmation dialog needs to be shown to the user
const
LoginUrlInfoRequestConfirmation.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

botUserId → int
botUserId User identifier of a bot linked with the website
final
clientId → int?
clientId client identifier
final
domain → String
domain A domain of the URL
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
requestWriteAccess → bool
requestWriteAccess True, if the user must be asked for the permission to the bot to send them messages
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → String
url An HTTP URL to be opened
final

Methods

copyWith({String? url, String? domain, int? botUserId, bool? requestWriteAccess, dynamic extra, int? clientId}) → LoginUrlInfoRequestConfirmation
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String