MessageAnimatedEmoji class

Inheritance

Constructors

MessageAnimatedEmoji({required AnimatedEmoji animatedEmoji, required String emoji})
A message with an animated emoji
const
MessageAnimatedEmoji.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

animatedEmoji → AnimatedEmoji
animatedEmoji The animated emoji
final
clientId → int?
client identifier
no setterinherited
emoji → String
emoji The corresponding emoji
final
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({AnimatedEmoji? animatedEmoji, String? emoji}) → MessageAnimatedEmoji
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String