MessageAnimation class

Inheritance

Constructors

MessageAnimation({required Animation animation, required FormattedText caption, required bool hasSpoiler, required bool isSecret})
An animation message (GIF-style).
const
MessageAnimation.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

animation → Animation
animation The animation description
final
caption → FormattedText
caption Animation caption
final
clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hasSpoiler → bool
hasSpoiler True, if the animation preview must be covered by a spoiler animation
final
isSecret → bool
isSecret True, if the animation thumbnail must be blurred and the animation must be shown only while tapped
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Animation? animation, FormattedText? caption, bool? hasSpoiler, bool? isSecret}) → MessageAnimation
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String