MessageBasicGroupChatCreate class

Inheritance

Constructors

MessageBasicGroupChatCreate({required String title, required List<int> memberUserIds})
A newly created basic group
const
MessageBasicGroupChatCreate.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
memberUserIds → List<int>
memberUserIds User identifiers of members in the basic group
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
title Title of the basic group
final

Methods

copyWith({String? title, List<int>? memberUserIds}) → MessageBasicGroupChatCreate
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String