MessageCalendar class

Inheritance

Constructors

MessageCalendar({required int totalCount, required List<MessageCalendarDay> days, dynamic extra, int? clientId})
Contains information about found messages, split by days according to the option "utc_time_offset"
const
MessageCalendar.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
days → List<MessageCalendarDay>
days Information about messages sent
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalCount → int
totalCount Total number of found messages
final

Methods

copyWith({int? totalCount, List<MessageCalendarDay>? days, dynamic extra, int? clientId}) → MessageCalendar
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String