MessageCalendarDay class

Inheritance

Constructors

MessageCalendarDay({required int totalCount, required Message message})
Contains information about found messages sent on a specific day
const
MessageCalendarDay.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
message → Message
message First message sent on the day
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalCount → int
totalCount Total number of found messages sent on the day
final

Methods

copyWith({int? totalCount, Message? message}) → MessageCalendarDay
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String