MessageChatSetMessageAutoDeleteTime class

Inheritance

Constructors

MessageChatSetMessageAutoDeleteTime({required int messageAutoDeleteTime, required int fromUserId})
The auto-delete or self-destruct timer for messages in the chat has been changed
const
MessageChatSetMessageAutoDeleteTime.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
fromUserId → int
fromUserId If not 0, a user identifier, which default setting was automatically applied
final
hashCode → int
The hash code for this object.
no setterinherited
messageAutoDeleteTime → int
messageAutoDeleteTime New value auto-delete or self-destruct time, in seconds; 0 if disabled
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? messageAutoDeleteTime, int? fromUserId}) → MessageChatSetMessageAutoDeleteTime
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String