MessageChatUpgradeTo class

Inheritance

Constructors

MessageChatUpgradeTo({required int supergroupId})
A basic group was upgraded to a supergroup and was deactivated as the result
const
MessageChatUpgradeTo.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supergroupId → int
supergroupId Identifier of the supergroup to which the basic group was upgraded
final

Methods

copyWith({int? supergroupId}) → MessageChatUpgradeTo
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String