MessageCopyOptions class

Inheritance

Constructors

MessageCopyOptions({required bool sendCopy, required bool replaceCaption, FormattedText? newCaption})
Options to be used when a message content is copied without reference to the original sender. Service messages and messageInvoice can't be copied
const
MessageCopyOptions.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
newCaption → FormattedText?
newCaption New message caption; pass null to copy message without caption. Ignored if replace_caption is false
final
replaceCaption → bool
replaceCaption True, if media caption of the message copy needs to be replaced. Ignored if send_copy is false
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sendCopy → bool
sendCopy True, if content of the message needs to be copied without reference to the original sender. Always true if the message is forwarded to a secret chat or is local
final

Methods

copyWith({bool? sendCopy, bool? replaceCaption, FormattedText? newCaption}) → MessageCopyOptions
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String