MessageDice class

Inheritance

Constructors

MessageDice({DiceStickers? initialState, DiceStickers? finalState, required String emoji, required int value, required int successAnimationFrameNumber})
A dice message. The dice value is randomly generated by the server
const
MessageDice.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
emoji → String
emoji Emoji on which the dice throw animation is based
final
extra → dynamic
callback sign
no setterinherited
finalState → DiceStickers?
finalState The animated stickers with the final dice animation; may be null if unknown. updateMessageContent will be sent when the sticker became known
final
hashCode → int
The hash code for this object.
no setterinherited
initialState → DiceStickers?
initialState The animated stickers with the initial dice animation; may be null if unknown. updateMessageContent will be sent when the sticker became known
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
successAnimationFrameNumber → int
successAnimationFrameNumber Number of frame after which a success animation like a shower of confetti needs to be shown on updateMessageSendSucceeded
final
value → int
value The dice value. If the value is 0, the dice don't have final state yet
final

Methods

copyWith({DiceStickers? initialState, DiceStickers? finalState, String? emoji, int? value, int? successAnimationFrameNumber}) → MessageDice
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String