MessageForumTopicIsClosedToggled class

Inheritance

Constructors

MessageForumTopicIsClosedToggled({required bool isClosed})
A forum topic has been closed or opened
const
MessageForumTopicIsClosedToggled.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isClosed → bool
isClosed True, if the topic was closed; otherwise, the topic was reopened
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? isClosed}) → MessageForumTopicIsClosedToggled
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String