MessageForumTopicIsHiddenToggled class

Inheritance

Constructors

MessageForumTopicIsHiddenToggled({required bool isHidden})
A General forum topic has been hidden or unhidden
const
MessageForumTopicIsHiddenToggled.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isHidden → bool
isHidden True, if the topic was hidden; otherwise, the topic was unhidden
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? isHidden}) → MessageForumTopicIsHiddenToggled
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String