MessageForwardOrigin class

Inheritance
Implementers

Constructors

MessageForwardOrigin()
Contains information about the origin of a forwarded message
const
MessageForwardOrigin.fromJson(Map<String, dynamic> json)
a MessageForwardOrigin return type can be :
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith() → MessageForwardOrigin
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String