MessageGiftedPremium class

Inheritance

Constructors

MessageGiftedPremium({required int gifterUserId, required String currency, required int amount, required String cryptocurrency, required int cryptocurrencyAmount, required int monthCount, Sticker? sticker})
Telegram Premium was gifted to the user
const
MessageGiftedPremium.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

amount → int
amount The paid amount, in the smallest units of the currency
final
clientId → int?
client identifier
no setterinherited
cryptocurrency → String
cryptocurrency Cryptocurrency used to pay for the gift; may be empty if none
final
cryptocurrencyAmount → int
cryptocurrencyAmount The paid amount, in the smallest units of the cryptocurrency
final
currency → String
currency Currency for the paid amount
final
extra → dynamic
callback sign
no setterinherited
gifterUserId → int
gifterUserId The identifier of a user that gifted Telegram Premium; 0 if the gift was anonymous
final
hashCode → int
The hash code for this object.
no setterinherited
monthCount → int
monthCount Number of month the Telegram Premium subscription will be active
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sticker → Sticker?
sticker A sticker to be shown in the message; may be null if unknown
final

Methods

copyWith({int? gifterUserId, String? currency, int? amount, String? cryptocurrency, int? cryptocurrencyAmount, int? monthCount, Sticker? sticker}) → MessageGiftedPremium
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String