MessageInteractionInfo class

Inheritance

Constructors

MessageInteractionInfo({required int viewCount, required int forwardCount, MessageReplyInfo? replyInfo, required List<MessageReaction> reactions})
Contains information about interactions with a message
const
MessageInteractionInfo.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
forwardCount → int
forwardCount Number of times the message was forwarded
final
hashCode → int
The hash code for this object.
no setterinherited
reactions → List<MessageReaction>
reactions The list of reactions added to the message
final
replyInfo → MessageReplyInfo?
replyInfo Information about direct or indirect replies to the message; may be null. Currently, available only in channels with a discussion supergroup and discussion supergroups for messages, which are not replies itself
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
viewCount → int
viewCount Number of times the message was viewed
final

Methods

copyWith({int? viewCount, int? forwardCount, MessageReplyInfo? replyInfo, List<MessageReaction>? reactions}) → MessageInteractionInfo
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String