MessageInviteVideoChatParticipants class

Inheritance

Constructors

MessageInviteVideoChatParticipants({required int groupCallId, required List<int> userIds})
A message with information about an invite to a video chat
const
MessageInviteVideoChatParticipants.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
groupCallId → int
groupCallId Identifier of the video chat. The video chat can be received through the method getGroupCall
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userIds → List<int>
userIds Invited user identifiers
final

Methods

copyWith({int? groupCallId, List<int>? userIds}) → MessageInviteVideoChatParticipants
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String