MessageInvoice class

Inheritance

Constructors

MessageInvoice({required String title, required FormattedText description, Photo? photo, required String currency, required int totalAmount, required String startParameter, required bool isTest, required bool needShippingAddress, required int receiptMessageId, MessageExtendedMedia? extendedMedia})
A message with an invoice from a bot. Use getInternalLink with internalLinkTypeBotStart to share the invoice
const
MessageInvoice.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
currency → String
currency Currency for the product price
final
description → FormattedText
description Product description
final
extendedMedia → MessageExtendedMedia?
extendedMedia Extended media attached to the invoice; may be null
final
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isTest → bool
isTest True, if the invoice is a test invoice
final
needShippingAddress → bool
needShippingAddress True, if the shipping address must be specified
final
photo → Photo?
photo Product photo; may be null
final
receiptMessageId → int
receiptMessageId The identifier of the message with the receipt, after the product has been purchased
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startParameter → String
startParameter Unique invoice bot start_parameter to be passed to getInternalLink
final
title → String
title Product title
final
totalAmount → int
totalAmount Product total price in the smallest units of the currency
final

Methods

copyWith({String? title, FormattedText? description, Photo? photo, String? currency, int? totalAmount, String? startParameter, bool? isTest, bool? needShippingAddress, int? receiptMessageId, MessageExtendedMedia? extendedMedia}) → MessageInvoice
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String