MessageLink class

Inheritance

Constructors

MessageLink({required String link, required bool isPublic, dynamic extra, int? clientId})
Contains an HTTPS link to a message in a supergroup or channel, or a forum topic
const
MessageLink.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
isPublic → bool
isPublic True, if the link will work for non-members of the chat
final
link The link
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? link, bool? isPublic, dynamic extra, int? clientId}) → MessageLink
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String