MessageLinkInfo class

Inheritance

Constructors

MessageLinkInfo({required bool isPublic, required int chatId, required int messageThreadId, Message? message, required int mediaTimestamp, required bool forAlbum, dynamic extra, int? clientId})
Contains information about a link to a message or a forum topic in a chat
const
MessageLinkInfo.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

chatId → int
chatId If found, identifier of the chat to which the link points, 0 otherwise
final
clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
forAlbum → bool
forAlbum True, if the whole media album to which the message belongs is linked
final
hashCode → int
The hash code for this object.
no setterinherited
isPublic → bool
isPublic True, if the link is a public link for a message or a forum topic in a chat
final
mediaTimestamp → int
mediaTimestamp Timestamp from which the video/audio/video note/voice note playing must start, in seconds; 0 if not specified. The media can be in the message content or in its web page preview
final
message → Message?
message If found, the linked message; may be null
final
messageThreadId → int
messageThreadId If found, identifier of the message thread in which to open the message, or a forum topic to open if the message is missing
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? isPublic, int? chatId, int? messageThreadId, Message? message, int? mediaTimestamp, bool? forAlbum, dynamic extra, int? clientId}) → MessageLinkInfo
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String