MessageLocation class

Inheritance

Constructors

MessageLocation({required Location location, required int livePeriod, required int expiresIn, required int heading, required int proximityAlertRadius})
A message with a location
const
MessageLocation.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
expiresIn → int
expiresIn Left time for which the location can be updated, in seconds. updateMessageContent is not sent when this field changes
final
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
heading → int
heading For live locations, a direction in which the location moves, in degrees; 1-360. If 0 the direction is unknown
final
livePeriod → int
livePeriod Time relative to the message send date, for which the location can be updated, in seconds
final
location → Location
location The location description
final
proximityAlertRadius → int
proximityAlertRadius For live locations, a maximum distance to another chat member for proximity alerts, in meters (0-100000). 0 if the notification is disabled. Available only to the message sender
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Location? location, int? livePeriod, int? expiresIn, int? heading, int? proximityAlertRadius}) → MessageLocation
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String