MessagePaymentSuccessful class

Inheritance

Constructors

MessagePaymentSuccessful({required int invoiceChatId, required int invoiceMessageId, required String currency, required int totalAmount, required bool isRecurring, required bool isFirstRecurring, required String invoiceName})
A payment has been completed
const
MessagePaymentSuccessful.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
currency → String
currency Currency for the price of the product
final
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
invoiceChatId → int
invoiceChatId Identifier of the chat, containing the corresponding invoice message
final
invoiceMessageId → int
invoiceMessageId Identifier of the message with the corresponding invoice; can be 0 or an identifier of a deleted message
final
invoiceName → String
invoiceName Name of the invoice; may be empty if unknown
final
isFirstRecurring → bool
isFirstRecurring True, if this is the first recurring payment
final
isRecurring → bool
isRecurring True, if this is a recurring payment
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalAmount → int
totalAmount Total price for the product, in the smallest units of the currency
final

Methods

copyWith({int? invoiceChatId, int? invoiceMessageId, String? currency, int? totalAmount, bool? isRecurring, bool? isFirstRecurring, String? invoiceName}) → MessagePaymentSuccessful
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String