MessagePaymentSuccessfulBot class

Inheritance

Constructors

MessagePaymentSuccessfulBot({required String currency, required int totalAmount, required bool isRecurring, required bool isFirstRecurring, required String invoicePayload, required String shippingOptionId, OrderInfo? orderInfo, required String telegramPaymentChargeId, required String providerPaymentChargeId})
A payment has been completed; for bots only
const
MessagePaymentSuccessfulBot.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
currency → String
currency Currency for price of the product
final
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
invoicePayload → String
invoicePayload Invoice payload
final
isFirstRecurring → bool
isFirstRecurring True, if this is the first recurring payment
final
isRecurring → bool
isRecurring True, if this is a recurring payment
final
orderInfo → OrderInfo?
orderInfo Information about the order; may be null
final
providerPaymentChargeId → String
providerPaymentChargeId Provider payment identifier
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shippingOptionId → String
shippingOptionId Identifier of the shipping option chosen by the user; may be empty if not applicable
final
telegramPaymentChargeId → String
telegramPaymentChargeId Telegram payment identifier
final
totalAmount → int
totalAmount Total price for the product, in the smallest units of the currency
final

Methods

copyWith({String? currency, int? totalAmount, bool? isRecurring, bool? isFirstRecurring, String? invoicePayload, String? shippingOptionId, OrderInfo? orderInfo, String? telegramPaymentChargeId, String? providerPaymentChargeId}) → MessagePaymentSuccessfulBot
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String