MessagePosition class

Inheritance

Constructors

MessagePosition({required int position, required int messageId, required int date})
Contains information about a message in a specific position
const
MessagePosition.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
date → int
date Point in time (Unix timestamp) when the message was sent
final
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
messageId → int
messageId Message identifier
final
position → int
position 0-based message position in the full list of suitable messages
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? position, int? messageId, int? date}) → MessagePosition
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String