MessageProximityAlertTriggered class

Inheritance

Constructors

MessageProximityAlertTriggered({required MessageSender travelerId, required MessageSender watcherId, required int distance})
A user in the chat came within proximity alert range
const
MessageProximityAlertTriggered.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
distance → int
distance The distance between the users
final
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
travelerId → MessageSender
travelerId The identifier of a user or chat that triggered the proximity alert
final
watcherId → MessageSender
watcherId The identifier of a user or chat that subscribed for the proximity alert
final

Methods

copyWith({MessageSender? travelerId, MessageSender? watcherId, int? distance}) → MessageProximityAlertTriggered
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String