MessageReaction class

Inheritance

Constructors

MessageReaction({required ReactionType type, required int totalCount, required bool isChosen, required List<MessageSender> recentSenderIds})
Contains information about a reaction to a message
const
MessageReaction.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isChosen → bool
isChosen True, if the reaction is chosen by the current user
final
recentSenderIds → List<MessageSender>
recentSenderIds Identifiers of at most 3 recent message senders, added the reaction; available in private, basic group and supergroup chats
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalCount → int
totalCount Number of times the reaction was added
final
type → ReactionType
type Type of the reaction
final

Methods

copyWith({ReactionType? type, int? totalCount, bool? isChosen, List<MessageSender>? recentSenderIds}) → MessageReaction
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String