MessageReplyToStory class

Inheritance

Constructors

MessageReplyToStory({required int storySenderChatId, required int storyId})
Describes a replied story
const
MessageReplyToStory.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storyId → int
storyId The identifier of the replied story
final
storySenderChatId → int
storySenderChatId The identifier of the sender of the replied story. Currently, stories can be replied only in the sender's chat
final

Methods

copyWith({int? storySenderChatId, int? storyId}) → MessageReplyToStory
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String