MessageSendOptions class

Inheritance

Constructors

MessageSendOptions({required bool disableNotification, required bool fromBackground, required bool protectContent, required bool updateOrderOfInstalledStickerSets, MessageSchedulingState? schedulingState, required int sendingId})
Options to be used when a message is sent
const
MessageSendOptions.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
disableNotification → bool
disableNotification Pass true to disable notification for the message
final
extra → dynamic
callback sign
no setterinherited
fromBackground → bool
fromBackground Pass true if the message is sent from the background
final
hashCode → int
The hash code for this object.
no setterinherited
protectContent → bool
protectContent Pass true if the content of the message must be protected from forwarding and saving; for bots only
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schedulingState → MessageSchedulingState?
schedulingState Message scheduling state; pass null to send message immediately. Messages sent to a secret chat, live location messages and self-destructing messages can't be scheduled
final
sendingId → int
sendingId Non-persistent identifier, which will be returned back in messageSendingStatePending object and can be used to match sent messages and corresponding updateNewMessage updates
final
updateOrderOfInstalledStickerSets → bool
updateOrderOfInstalledStickerSets Pass true if the user explicitly chosen a sticker or a custom emoji from an installed sticker set; applicable only to sendMessage and sendMessageAlbum
final

Methods

copyWith({bool? disableNotification, bool? fromBackground, bool? protectContent, bool? updateOrderOfInstalledStickerSets, MessageSchedulingState? schedulingState, int? sendingId}) → MessageSendOptions
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String