MessageSendingStateFailed class

Inheritance

Constructors

MessageSendingStateFailed({required int errorCode, required String errorMessage, required bool canRetry, required bool needAnotherSender, required double retryAfter})
The message failed to be sent
const
MessageSendingStateFailed.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

canRetry → bool
canRetry True, if the message can be re-sent
final
clientId → int?
client identifier
no setterinherited
errorCode → int
errorCode An error code; 0 if unknown
final
errorMessage → String
errorMessage Error message
final
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
needAnotherSender → bool
needAnotherSender True, if the message can be re-sent only on behalf of a different sender
final
retryAfter → double
retryAfter Time left before the message can be re-sent, in seconds. No update is sent when this field changes
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? errorCode, String? errorMessage, bool? canRetry, bool? needAnotherSender, double? retryAfter}) → MessageSendingStateFailed
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String