MessageSponsor class

Inheritance

Constructors

MessageSponsor({required MessageSponsorType type, ChatPhotoInfo? photo, required String info})
Information about the sponsor of a message
const
MessageSponsor.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
info → String
info Additional optional information about the sponsor to be shown along with the message
final
photo → ChatPhotoInfo?
photo Photo of the sponsor; may be null if must not be shown
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → MessageSponsorType
type Type of the sponsor
final

Methods

copyWith({MessageSponsorType? type, ChatPhotoInfo? photo, String? info}) → MessageSponsor
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String