MessageStatistics class

Inheritance

Constructors

MessageStatistics({required StatisticalGraph messageInteractionGraph, dynamic extra, int? clientId})
A detailed statistics about a message
const
MessageStatistics.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
messageInteractionGraph → StatisticalGraph
messageInteractionGraph A graph containing number of message views and shares
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({StatisticalGraph? messageInteractionGraph, dynamic extra, int? clientId}) → MessageStatistics
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String