MessageSticker class

Inheritance

Constructors

MessageSticker({required Sticker sticker, required bool isPremium})
A sticker message
const
MessageSticker.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isPremium → bool
isPremium True, if premium animation of the sticker must be played
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sticker → Sticker
sticker The sticker description
final

Methods

copyWith({Sticker? sticker, bool? isPremium}) → MessageSticker
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String