MessageSuggestProfilePhoto class

Inheritance

Constructors

MessageSuggestProfilePhoto({required ChatPhoto photo})
A profile photo was suggested to a user in a private chat
const
MessageSuggestProfilePhoto.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
photo → ChatPhoto
photo The suggested chat photo. Use the method setProfilePhoto with inputChatPhotoPrevious to apply the photo
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({ChatPhoto? photo}) → MessageSuggestProfilePhoto
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String