MessageText class

Inheritance

Constructors

MessageText({required FormattedText text, WebPage? webPage})
A text message
const
MessageText.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → FormattedText
text Text of the message
final
webPage → WebPage?
webPage A preview of the web page that's mentioned in the text; may be null
final

Methods

copyWith({FormattedText? text, WebPage? webPage}) → MessageText
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String