MessageThreadInfo class

Inheritance

Constructors

MessageThreadInfo({required int chatId, required int messageThreadId, MessageReplyInfo? replyInfo, required int unreadMessageCount, required List<Message> messages, DraftMessage? draftMessage, dynamic extra, int? clientId})
Contains information about a message thread
const
MessageThreadInfo.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

chatId → int
chatId Identifier of the chat to which the message thread belongs
final
clientId → int?
clientId client identifier
final
draftMessage → DraftMessage?
draftMessage A draft of a message in the message thread; may be null if none
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
messages → List<Message>
messages The messages from which the thread starts. The messages are returned in a reverse chronological order (i.e., in order of decreasing message_id)
final
messageThreadId → int
messageThreadId Message thread identifier, unique within the chat
final
replyInfo → MessageReplyInfo?
replyInfo Information about the message thread; may be null for forum topic threads
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unreadMessageCount → int
unreadMessageCount Approximate number of unread messages in the message thread
final

Methods

copyWith({int? chatId, int? messageThreadId, MessageReplyInfo? replyInfo, int? unreadMessageCount, List<Message>? messages, DraftMessage? draftMessage, dynamic extra, int? clientId}) → MessageThreadInfo
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String