MessageVideo class

Inheritance

Constructors

MessageVideo({required Video video, required FormattedText caption, required bool hasSpoiler, required bool isSecret})
A video message
const
MessageVideo.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

caption → FormattedText
caption Video caption
final
clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hasSpoiler → bool
hasSpoiler True, if the video preview must be covered by a spoiler animation
final
isSecret → bool
isSecret True, if the video thumbnail must be blurred and the video must be shown only while tapped
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
video → Video
video The video description
final

Methods

copyWith({Video? video, FormattedText? caption, bool? hasSpoiler, bool? isSecret}) → MessageVideo
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String