MessageVideoNote class

Inheritance

Constructors

MessageVideoNote({required VideoNote videoNote, required bool isViewed, required bool isSecret})
A video note message
const
MessageVideoNote.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isSecret → bool
isSecret True, if the video note thumbnail must be blurred and the video note must be shown only while tapped
final
isViewed → bool
isViewed True, if at least one of the recipients has viewed the video note
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
videoNote → VideoNote
videoNote The video note description
final

Methods

copyWith({VideoNote? videoNote, bool? isViewed, bool? isSecret}) → MessageVideoNote
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String