MessageViewer class

Inheritance

Constructors

MessageViewer({required int userId, required int viewDate})
Represents a viewer of a message
const
MessageViewer.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userId → int
userId User identifier of the viewer
final
viewDate → int
viewDate Approximate point in time (Unix timestamp) when the message was viewed
final

Methods

copyWith({int? userId, int? viewDate}) → MessageViewer
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String