MessageViewers class

Inheritance

Constructors

MessageViewers({required List<MessageViewer> viewers, dynamic extra, int? clientId})
Represents a list of message viewers
const
MessageViewers.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
viewers → List<MessageViewer>
viewers List of message viewers
final

Methods

copyWith({List<MessageViewer>? viewers, dynamic extra, int? clientId}) → MessageViewers
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String