MessageVoiceNote class

Inheritance

Constructors

MessageVoiceNote({required VoiceNote voiceNote, required FormattedText caption, required bool isListened})
A voice note message
const
MessageVoiceNote.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

caption → FormattedText
caption Voice note caption
final
clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isListened → bool
isListened True, if at least one of the recipients has listened to the voice note
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
voiceNote → VoiceNote
voiceNote The voice note description
final

Methods

copyWith({VoiceNote? voiceNote, FormattedText? caption, bool? isListened}) → MessageVoiceNote
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String