NetworkStatisticsEntryFile class

Inheritance

Constructors

NetworkStatisticsEntryFile({FileType? fileType, required NetworkType networkType, required int sentBytes, required int receivedBytes})
Contains information about the total amount of data that was used to send and receive files
const
NetworkStatisticsEntryFile.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
fileType → FileType?
fileType Type of the file the data is part of; pass null if the data isn't related to files
final
hashCode → int
The hash code for this object.
no setterinherited
networkType → NetworkType
networkType Type of the network the data was sent through. Call setNetworkType to maintain the actual network type
final
receivedBytes → int
receivedBytes Total number of bytes received
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sentBytes → int
sentBytes Total number of bytes sent
final

Methods

copyWith({FileType? fileType, NetworkType? networkType, int? sentBytes, int? receivedBytes}) → NetworkStatisticsEntryFile
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String