Notification class

Inheritance

Constructors

Notification({required int id, required int date, required bool isSilent, required NotificationType type})
Contains information about a notification
const
Notification.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
date → int
date Notification date
final
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → int
id Unique persistent identifier of this notification
final
isSilent → bool
isSilent True, if the notification was explicitly sent without sound
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → NotificationType
type Notification type
final

Methods

copyWith({int? id, int? date, bool? isSilent, NotificationType? type}) → Notification
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String