NotificationGroup class

Inheritance

Constructors

NotificationGroup({required int id, required NotificationGroupType type, required int chatId, required int totalCount, required List<Notification> notifications})
Describes a group of notifications
const
NotificationGroup.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

chatId → int
chatId Identifier of a chat to which all notifications in the group belong
final
clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → int
id Unique persistent auto-incremented from 1 identifier of the notification group
final
notifications → List<Notification>
notifications The list of active notifications
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalCount → int
totalCount Total number of active notifications in the group
final
type → NotificationGroupType
type Type of the group
final

Methods

copyWith({int? id, NotificationGroupType? type, int? chatId, int? totalCount, List<Notification>? notifications}) → NotificationGroup
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String