NotificationTypeNewPushMessage class

Inheritance

Constructors

NotificationTypeNewPushMessage({required int messageId, required MessageSender senderId, required String senderName, required bool isOutgoing, required PushMessageContent content})
New message was received through a push notification
const
NotificationTypeNewPushMessage.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
content → PushMessageContent
content Push message content
final
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isOutgoing → bool
isOutgoing True, if the message is outgoing
final
messageId → int
messageId The message identifier. The message will not be available in the chat history, but the notificationTypeNewPushMessage can be used in viewMessages, or as a message to reply
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
senderId → MessageSender
senderId Identifier of the sender of the message. Corresponding user or chat may be inaccessible
final
senderName → String
senderName Name of the sender
final

Methods

copyWith({int? messageId, MessageSender? senderId, String? senderName, bool? isOutgoing, PushMessageContent? content}) → NotificationTypeNewPushMessage
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String