OpenMessageContent class

Inheritance

Constructors

OpenMessageContent({required int chatId, required int messageId})
Informs TDLib that the message content has been opened (e.g., the user has opened a photo, video, document, location or venue, or has listened to an audio file or voice note message).. An updateMessageContentOpened update will be generated if something has changed
const

Properties

chatId → int
chatId Chat identifier of the message
final
hashCode → int
The hash code for this object.
no setterinherited
messageId → int
messageId Identifier of the message with the opened content
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? messageId}) → OpenMessageContent
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String