OpenStory class

Inheritance

Constructors

OpenStory({required int storySenderChatId, required int storyId})
Informs TDLib that a story is opened and is being viewed by the user
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storyId → int
storyId The identifier of the story
final
storySenderChatId → int
storySenderChatId The identifier of the sender of the opened story
final

Methods

copyWith({int? storySenderChatId, int? storyId}) → OpenStory
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String