OpenWebApp class

Inheritance

Constructors

OpenWebApp({required int chatId, required int botUserId, required String url, ThemeParameters? theme, required String applicationName, required int messageThreadId, MessageReplyTo? replyTo})
Informs TDLib that a Web App is being opened from attachment menu, a botMenuButton button, an internalLinkTypeAttachmentMenuBot link, or an inlineKeyboardButtonTypeWebApp button.. For each bot, a confirmation alert about data sent to the bot must be shown once
const

Properties

applicationName → String
applicationName Short name of the application; 0-64 English letters, digits, and underscores
final
botUserId → int
botUserId Identifier of the bot, providing the Web App
final
chatId → int
chatId Identifier of the chat in which the Web App is opened. The Web App can't be opened in secret chats
final
hashCode → int
The hash code for this object.
no setterinherited
messageThreadId → int
messageThreadId If not 0, a message thread identifier in which the message will be sent
final
replyTo → MessageReplyTo?
replyTo Identifier of the replied message or story for the message sent by the Web App; pass null if none
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
theme → ThemeParameters?
theme Preferred Web App theme; pass null to use the default theme
final
url → String
url The URL from an inlineKeyboardButtonTypeWebApp button, a botMenuButton button, or an internalLinkTypeAttachmentMenuBot link, or an empty string otherwise
final

Methods

copyWith({int? chatId, int? botUserId, String? url, ThemeParameters? theme, String? applicationName, int? messageThreadId, MessageReplyTo? replyTo}) → OpenWebApp
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String