OptimizeStorage class

Inheritance

Constructors

OptimizeStorage({required int size, required int ttl, required int count, required int immunityDelay, required List<FileType> fileTypes, required List<int> chatIds, required List<int> excludeChatIds, required bool returnDeletedFileStatistics, required int chatLimit})
Optimizes storage usage, i.e. deletes some files and returns new storage usage statistics. Secret thumbnails can't be deleted
const

Properties

chatIds → List<int>
chatIds If non-empty, only files from the given chats are considered. Use 0 as chat identifier to delete files not belonging to any chat (e.g., profile photos)
final
chatLimit → int
chatLimit Same as in getStorageStatistics. Affects only returned statistics
final
count → int
count Limit on the total number of files after deletion. Pass -1 to use the default limit
final
excludeChatIds → List<int>
excludeChatIds If non-empty, files from the given chats are excluded. Use 0 as chat identifier to exclude all files not belonging to any chat (e.g., profile photos)
final
fileTypes → List<FileType>
fileTypes If non-empty, only files with the given types are considered. By default, all types except thumbnails, profile photos, stickers and wallpapers are deleted
final
hashCode → int
The hash code for this object.
no setterinherited
immunityDelay → int
immunityDelay The amount of time after the creation of a file during which it can't be deleted, in seconds. Pass -1 to use the default value
final
returnDeletedFileStatistics → bool
returnDeletedFileStatistics Pass true if statistics about the files that were deleted must be returned instead of the whole storage usage statistics. Affects only returned statistics
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → int
size Limit on the total size of files after deletion, in bytes. Pass -1 to use the default limit
final
ttl → int
ttl Limit on the time that has passed since the last time a file was accessed (or creation time for some filesystems). Pass -1 to use the default limit
final

Methods

copyWith({int? size, int? ttl, int? count, int? immunityDelay, List<FileType>? fileTypes, List<int>? chatIds, List<int>? excludeChatIds, bool? returnDeletedFileStatistics, int? chatLimit}) → OptimizeStorage
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String