PageBlockAnimation class

Inheritance

Constructors

PageBlockAnimation({Animation? animation, required PageBlockCaption caption, required bool needAutoplay})
An animation
const
PageBlockAnimation.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

animation → Animation?
animation Animation file; may be null
final
caption → PageBlockCaption
caption Animation caption
final
clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
needAutoplay → bool
needAutoplay True, if the animation must be played automatically
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Animation? animation, PageBlockCaption? caption, bool? needAutoplay}) → PageBlockAnimation
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String