PageBlockCaption class

Inheritance

Constructors

PageBlockCaption({required RichText text, required RichText credit})
Contains a caption of an instant view web page block, consisting of a text and a trailing credit
const
PageBlockCaption.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
credit → RichText
credit Block credit (like HTML tag )
final
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → RichText
text Content of the caption
final

Methods

copyWith({RichText? text, RichText? credit}) → PageBlockCaption
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String