PageBlockChatLink class

Inheritance

Constructors

PageBlockChatLink({required String title, ChatPhotoInfo? photo, required String username})
A link to a chat
const
PageBlockChatLink.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
photo → ChatPhotoInfo?
photo Chat photo; may be null
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
title Chat title
final
username → String
username Chat username by which all other information about the chat can be resolved
final

Methods

copyWith({String? title, ChatPhotoInfo? photo, String? username}) → PageBlockChatLink
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String