PageBlockDetails class

Inheritance

Constructors

PageBlockDetails({required RichText header, required List<PageBlock> pageBlocks, required bool isOpen})
A collapsible block
const
PageBlockDetails.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
header Always visible heading for the block
final
isOpen → bool
isOpen True, if the block is open by default
final
pageBlocks → List<PageBlock>
pageBlocks Block contents
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({RichText? header, List<PageBlock>? pageBlocks, bool? isOpen}) → PageBlockDetails
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String