PageBlockEmbedded class

Inheritance

Constructors

PageBlockEmbedded({required String url, required String html, Photo? posterPhoto, required int width, required int height, required PageBlockCaption caption, required bool isFullWidth, required bool allowScrolling})
An embedded web page
const
PageBlockEmbedded.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

allowScrolling → bool
allowScrolling True, if scrolling needs to be allowed
final
caption → PageBlockCaption
caption Block caption
final
clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
height → int
height Block height; 0 if unknown
final
html → String
html HTML-markup of the embedded page
final
isFullWidth → bool
isFullWidth True, if the block must be full width
final
posterPhoto → Photo?
posterPhoto Poster photo, if available; may be null
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → String
url Web page URL, if available
final
width → int
width Block width; 0 if unknown
final

Methods

copyWith({String? url, String? html, Photo? posterPhoto, int? width, int? height, PageBlockCaption? caption, bool? isFullWidth, bool? allowScrolling}) → PageBlockEmbedded
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String