PageBlockEmbeddedPost class

Inheritance

Constructors

PageBlockEmbeddedPost({required String url, required String author, Photo? authorPhoto, required int date, required List<PageBlock> pageBlocks, required PageBlockCaption caption})
An embedded post
const
PageBlockEmbeddedPost.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

author → String
author Post author
final
authorPhoto → Photo?
authorPhoto Post author photo; may be null
final
caption → PageBlockCaption
caption Post caption
final
clientId → int?
client identifier
no setterinherited
date → int
date Point in time (Unix timestamp) when the post was created; 0 if unknown
final
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
pageBlocks → List<PageBlock>
pageBlocks Post content
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → String
url Web page URL
final

Methods

copyWith({String? url, String? author, Photo? authorPhoto, int? date, List<PageBlock>? pageBlocks, PageBlockCaption? caption}) → PageBlockEmbeddedPost
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String