PageBlockMap class

Inheritance

Constructors

PageBlockMap({required Location location, required int zoom, required int width, required int height, required PageBlockCaption caption})
A map
const
PageBlockMap.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

caption → PageBlockCaption
caption Block caption
final
clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
height → int
height Map height
final
location → Location
location Location of the map center
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → int
width Map width
final
zoom → int
zoom Map zoom level
final

Methods

copyWith({Location? location, int? zoom, int? width, int? height, PageBlockCaption? caption}) → PageBlockMap
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String