PageBlockPhoto class

Inheritance

Constructors

PageBlockPhoto({Photo? photo, required PageBlockCaption caption, required String url})
A photo
const
PageBlockPhoto.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

caption → PageBlockCaption
caption Photo caption
final
clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
photo → Photo?
photo Photo file; may be null
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → String
url URL that needs to be opened when the photo is clicked
final

Methods

copyWith({Photo? photo, PageBlockCaption? caption, String? url}) → PageBlockPhoto
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String