PageBlockTableCell class

Inheritance

Constructors

PageBlockTableCell({RichText? text, required bool isHeader, required int colspan, required int rowspan, required PageBlockHorizontalAlignment align, required PageBlockVerticalAlignment valign})
Represents a cell of a table
const
PageBlockTableCell.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

align → PageBlockHorizontalAlignment
align Horizontal cell content alignment
final
clientId → int?
client identifier
no setterinherited
colspan → int
colspan The number of columns the cell spans
final
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isHeader → bool
isHeader True, if it is a header cell
final
rowspan → int
rowspan The number of rows the cell spans
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → RichText?
text Cell text; may be null. If the text is null, then the cell must be invisible
final
valign → PageBlockVerticalAlignment
valign Vertical cell content alignment
final

Methods

copyWith({RichText? text, bool? isHeader, int? colspan, int? rowspan, PageBlockHorizontalAlignment? align, PageBlockVerticalAlignment? valign}) → PageBlockTableCell
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String