PageBlockVideo class

Inheritance

Constructors

PageBlockVideo({Video? video, required PageBlockCaption caption, required bool needAutoplay, required bool isLooped})
A video
const
PageBlockVideo.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

caption → PageBlockCaption
caption Video caption
final
clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isLooped → bool
isLooped True, if the video must be looped
final
needAutoplay → bool
needAutoplay True, if the video must be played automatically
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
video → Video?
video Video file; may be null
final

Methods

copyWith({Video? video, PageBlockCaption? caption, bool? needAutoplay, bool? isLooped}) → PageBlockVideo
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String