PageBlockVoiceNote class

Inheritance

Constructors

PageBlockVoiceNote({VoiceNote? voiceNote, required PageBlockCaption caption})
A voice note
const
PageBlockVoiceNote.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

caption → PageBlockCaption
caption Voice note caption
final
clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
voiceNote → VoiceNote?
voiceNote Voice note; may be null
final

Methods

copyWith({VoiceNote? voiceNote, PageBlockCaption? caption}) → PageBlockVoiceNote
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String