ParseTextEntities class

Inheritance

Constructors

ParseTextEntities({required String text, required TextParseMode parseMode})
Parses Bold, Italic, Underline, Strikethrough, Spoiler, CustomEmoji, Code, Pre, PreCode, TextUrl and MentionName entities from a marked-up text. Can be called synchronously
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
parseMode → TextParseMode
parseMode Text parse mode
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String
text The text to parse
final

Methods

copyWith({String? text, TextParseMode? parseMode}) → ParseTextEntities
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String