PassportAuthorizationForm class

Inheritance

Constructors

PassportAuthorizationForm({required int id, required List<PassportRequiredElement> requiredElements, required String privacyPolicyUrl, dynamic extra, int? clientId})
Contains information about a Telegram Passport authorization form that was requested
const
PassportAuthorizationForm.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
id → int
id Unique identifier of the authorization form
final
privacyPolicyUrl → String
privacyPolicyUrl URL for the privacy policy of the service; may be empty
final
requiredElements → List<PassportRequiredElement>
requiredElements Telegram Passport elements that must be provided to complete the form
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? id, List<PassportRequiredElement>? requiredElements, String? privacyPolicyUrl, dynamic extra, int? clientId}) → PassportAuthorizationForm
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String