PassportElementDriverLicense class

Inheritance

Constructors

PassportElementDriverLicense({required IdentityDocument driverLicense, dynamic extra, int? clientId})
A Telegram Passport element containing the user's driver license
const
PassportElementDriverLicense.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
driverLicense → IdentityDocument
driverLicense Driver license
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({IdentityDocument? driverLicense, dynamic extra, int? clientId}) → PassportElementDriverLicense
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String