PassportElementError class

Inheritance

Constructors

PassportElementError({required PassportElementType type, required String message, required PassportElementErrorSource source})
Contains the description of an error in a Telegram Passport element
const
PassportElementError.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
message → String
message Error message
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → PassportElementErrorSource
source Error source
final
type → PassportElementType
type Type of the Telegram Passport element which has the error
final

Methods

copyWith({PassportElementType? type, String? message, PassportElementErrorSource? source}) → PassportElementError
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String