PassportElementIdentityCard class

Inheritance

Constructors

PassportElementIdentityCard({required IdentityDocument identityCard, dynamic extra, int? clientId})
A Telegram Passport element containing the user's identity card
const
PassportElementIdentityCard.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
identityCard → IdentityDocument
identityCard Identity card
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({IdentityDocument? identityCard, dynamic extra, int? clientId}) → PassportElementIdentityCard
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String