PaymentForm class

Inheritance

Constructors

PaymentForm({required int id, required Invoice invoice, required int sellerBotUserId, required int paymentProviderUserId, required PaymentProvider paymentProvider, required List<PaymentOption> additionalPaymentOptions, OrderInfo? savedOrderInfo, required List<SavedCredentials> savedCredentials, required bool canSaveCredentials, required bool needPassword, required String productTitle, required FormattedText productDescription, Photo? productPhoto, dynamic extra, int? clientId})
Contains information about an invoice payment form
const
PaymentForm.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

additionalPaymentOptions → List<PaymentOption>
additionalPaymentOptions The list of additional payment options
final
canSaveCredentials → bool
canSaveCredentials True, if the user can choose to save credentials
final
clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
id → int
id The payment form identifier
final
invoice → Invoice
invoice Full information about the invoice
final
needPassword → bool
needPassword True, if the user will be able to save credentials, if sets up a 2-step verification password
final
paymentProvider → PaymentProvider
paymentProvider Information about the payment provider
final
paymentProviderUserId → int
paymentProviderUserId User identifier of the payment provider bot
final
productDescription → FormattedText
productDescription Product description
final
productPhoto → Photo?
productPhoto Product photo; may be null
final
productTitle → String
productTitle Product title
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
savedCredentials → List<SavedCredentials>
savedCredentials The list of saved payment credentials
final
savedOrderInfo → OrderInfo?
savedOrderInfo Saved server-side order information; may be null
final
sellerBotUserId → int
sellerBotUserId User identifier of the seller bot
final

Methods

copyWith({int? id, Invoice? invoice, int? sellerBotUserId, int? paymentProviderUserId, PaymentProvider? paymentProvider, List<PaymentOption>? additionalPaymentOptions, OrderInfo? savedOrderInfo, List<SavedCredentials>? savedCredentials, bool? canSaveCredentials, bool? needPassword, String? productTitle, FormattedText? productDescription, Photo? productPhoto, dynamic extra, int? clientId}) → PaymentForm
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String