PaymentProviderStripe class

Inheritance

Constructors

PaymentProviderStripe({required String publishableKey, required bool needCountry, required bool needPostalCode, required bool needCardholderName})
Stripe payment provider
const
PaymentProviderStripe.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
needCardholderName → bool
needCardholderName True, if the cardholder name must be provided
final
needCountry → bool
needCountry True, if the user country must be provided
final
needPostalCode → bool
needPostalCode True, if the user ZIP/postal code must be provided
final
publishableKey → String
publishableKey Stripe API publishable key
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? publishableKey, bool? needCountry, bool? needPostalCode, bool? needCardholderName}) → PaymentProviderStripe
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String