PersonalDetails class

Inheritance

Constructors

PersonalDetails({required String firstName, required String middleName, required String lastName, required String nativeFirstName, required String nativeMiddleName, required String nativeLastName, required Date birthdate, required String gender, required String countryCode, required String residenceCountryCode})
Contains the user's personal details
const
PersonalDetails.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

birthdate → Date
birthdate Birthdate of the user
final
clientId → int?
client identifier
no setterinherited
countryCode → String
countryCode A two-letter ISO 3166-1 alpha-2 country code of the user's country
final
extra → dynamic
callback sign
no setterinherited
firstName → String
firstName First name of the user written in English; 1-255 characters
final
gender → String
gender Gender of the user, "male" or "female"
final
hashCode → int
The hash code for this object.
no setterinherited
lastName → String
lastName Last name of the user written in English; 1-255 characters
final
middleName → String
middleName Middle name of the user written in English; 0-255 characters
final
nativeFirstName → String
nativeFirstName Native first name of the user; 1-255 characters
final
nativeLastName → String
nativeLastName Native last name of the user; 1-255 characters
final
nativeMiddleName → String
nativeMiddleName Native middle name of the user; 0-255 characters
final
residenceCountryCode → String
residenceCountryCode A two-letter ISO 3166-1 alpha-2 country code of the user's residence country
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? firstName, String? middleName, String? lastName, String? nativeFirstName, String? nativeMiddleName, String? nativeLastName, Date? birthdate, String? gender, String? countryCode, String? residenceCountryCode}) → PersonalDetails
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String