PersonalDocument class

Inheritance

Constructors

PersonalDocument({required List<DatedFile> files, required List<DatedFile> translation})
A personal document, containing some information about a user
const
PersonalDocument.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
files → List<DatedFile>
files List of files containing the pages of the document
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
translation → List<DatedFile>
translation List of files containing a certified English translation of the document
final

Methods

copyWith({List<DatedFile>? files, List<DatedFile>? translation}) → PersonalDocument
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String