PhoneNumberInfo class

Inheritance

Constructors

PhoneNumberInfo({CountryInfo? country, required String countryCallingCode, required String formattedPhoneNumber, required bool isAnonymous, dynamic extra, int? clientId})
Contains information about a phone number
const
PhoneNumberInfo.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
country → CountryInfo?
country Information about the country to which the phone number belongs; may be null
final
countryCallingCode → String
countryCallingCode The part of the phone number denoting country calling code or its part
final
extra → dynamic
extra callback sign
final
formattedPhoneNumber → String
formattedPhoneNumber The phone number without country calling code formatted accordingly to local rules. Expected digits are returned as '-', but even more digits might be entered by the user
final
hashCode → int
The hash code for this object.
no setterinherited
isAnonymous → bool
isAnonymous True, if the phone number was bought on Fragment and isn't tied to a SIM card
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({CountryInfo? country, String? countryCallingCode, String? formattedPhoneNumber, bool? isAnonymous, dynamic extra, int? clientId}) → PhoneNumberInfo
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String