Photo class

Inheritance

Constructors

Photo({required bool hasStickers, Minithumbnail? minithumbnail, required List<PhotoSize> sizes})
Describes a photo
const
Photo.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hasStickers → bool
hasStickers True, if stickers were added to the photo. The list of corresponding sticker sets can be received using getAttachedStickerSets
final
minithumbnail → Minithumbnail?
minithumbnail Photo minithumbnail; may be null
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sizes → List<PhotoSize>
sizes Available variants of the photo, in different sizes
final

Methods

copyWith({bool? hasStickers, Minithumbnail? minithumbnail, List<PhotoSize>? sizes}) → Photo
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String