PhotoSize class

Inheritance

Constructors

PhotoSize({required String type, required File photo, required int width, required int height, required List<int> progressiveSizes})
Describes an image in JPEG format
const
PhotoSize.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
height → int
height Image height
final
photo → File
photo Information about the image file
final
progressiveSizes → List<int>
progressiveSizes Sizes of progressive JPEG file prefixes, which can be used to preliminarily show the image; in bytes
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
type Image type (see https://core.telegram.org/constructor/photoSize)
final
width → int
width Image width
final

Methods

copyWith({String? type, File? photo, int? width, int? height, List<int>? progressiveSizes}) → PhotoSize
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String