PinChatMessage class

Inheritance

Constructors

PinChatMessage({required int chatId, required int messageId, required bool disableNotification, required bool onlyForSelf})
Pins a message in a chat; requires can_pin_messages rights or can_edit_messages rights in the channel
const

Properties

chatId → int
chatId Identifier of the chat
final
disableNotification → bool
disableNotification Pass true to disable notification about the pinned message. Notifications are always disabled in channels and private chats
final
hashCode → int
The hash code for this object.
no setterinherited
messageId → int
messageId Identifier of the new pinned message
final
onlyForSelf → bool
onlyForSelf Pass true to pin the message only for self; private chats only
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? messageId, bool? disableNotification, bool? onlyForSelf}) → PinChatMessage
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String