PingProxy class

Inheritance

Constructors

PingProxy({required int proxyId})
Computes time needed to receive a response from a Telegram server through a proxy. Can be called before authorization
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
proxyId → int
proxyId Proxy identifier. Use 0 to ping a Telegram server without a proxy
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? proxyId}) → PingProxy
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String