PollTypeRegular class

Inheritance

Constructors

PollTypeRegular({required bool allowMultipleAnswers})
A regular poll
const
PollTypeRegular.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

allowMultipleAnswers → bool
allowMultipleAnswers True, if multiple answer options can be chosen simultaneously
final
clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? allowMultipleAnswers}) → PollTypeRegular
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String