PremiumFeatures class

Inheritance

Constructors

PremiumFeatures({required List<PremiumFeature> features, required List<PremiumLimit> limits, InternalLinkType? paymentLink, dynamic extra, int? clientId})
Contains information about features, available to Premium users
const
PremiumFeatures.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
features → List<PremiumFeature>
features The list of available features
final
hashCode → int
The hash code for this object.
no setterinherited
limits → List<PremiumLimit>
limits The list of limits, increased for Premium users
final
paymentLink An internal link to be opened to pay for Telegram Premium if store payment isn't possible; may be null if direct payment isn't available
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<PremiumFeature>? features, List<PremiumLimit>? limits, InternalLinkType? paymentLink, dynamic extra, int? clientId}) → PremiumFeatures
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String