PremiumLimit class

Inheritance

Constructors

PremiumLimit({required PremiumLimitType type, required int defaultValue, required int premiumValue, dynamic extra, int? clientId})
Contains information about a limit, increased for Premium users
const
PremiumLimit.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
defaultValue → int
defaultValue Default value of the limit
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
premiumValue → int
premiumValue Value of the limit for Premium users
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → PremiumLimitType
type The type of the limit
final

Methods

copyWith({PremiumLimitType? type, int? defaultValue, int? premiumValue, dynamic extra, int? clientId}) → PremiumLimit
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String