ProcessChatFolderNewChats class

Inheritance

Constructors

ProcessChatFolderNewChats({required int chatFolderId, required List<int> addedChatIds})
Process new chats added to a shareable chat folder by its owner
const

Properties

addedChatIds → List<int>
addedChatIds Identifiers of the new chats, which are added to the chat folder. The chats are automatically joined if they aren't joined yet
final
chatFolderId → int
chatFolderId Chat folder identifier
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatFolderId, List<int>? addedChatIds}) → ProcessChatFolderNewChats
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String