Proxy class

Inheritance

Constructors

Proxy({required int id, required String server, required int port, required int lastUsedDate, required bool isEnabled, required ProxyType type, dynamic extra, int? clientId})
Contains information about a proxy server
const
Proxy.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
id → int
id Unique identifier of the proxy
final
isEnabled → bool
isEnabled True, if the proxy is enabled now
final
lastUsedDate → int
lastUsedDate Point in time (Unix timestamp) when the proxy was last used; 0 if never
final
port → int
port Proxy server port
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
server → String
server Proxy server IP address
final
type → ProxyType
type Type of the proxy
final

Methods

copyWith({int? id, String? server, int? port, int? lastUsedDate, bool? isEnabled, ProxyType? type, dynamic extra, int? clientId}) → Proxy
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String