ProxyTypeHttp class

Inheritance

Constructors

ProxyTypeHttp({required String username, required String password, required bool httpOnly})
A HTTP transparent proxy server
const
ProxyTypeHttp.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
httpOnly → bool
httpOnly Pass true if the proxy supports only HTTP requests and doesn't support transparent TCP connections via HTTP CONNECT method
final
password → String
password Password for logging in; may be empty
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
username → String
username Username for logging in; may be empty
final

Methods

copyWith({String? username, String? password, bool? httpOnly}) → ProxyTypeHttp
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String