PushMessageContentAudio class

Inheritance

Constructors

PushMessageContentAudio({Audio? audio, required bool isPinned})
An audio message
const
PushMessageContentAudio.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

audio → Audio?
audio Message content; may be null
final
clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isPinned → bool
isPinned True, if the message is a pinned message with the specified content
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Audio? audio, bool? isPinned}) → PushMessageContentAudio
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String