PushMessageContentChatDeleteMember class

Inheritance

Constructors

PushMessageContentChatDeleteMember({required String memberName, required bool isCurrentUser, required bool isLeft})
A chat member was deleted
const
PushMessageContentChatDeleteMember.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isCurrentUser → bool
isCurrentUser True, if the current user was deleted from the group
final
isLeft → bool
isLeft True, if the user has left the group themselves
final
memberName → String
memberName Name of the deleted member
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? memberName, bool? isCurrentUser, bool? isLeft}) → PushMessageContentChatDeleteMember
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String