PushMessageContentMediaAlbum class

Inheritance

Constructors

PushMessageContentMediaAlbum({required int totalCount, required bool hasPhotos, required bool hasVideos, required bool hasAudios, required bool hasDocuments})
A media album
const
PushMessageContentMediaAlbum.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hasAudios → bool
hasAudios True, if the album has at least one audio file
final
hasDocuments → bool
hasDocuments True, if the album has at least one document
final
hashCode → int
The hash code for this object.
no setterinherited
hasPhotos → bool
hasPhotos True, if the album has at least one photo
final
hasVideos → bool
hasVideos True, if the album has at least one video file
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalCount → int
totalCount Number of messages in the album
final

Methods

copyWith({int? totalCount, bool? hasPhotos, bool? hasVideos, bool? hasAudios, bool? hasDocuments}) → PushMessageContentMediaAlbum
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String