PushMessageContentPhoto class

Inheritance

Constructors

PushMessageContentPhoto({Photo? photo, required String caption, required bool isSecret, required bool isPinned})
A photo message
const
PushMessageContentPhoto.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

caption → String
caption Photo caption
final
clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isPinned → bool
isPinned True, if the message is a pinned message with the specified content
final
isSecret → bool
isSecret True, if the photo is secret
final
photo → Photo?
photo Message content; may be null
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Photo? photo, String? caption, bool? isSecret, bool? isPinned}) → PushMessageContentPhoto
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String