PushMessageContentPoll class

Inheritance

Constructors

PushMessageContentPoll({required String question, required bool isRegular, required bool isPinned})
A message with a poll
const
PushMessageContentPoll.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isPinned → bool
isPinned True, if the message is a pinned message with the specified content
final
isRegular → bool
isRegular True, if the poll is regular and not in quiz mode
final
question → String
question Poll question
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? question, bool? isRegular, bool? isPinned}) → PushMessageContentPoll
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String