RateSpeechRecognition class

Inheritance

Constructors

RateSpeechRecognition({required int chatId, required int messageId, required bool isGood})
Rates recognized speech in a video note or a voice note message
const

Properties

chatId → int
chatId Identifier of the chat to which the message belongs
final
hashCode → int
The hash code for this object.
no setterinherited
isGood → bool
isGood Pass true if the speech recognition is good
final
messageId → int
messageId Identifier of the message
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? messageId, bool? isGood}) → RateSpeechRecognition
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String