ReadAllMessageThreadMentions class

Inheritance

Constructors

ReadAllMessageThreadMentions({required int chatId, required int messageThreadId})
Marks all mentions in a forum topic as read
const

Properties

chatId → int
chatId Chat identifier
final
hashCode → int
The hash code for this object.
no setterinherited
messageThreadId → int
messageThreadId Message thread identifier in which mentions are marked as read
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? messageThreadId}) → ReadAllMessageThreadMentions
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String