ReadChatList class

Inheritance

Constructors

ReadChatList({required ChatList chatList})
Traverse all chats in a chat list and marks all messages in the chats as read
const

Properties

chatList → ChatList
chatList Chat list in which to mark all chats as read
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({ChatList? chatList}) → ReadChatList
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String