RecoverAuthenticationPassword class

Inheritance

Constructors

RecoverAuthenticationPassword({required String recoveryCode, required String newPassword, required String newHint})
Recovers the 2-step verification password with a password recovery code sent to an email address that was previously set up. Works only when the current authorization state is authorizationStateWaitPassword
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
newHint → String
newHint New password hint; may be empty
final
newPassword → String
newPassword New 2-step verification password of the user; may be empty to remove the password
final
recoveryCode → String
recoveryCode Recovery code to check
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? recoveryCode, String? newPassword, String? newHint}) → RecoverAuthenticationPassword
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String