RegisterDevice class

Inheritance

Constructors

RegisterDevice({required DeviceToken deviceToken, required List<int> otherUserIds})
Registers the currently used device for receiving push notifications. Returns a globally unique identifier of the push notification subscription
const

Properties

deviceToken → DeviceToken
deviceToken Device token
final
hashCode → int
The hash code for this object.
no setterinherited
otherUserIds → List<int>
otherUserIds List of user identifiers of other users currently using the application
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({DeviceToken? deviceToken, List<int>? otherUserIds}) → RegisterDevice
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String