RemoveAllFilesFromDownloads class

Inheritance

Constructors

RemoveAllFilesFromDownloads({required bool onlyActive, required bool onlyCompleted, required bool deleteFromCache})
Removes all files from the file download list
const

Properties

deleteFromCache → bool
deleteFromCache Pass true to delete the file from the TDLib file cache
final
hashCode → int
The hash code for this object.
no setterinherited
onlyActive → bool
onlyActive Pass true to remove only active downloads, including paused
final
onlyCompleted → bool
onlyCompleted Pass true to remove only completed downloads
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? onlyActive, bool? onlyCompleted, bool? deleteFromCache}) → RemoveAllFilesFromDownloads
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String