RemoveFavoriteSticker class

Inheritance

Constructors

RemoveFavoriteSticker({required InputFile sticker})
Removes a sticker from the list of favorite stickers
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sticker → InputFile
sticker Sticker file to delete from the list
final

Methods

copyWith({InputFile? sticker}) → RemoveFavoriteSticker
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String