RemoveFileFromDownloads class

Inheritance

Constructors

RemoveFileFromDownloads({required int fileId, required bool deleteFromCache})
Removes a file from the file download list
const

Properties

deleteFromCache → bool
deleteFromCache Pass true to delete the file from the TDLib file cache
final
fileId → int
fileId Identifier of the downloaded file
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? fileId, bool? deleteFromCache}) → RemoveFileFromDownloads
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String