RemoveMessageReaction class

Inheritance

Constructors

RemoveMessageReaction({required int chatId, required int messageId, required ReactionType reactionType})
Removes a reaction from a message. A chosen reaction can always be removed
const

Properties

chatId → int
chatId Identifier of the chat to which the message belongs
final
hashCode → int
The hash code for this object.
no setterinherited
messageId → int
messageId Identifier of the message
final
reactionType → ReactionType
reactionType Type of the reaction to remove
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? messageId, ReactionType? reactionType}) → RemoveMessageReaction
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String