RemoveNotification class

Inheritance

Constructors

RemoveNotification({required int notificationGroupId, required int notificationId})
Removes an active notification from notification list. Needs to be called only if the notification is removed by the current user
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
notificationGroupId → int
notificationGroupId Identifier of notification group to which the notification belongs
final
notificationId → int
notificationId Identifier of removed notification
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? notificationGroupId, int? notificationId}) → RemoveNotification
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String