RemoveNotificationGroup class

Inheritance

Constructors

RemoveNotificationGroup({required int notificationGroupId, required int maxNotificationId})
Removes a group of active notifications. Needs to be called only if the notification group is removed by the current user
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
maxNotificationId → int
maxNotificationId The maximum identifier of removed notifications
final
notificationGroupId → int
notificationGroupId Notification group identifier
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? notificationGroupId, int? maxNotificationId}) → RemoveNotificationGroup
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String