RemoveRecentHashtag class

Inheritance

Constructors

RemoveRecentHashtag({required String hashtag})
Removes a hashtag from the list of recently used hashtags
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
hashtag → String
hashtag Hashtag to delete
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? hashtag}) → RemoveRecentHashtag
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String