RemoveRecentSticker class

Inheritance

Constructors

RemoveRecentSticker({required bool isAttached, required InputFile sticker})
Removes a sticker from the list of recently used stickers
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
isAttached → bool
isAttached Pass true to remove the sticker from the list of stickers recently attached to photo or video files; pass false to remove the sticker from the list of recently sent stickers
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sticker → InputFile
sticker Sticker file to delete
final

Methods

copyWith({bool? isAttached, InputFile? sticker}) → RemoveRecentSticker
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String