ReportChat class

Inheritance

Constructors

ReportChat({required int chatId, required List<int> messageIds, required ReportReason reason, required String text})
Reports a chat to the Telegram moderators. A chat can be reported only from the chat action bar, or if chat.can_be_reported
const

Properties

chatId → int
chatId Chat identifier
final
hashCode → int
The hash code for this object.
no setterinherited
messageIds → List<int>
messageIds Identifiers of reported messages; may be empty to report the whole chat
final
reason → ReportReason
reason The reason for reporting the chat
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String
text Additional report details; 0-1024 characters
final

Methods

copyWith({int? chatId, List<int>? messageIds, ReportReason? reason, String? text}) → ReportChat
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String