ReportChatPhoto class

Inheritance

Constructors

ReportChatPhoto({required int chatId, required int fileId, required ReportReason reason, required String text})
Reports a chat photo to the Telegram moderators. A chat photo can be reported only if chat.can_be_reported
const

Properties

chatId → int
chatId Chat identifier
final
fileId → int
fileId Identifier of the photo to report. Only full photos from chatPhoto can be reported
final
hashCode → int
The hash code for this object.
no setterinherited
reason → ReportReason
reason The reason for reporting the chat photo
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String
text Additional report details; 0-1024 characters
final

Methods

copyWith({int? chatId, int? fileId, ReportReason? reason, String? text}) → ReportChatPhoto
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String