ReportStory class

Inheritance

Constructors

ReportStory({required int storySenderChatId, required int storyId, required ReportReason reason, required String text})
Reports a story to the Telegram moderators
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
reason → ReportReason
reason The reason for reporting the story
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storyId → int
storyId The identifier of the story to report
final
storySenderChatId → int
storySenderChatId The identifier of the sender of the story to report
final
text → String
text Additional report details; 0-1024 characters
final

Methods

copyWith({int? storySenderChatId, int? storyId, ReportReason? reason, String? text}) → ReportStory
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String