ReportSupergroupSpam class

Inheritance

Constructors

ReportSupergroupSpam({required int supergroupId, required List<int> messageIds})
Reports messages in a supergroup as spam; requires administrator rights in the supergroup
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
messageIds → List<int>
messageIds Identifiers of messages to report
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supergroupId → int
supergroupId Supergroup identifier
final

Methods

copyWith({int? supergroupId, List<int>? messageIds}) → ReportSupergroupSpam
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String