ResendMessages class

Inheritance

Constructors

ResendMessages({required int chatId, required List<int> messageIds})
Resends messages which failed to send. Can be called only for messages for which messageSendingStateFailed.can_retry is true and after specified in messageSendingStateFailed.retry_after time passed.. If a message is re-sent, the corresponding failed to send message is deleted. Returns the sent messages in the same order as the message identifiers passed in message_ids. If a message can't be re-sent, null will be returned instead of the message
const

Properties

chatId → int
chatId Identifier of the chat to send messages
final
hashCode → int
The hash code for this object.
no setterinherited
messageIds → List<int>
messageIds Identifiers of the messages to resend. Message identifiers must be in a strictly increasing order
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, List<int>? messageIds}) → ResendMessages
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String