ResetPasswordResultDeclined class

Inheritance

Constructors

ResetPasswordResultDeclined({required int retryDate, dynamic extra, int? clientId})
The password reset request was declined
const
ResetPasswordResultDeclined.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
retryDate → int
retryDate Point in time (Unix timestamp) when the password reset can be retried
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? retryDate, dynamic extra, int? clientId}) → ResetPasswordResultDeclined
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String