ResetPasswordResultPending class

Inheritance

Constructors

ResetPasswordResultPending({required int pendingResetDate, dynamic extra, int? clientId})
The password reset request is pending
const
ResetPasswordResultPending.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
pendingResetDate → int
pendingResetDate Point in time (Unix timestamp) after which the password can be reset immediately using resetPassword
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? pendingResetDate, dynamic extra, int? clientId}) → ResetPasswordResultPending
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String