RevokeChatInviteLink class

Inheritance

Constructors

RevokeChatInviteLink({required int chatId, required String inviteLink})
Revokes invite link for a chat. Available for basic groups, supergroups, and channels. Requires administrator privileges and can_invite_users right in the chat for own links and owner privileges for other links.. If a primary link is revoked, then additionally to the revoked link returns new primary link
const

Properties

chatId → int
chatId Chat identifier
final
hashCode → int
The hash code for this object.
no setterinherited
inviteLink Invite link to be revoked
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, String? inviteLink}) → RevokeChatInviteLink
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String