RichTextAnchorLink class

Inheritance

Constructors

RichTextAnchorLink({required RichText text, required String anchorName, required String url})
A link to an anchor on the same web page
const
RichTextAnchorLink.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

anchorName → String
anchorName The anchor name. If the name is empty, the link must bring back to top
final
clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → RichText
text The link text
final
url → String
url An HTTP URL, opening the anchor
final

Methods

copyWith({RichText? text, String? anchorName, String? url}) → RichTextAnchorLink
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String