RichTextEmailAddress class

Inheritance

Constructors

RichTextEmailAddress({required RichText text, required String emailAddress})
A rich text email link
const
RichTextEmailAddress.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
emailAddress → String
emailAddress Email address
final
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → RichText
text Text
final

Methods

copyWith({RichText? text, String? emailAddress}) → RichTextEmailAddress
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String