RichTextUrl class

Inheritance

Constructors

RichTextUrl({required RichText text, required String url, required bool isCached})
A rich text URL link
const
RichTextUrl.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isCached → bool
isCached True, if the URL has cached instant view server-side
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → RichText
text Text
final
url → String
url URL
final

Methods

copyWith({RichText? text, String? url, bool? isCached}) → RichTextUrl
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String