ScopeAutosaveSettings class

Inheritance

Constructors

ScopeAutosaveSettings({required bool autosavePhotos, required bool autosaveVideos, required int maxVideoFileSize})
Contains autosave settings for an autosave settings scope
const
ScopeAutosaveSettings.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

autosavePhotos → bool
autosavePhotos True, if photo autosave is enabled
final
autosaveVideos → bool
autosaveVideos True, if video autosave is enabled
final
clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
maxVideoFileSize → int
maxVideoFileSize The maximum size of a video file to be autosaved, in bytes; 512 KB - 4000 MB
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? autosavePhotos, bool? autosaveVideos, int? maxVideoFileSize}) → ScopeAutosaveSettings
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String