SearchCallMessages class

Inheritance

Constructors

SearchCallMessages({required String offset, required int limit, required bool onlyMissed})
Searches for call messages. Returns the results in reverse chronological order (i.e., in order of decreasing message_id). For optimal performance, the number of returned messages is chosen by TDLib
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
limit → int
limit The maximum number of messages to be returned; up to 100. For optimal performance, the number of returned messages is chosen by TDLib and can be smaller than the specified limit
final
offset → String
offset Offset of the first entry to return as received from the previous request; use empty string to get the first chunk of results
final
onlyMissed → bool
onlyMissed Pass true to search only for messages with missed/declined calls
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? offset, int? limit, bool? onlyMissed}) → SearchCallMessages
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String