SearchChatRecentLocationMessages class

Inheritance

Constructors

SearchChatRecentLocationMessages({required int chatId, required int limit})
Returns information about the recent locations of chat members that were sent to the chat. Returns up to 1 location message per user
const

Properties

chatId → int
chatId Chat identifier
final
hashCode → int
The hash code for this object.
no setterinherited
limit → int
limit The maximum number of messages to be returned
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? limit}) → SearchChatRecentLocationMessages
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String