SearchChats class

Inheritance

Constructors

SearchChats({required String query, required int limit})
Searches for the specified query in the title and username of already known chats; this is an offline request. Returns chats in the order seen in the main chat list
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
limit → int
limit The maximum number of chats to be returned
final
query → String
query Query to search for. If the query is empty, returns up to 50 recently found chats
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? query, int? limit}) → SearchChats
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String