SearchFileDownloads class

Inheritance

Constructors

SearchFileDownloads({required String query, required bool onlyActive, required bool onlyCompleted, required String offset, required int limit})
Searches for files in the file download list or recently downloaded files from the list
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
limit → int
limit The maximum number of files to be returned
final
offset → String
offset Offset of the first entry to return as received from the previous request; use empty string to get the first chunk of results
final
onlyActive → bool
onlyActive Pass true to search only for active downloads, including paused
final
onlyCompleted → bool
onlyCompleted Pass true to search only for completed downloads
final
query → String
query Query to search for; may be empty to return all downloaded files
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? query, bool? onlyActive, bool? onlyCompleted, String? offset, int? limit}) → SearchFileDownloads
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String