SearchInstalledStickerSets class

Inheritance

Constructors

SearchInstalledStickerSets({required StickerType stickerType, required String query, required int limit})
Searches for installed sticker sets by looking for specified query in their title and name
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
limit → int
limit The maximum number of sticker sets to return
final
query → String
query Query to search for
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stickerType → StickerType
stickerType Type of the sticker sets to search for
final

Methods

copyWith({StickerType? stickerType, String? query, int? limit}) → SearchInstalledStickerSets
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String