SearchMessages class

Inheritance

Constructors

SearchMessages({ChatList? chatList, required String query, required String offset, required int limit, SearchMessagesFilter? filter, required int minDate, required int maxDate})
Searches for messages in all chats except secret chats. Returns the results in reverse chronological order (i.e., in order of decreasing (date, chat_id, message_id)).. For optimal performance, the number of returned messages is chosen by TDLib and can be smaller than the specified limit
const

Properties

chatList → ChatList?
chatList Chat list in which to search messages; pass null to search in all chats regardless of their chat list. Only Main and Archive chat lists are supported
final
filter → SearchMessagesFilter?
filter Additional filter for messages to search; pass null to search for all messages. Filters searchMessagesFilterMention, searchMessagesFilterUnreadMention, searchMessagesFilterUnreadReaction, searchMessagesFilterFailedToSend, and searchMessagesFilterPinned are unsupported in this function
final
hashCode → int
The hash code for this object.
no setterinherited
limit → int
limit The maximum number of messages to be returned; up to 100. For optimal performance, the number of returned messages is chosen by TDLib and can be smaller than the specified limit
final
maxDate → int
maxDate If not 0, the maximum date of the messages to return
final
minDate → int
minDate If not 0, the minimum date of the messages to return
final
offset → String
offset Offset of the first entry to return as received from the previous request; use empty string to get the first chunk of results
final
query → String
query Query to search for
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({ChatList? chatList, String? query, String? offset, int? limit, SearchMessagesFilter? filter, int? minDate, int? maxDate}) → SearchMessages
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String