SearchPublicChats class

Inheritance

Constructors

SearchPublicChats({required String query})
Searches public chats by looking for specified query in their username and title. Currently, only private chats, supergroups and channels can be public. Returns a meaningful number of results.. Excludes private chats with contacts and chats from the chat list from the results
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
query → String
query Query to search for
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? query}) → SearchPublicChats
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String