SearchStickerSet class

Inheritance

Constructors

SearchStickerSet({required String name})
Searches for a sticker set by its name
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
name Name of the sticker set
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? name}) → SearchStickerSet
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String