SearchStickerSets class

Inheritance

Constructors

SearchStickerSets({required String query})
Searches for ordinary sticker sets by looking for specified query in their title and name. Excludes installed sticker sets from the results
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
query → String
query Query to search for
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? query}) → SearchStickerSets
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String