SearchWebApp class

Inheritance

Constructors

SearchWebApp({required int botUserId, required String webAppShortName})
Returns information about a Web App by its short name. Returns a 404 error if the Web App is not found
const

Properties

botUserId → int
botUserId Identifier of the target bot
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
webAppShortName → String
webAppShortName Short name of the Web App
final

Methods

copyWith({int? botUserId, String? webAppShortName}) → SearchWebApp
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String