SendCallDebugInformation class

Inheritance

Constructors

SendCallDebugInformation({required int callId, required String debugInformation})
Sends debug information for a call to Telegram servers
const

Properties

callId → int
callId Call identifier
final
debugInformation → String
debugInformation Debug information in application-specific format
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? callId, String? debugInformation}) → SendCallDebugInformation
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String