SendCallLog class

Inheritance

Constructors

SendCallLog({required int callId, required InputFile logFile})
Sends log file for a call to Telegram servers
const

Properties

callId → int
callId Call identifier
final
hashCode → int
The hash code for this object.
no setterinherited
logFile → InputFile
logFile Call log file. Only inputFileLocal and inputFileGenerated are supported
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? callId, InputFile? logFile}) → SendCallLog
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String