SendChatAction class

Inheritance

Constructors

SendChatAction({required int chatId, required int messageThreadId, ChatAction? action})
Sends a notification about user activity in a chat
const

Properties

action → ChatAction?
action The action description; pass null to cancel the currently active action
final
chatId → int
chatId Chat identifier
final
hashCode → int
The hash code for this object.
no setterinherited
messageThreadId → int
messageThreadId If not 0, a message thread identifier in which the action was performed
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? messageThreadId, ChatAction? action}) → SendChatAction
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String