SendCustomRequest class

Inheritance

Constructors

SendCustomRequest({required String method, required String parameters})
Sends a custom request; for bots only
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
method → String
method The method name
final
parameters → String
parameters JSON-serialized method parameters
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? method, String? parameters}) → SendCustomRequest
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String