SendInlineQueryResultMessage class

Inheritance

Constructors

SendInlineQueryResultMessage({required int chatId, required int messageThreadId, MessageReplyTo? replyTo, MessageSendOptions? options, required int queryId, required String resultId, required bool hideViaBot})
Sends the result of an inline query as a message. Returns the sent message. Always clears a chat draft message
const

Properties

chatId → int
chatId Target chat
final
hashCode → int
The hash code for this object.
no setterinherited
hideViaBot → bool
hideViaBot Pass true to hide the bot, via which the message is sent. Can be used only for bots getOption("animation_search_bot_username"), getOption("photo_search_bot_username"), and getOption("venue_search_bot_username")
final
messageThreadId → int
messageThreadId If not 0, a message thread identifier in which the message will be sent
final
options → MessageSendOptions?
options Options to be used to send the message; pass null to use default options
final
queryId → int
queryId Identifier of the inline query
final
replyTo → MessageReplyTo?
replyTo Identifier of the replied message or story; pass null if none
final
resultId → String
resultId Identifier of the inline result
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? messageThreadId, MessageReplyTo? replyTo, MessageSendOptions? options, int? queryId, String? resultId, bool? hideViaBot}) → SendInlineQueryResultMessage
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String