SendMessage class

Inheritance

Constructors

SendMessage({required int chatId, required int messageThreadId, MessageReplyTo? replyTo, MessageSendOptions? options, ReplyMarkup? replyMarkup, required InputMessageContent inputMessageContent})
Sends a message. Returns the sent message
const

Properties

chatId → int
chatId Target chat
final
hashCode → int
The hash code for this object.
no setterinherited
inputMessageContent → InputMessageContent
inputMessageContent The content of the message to be sent
final
messageThreadId → int
messageThreadId If not 0, a message thread identifier in which the message will be sent
final
options → MessageSendOptions?
options Options to be used to send the message; pass null to use default options
final
replyMarkup → ReplyMarkup?
replyMarkup Markup for replying to the message; pass null if none; for bots only
final
replyTo → MessageReplyTo?
replyTo Identifier of the replied message or story; pass null if none
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? messageThreadId, MessageReplyTo? replyTo, MessageSendOptions? options, ReplyMarkup? replyMarkup, InputMessageContent? inputMessageContent}) → SendMessage
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String