SendPhoneNumberConfirmationCode class

Inheritance

Constructors

SendPhoneNumberConfirmationCode({required String hash, required String phoneNumber, PhoneNumberAuthenticationSettings? settings})
Sends phone number confirmation code to handle links of the type internalLinkTypePhoneNumberConfirmation
const

Properties

hash → String
hash Hash value from the link
final
hashCode → int
The hash code for this object.
no setterinherited
phoneNumber → String
phoneNumber Phone number value from the link
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
settings → PhoneNumberAuthenticationSettings?
settings Settings for the authentication of the user's phone number; pass null to use default settings
final

Methods

copyWith({String? hash, String? phoneNumber, PhoneNumberAuthenticationSettings? settings}) → SendPhoneNumberConfirmationCode
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String