SendStory class

Inheritance

Constructors

SendStory({required InputStoryContent content, FormattedText? caption, required StoryPrivacySettings privacySettings, required int activePeriod, required bool isPinned, required bool protectContent})
Sends a new story. Returns a temporary story with identifier 0
const

Properties

activePeriod → int
activePeriod Period after which the story is moved to archive, in seconds; must be one of 6 * 3600, 12 * 3600, 86400, 2 * 86400, 3 * 86400, or 7 * 86400 for Telegram Premium users, and 86400 otherwise
final
caption → FormattedText?
caption Story caption; pass null to use an empty caption; 0-getOption("story_caption_length_max") characters
final
content → InputStoryContent
content Content of the story
final
hashCode → int
The hash code for this object.
no setterinherited
isPinned → bool
isPinned Pass true to keep the story accessible after expiration
final
privacySettings → StoryPrivacySettings
privacySettings The privacy settings for the story
final
protectContent → bool
protectContent Pass true if the content of the story must be protected from forwarding and screenshotting
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({InputStoryContent? content, FormattedText? caption, StoryPrivacySettings? privacySettings, int? activePeriod, bool? isPinned, bool? protectContent}) → SendStory
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String