SendWebAppData class

Inheritance

Constructors

SendWebAppData({required int botUserId, required String buttonText, required String data})
Sends data received from a keyboardButtonTypeWebApp Web App to a bot
const

Properties

botUserId → int
botUserId Identifier of the target bot
final
buttonText → String
buttonText Text of the keyboardButtonTypeWebApp button, which opened the Web App
final
data → String
data The data
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? botUserId, String? buttonText, String? data}) → SendWebAppData
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String