Sessions class

Inheritance

Constructors

Sessions({required List<Session> sessions, required int inactiveSessionTtlDays, dynamic extra, int? clientId})
Contains a list of sessions
const
Sessions.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
inactiveSessionTtlDays → int
inactiveSessionTtlDays Number of days of inactivity before sessions will automatically be terminated; 1-366 days
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessions → List<Session>
sessions List of sessions
final

Methods

copyWith({List<Session>? sessions, int? inactiveSessionTtlDays, dynamic extra, int? clientId}) → Sessions
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String