SetAccountTtl class

Inheritance

Constructors

SetAccountTtl({required AccountTtl ttl})
Changes the period of inactivity after which the account of the current user will automatically be deleted
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
ttl → AccountTtl
ttl New account TTL
final

Methods

copyWith({AccountTtl? ttl}) → SetAccountTtl
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String