SetArchiveChatListSettings class

Inheritance

Constructors

SetArchiveChatListSettings({required ArchiveChatListSettings settings})
Changes settings for automatic moving of chats to and from the Archive chat lists
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
settings → ArchiveChatListSettings
settings New settings
final

Methods

copyWith({ArchiveChatListSettings? settings}) → SetArchiveChatListSettings
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String