SetAutoDownloadSettings class

Inheritance

Constructors

SetAutoDownloadSettings({required AutoDownloadSettings settings, required NetworkType type})
Sets auto-download settings
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
settings → AutoDownloadSettings
settings New user auto-download settings
final
type → NetworkType
type Type of the network for which the new settings are relevant
final

Methods

copyWith({AutoDownloadSettings? settings, NetworkType? type}) → SetAutoDownloadSettings
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String