SetAutosaveSettings class

Inheritance

Constructors

SetAutosaveSettings({required AutosaveSettingsScope scope, ScopeAutosaveSettings? settings})
Sets autosave settings for the given scope. The method is guaranteed to work only after at least one call to getAutosaveSettings
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope → AutosaveSettingsScope
scope Autosave settings scope
final
settings → ScopeAutosaveSettings?
settings New autosave settings for the scope; pass null to set autosave settings to default
final

Methods

copyWith({AutosaveSettingsScope? scope, ScopeAutosaveSettings? settings}) → SetAutosaveSettings
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String