SetBotName class

Inheritance

Constructors

SetBotName({required int botUserId, required String languageCode, required String name})
Sets the name of a bot. Can be called only if userTypeBot.can_be_edited == true
const

Properties

botUserId → int
botUserId Identifier of the target bot
final
hashCode → int
The hash code for this object.
no setterinherited
languageCode → String
languageCode A two-letter ISO 639-1 language code. If empty, the name will be shown to all users for whose languages there is no dedicated name
final
name → String
name New bot's name on the specified language; 0-64 characters; must be non-empty if language code is empty
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? botUserId, String? languageCode, String? name}) → SetBotName
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String