SetBotProfilePhoto class

Inheritance

Constructors

SetBotProfilePhoto({required int botUserId, InputChatPhoto? photo})
Changes a profile photo for a bot
const

Properties

botUserId → int
botUserId Identifier of the target bot
final
hashCode → int
The hash code for this object.
no setterinherited
photo → InputChatPhoto?
photo Profile photo to set; pass null to delete the chat photo
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? botUserId, InputChatPhoto? photo}) → SetBotProfilePhoto
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String