SetBotUpdatesStatus class

Inheritance

Constructors

SetBotUpdatesStatus({required int pendingUpdateCount, required String errorMessage})
Informs the server about the number of pending bot updates if they haven't been processed for a long time; for bots only
const

Properties

errorMessage → String
errorMessage The last error message
final
hashCode → int
The hash code for this object.
no setterinherited
pendingUpdateCount → int
pendingUpdateCount The number of pending updates
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? pendingUpdateCount, String? errorMessage}) → SetBotUpdatesStatus
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String