SetChatActiveStoriesList class

Inheritance

Constructors

SetChatActiveStoriesList({required int chatId, required StoryList storyList})
Changes story list in which stories from the chat are shown
const

Properties

chatId → int
chatId Identifier of the chat that posted stories
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storyList → StoryList
storyList New list for active stories posted by the chat
final

Methods

copyWith({int? chatId, StoryList? storyList}) → SetChatActiveStoriesList
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String