SetChatAvailableReactions class

Inheritance

Constructors

SetChatAvailableReactions({required int chatId, required ChatAvailableReactions availableReactions})
Changes reactions, available in a chat. Available for basic groups, supergroups, and channels. Requires can_change_info administrator right
const

Properties

availableReactions → ChatAvailableReactions
availableReactions Reactions available in the chat. All emoji reactions must be active
final
chatId → int
chatId Identifier of the chat
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, ChatAvailableReactions? availableReactions}) → SetChatAvailableReactions
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String