SetChatDescription class

Inheritance

Constructors

SetChatDescription({required int chatId, required String description})
Changes information about a chat. Available for basic groups, supergroups, and channels. Requires can_change_info administrator right
const

Properties

chatId → int
chatId Identifier of the chat
final
description → String
description New chat description; 0-255 characters
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, String? description}) → SetChatDescription
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String