SetChatDraftMessage class

Inheritance

Constructors

SetChatDraftMessage({required int chatId, required int messageThreadId, DraftMessage? draftMessage})
Changes the draft message in a chat
const

Properties

chatId → int
chatId Chat identifier
final
draftMessage → DraftMessage?
draftMessage New draft message; pass null to remove the draft
final
hashCode → int
The hash code for this object.
no setterinherited
messageThreadId → int
messageThreadId If not 0, a message thread identifier in which the draft was changed
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? messageThreadId, DraftMessage? draftMessage}) → SetChatDraftMessage
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String