SetChatMemberStatus class

Inheritance

Constructors

SetChatMemberStatus({required int chatId, required MessageSender memberId, required ChatMemberStatus status})
Changes the status of a chat member, needs appropriate privileges. This function is currently not suitable for transferring chat ownership; use transferChatOwnership instead. Use addChatMember or banChatMember if some additional parameters needs to be passed
const

Properties

chatId → int
chatId Chat identifier
final
hashCode → int
The hash code for this object.
no setterinherited
memberId → MessageSender
memberId Member identifier. Chats can be only banned and unbanned in supergroups and channels
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → ChatMemberStatus
status The new status of the member in the chat
final

Methods

copyWith({int? chatId, MessageSender? memberId, ChatMemberStatus? status}) → SetChatMemberStatus
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String