SetChatNotificationSettings class

Inheritance

Constructors

SetChatNotificationSettings({required int chatId, required ChatNotificationSettings notificationSettings})
Changes the notification settings of a chat. Notification settings of a chat with the current user (Saved Messages) can't be changed
const

Properties

chatId → int
chatId Chat identifier
final
hashCode → int
The hash code for this object.
no setterinherited
notificationSettings → ChatNotificationSettings
notificationSettings New notification settings for the chat. If the chat is muted for more than 366 days, it is considered to be muted forever
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, ChatNotificationSettings? notificationSettings}) → SetChatNotificationSettings
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String