SetChatPhoto class

Inheritance

Constructors

SetChatPhoto({required int chatId, InputChatPhoto? photo})
Changes the photo of a chat. Supported only for basic groups, supergroups and channels. Requires can_change_info administrator right
const

Properties

chatId → int
chatId Chat identifier
final
hashCode → int
The hash code for this object.
no setterinherited
photo → InputChatPhoto?
photo New chat photo; pass null to delete the chat photo
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, InputChatPhoto? photo}) → SetChatPhoto
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String