SetCustomEmojiStickerSetThumbnail class

Inheritance

Constructors

SetCustomEmojiStickerSetThumbnail({required String name, required int customEmojiId})
Sets a custom emoji sticker set thumbnail; for bots only
const

Properties

customEmojiId → int
customEmojiId Identifier of the custom emoji from the sticker set, which will be set as sticker set thumbnail; pass 0 to remove the sticker set thumbnail
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
name Sticker set name
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? name, int? customEmojiId}) → SetCustomEmojiStickerSetThumbnail
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String