SetDatabaseEncryptionKey class

Inheritance

Constructors

SetDatabaseEncryptionKey({required String newEncryptionKey})
Changes the database encryption key. Usually the encryption key is never changed and is stored in some OS keychain
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
newEncryptionKey → String
newEncryptionKey New encryption key
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? newEncryptionKey}) → SetDatabaseEncryptionKey
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String