SetDefaultMessageAutoDeleteTime class

Inheritance

Constructors

SetDefaultMessageAutoDeleteTime({required MessageAutoDeleteTime messageAutoDeleteTime})
Changes the default message auto-delete time for new chats
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
messageAutoDeleteTime → MessageAutoDeleteTime
messageAutoDeleteTime New default message auto-delete time; must be from 0 up to 365 * 86400 and be divisible by 86400. If 0, then messages aren't deleted automatically
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({MessageAutoDeleteTime? messageAutoDeleteTime}) → SetDefaultMessageAutoDeleteTime
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String