SetForumTopicNotificationSettings class

Inheritance

Constructors

SetForumTopicNotificationSettings({required int chatId, required int messageThreadId, required ChatNotificationSettings notificationSettings})
Changes the notification settings of a forum topic
const

Properties

chatId → int
chatId Chat identifier
final
hashCode → int
The hash code for this object.
no setterinherited
messageThreadId → int
messageThreadId Message thread identifier of the forum topic
final
notificationSettings → ChatNotificationSettings
notificationSettings New notification settings for the forum topic. If the topic is muted for more than 366 days, it is considered to be muted forever
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? messageThreadId, ChatNotificationSettings? notificationSettings}) → SetForumTopicNotificationSettings
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String