SetInactiveSessionTtl class

Inheritance

Constructors

SetInactiveSessionTtl({required int inactiveSessionTtlDays})
Changes the period of inactivity after which sessions will automatically be terminated
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
inactiveSessionTtlDays → int
inactiveSessionTtlDays New number of days of inactivity before sessions will be automatically terminated; 1-366 days
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? inactiveSessionTtlDays}) → SetInactiveSessionTtl
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String