SetInlineGameScore class

Inheritance

Constructors

SetInlineGameScore({required String inlineMessageId, required bool editMessage, required int userId, required int score, required bool force})
Updates the game score of the specified user in a game; for bots only
const

Properties

editMessage → bool
editMessage Pass true to edit the game message to include the current scoreboard
final
force → bool
force Pass true to update the score even if it decreases. If the score is 0, the user will be deleted from the high score table
final
hashCode → int
The hash code for this object.
no setterinherited
inlineMessageId → String
inlineMessageId Inline message identifier
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
score → int
score The new score
final
userId → int
userId User identifier
final

Methods

copyWith({String? inlineMessageId, bool? editMessage, int? userId, int? score, bool? force}) → SetInlineGameScore
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String