SetLogStream class

Inheritance

Constructors

SetLogStream({required LogStream logStream})
Sets new log stream for internal logging of TDLib. Can be called synchronously
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
logStream → LogStream
logStream New log stream
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({LogStream? logStream}) → SetLogStream
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String