SetLogTagVerbosityLevel class

Inheritance

Constructors

SetLogTagVerbosityLevel({required String tag, required int newVerbosityLevel})
Sets the verbosity level for a specified TDLib internal log tag. Can be called synchronously
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
newVerbosityLevel → int
newVerbosityLevel New verbosity level; 1-1024
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tag → String
tag Logging tag to change verbosity level
final

Methods

copyWith({String? tag, int? newVerbosityLevel}) → SetLogTagVerbosityLevel
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String