SetLogVerbosityLevel class

Inheritance

Constructors

SetLogVerbosityLevel({required int newVerbosityLevel})
Sets the verbosity level of the internal logging of TDLib. Can be called synchronously
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
newVerbosityLevel → int
newVerbosityLevel New value of the verbosity level for logging. Value 0 corresponds to fatal errors, value 1 corresponds to errors, value 2 corresponds to warnings and debug warnings,. value 3 corresponds to informational, value 4 corresponds to debug, value 5 corresponds to verbose debug, value greater than 5 and up to 1023 can be used to enable even more logging
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? newVerbosityLevel}) → SetLogVerbosityLevel
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String