SetMenuButton class

Inheritance

Constructors

SetMenuButton({required int userId, required BotMenuButton menuButton})
Sets menu button for the given user or for all users; for bots only
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
menuButton New menu button
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userId → int
userId Identifier of the user or 0 to set menu button for all users
final

Methods

copyWith({int? userId, BotMenuButton? menuButton}) → SetMenuButton
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String