SetOption class

Inheritance

Constructors

SetOption({required String name, OptionValue? value})
Sets the value of an option. (Check the list of available options on https://core.telegram.org/tdlib/options.) Only writable options can be set. Can be called before authorization
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
name The name of the option
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → OptionValue?
value The new value of the option; pass null to reset option value to a default value
final

Methods

copyWith({String? name, OptionValue? value}) → SetOption
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String