SetPassportElementErrors class

Inheritance

Constructors

SetPassportElementErrors({required int userId, required List<InputPassportElementError> errors})
Informs the user that some of the elements in their Telegram Passport contain errors; for bots only. The user will not be able to resend the elements, until the errors are fixed
const

Properties

errors → List<InputPassportElementError>
errors The errors
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userId → int
userId User identifier
final

Methods

copyWith({int? userId, List<InputPassportElementError>? errors}) → SetPassportElementErrors
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String