SetPassword class

Inheritance

Constructors

SetPassword({required String oldPassword, required String newPassword, required String newHint, required bool setRecoveryEmailAddress, required String newRecoveryEmailAddress})
Changes the 2-step verification password for the current user. If a new recovery email address is specified, then the change will not be applied until the new recovery email address is confirmed
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
newHint → String
newHint New password hint; may be empty
final
newPassword → String
newPassword New 2-step verification password of the user; may be empty to remove the password
final
newRecoveryEmailAddress → String
newRecoveryEmailAddress New recovery email address; may be empty
final
oldPassword → String
oldPassword Previous 2-step verification password of the user
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
setRecoveryEmailAddress → bool
setRecoveryEmailAddress Pass true to change also the recovery email address
final

Methods

copyWith({String? oldPassword, String? newPassword, String? newHint, bool? setRecoveryEmailAddress, String? newRecoveryEmailAddress}) → SetPassword
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String