SetPinnedChats class

Inheritance

Constructors

SetPinnedChats({required ChatList chatList, required List<int> chatIds})
Changes the order of pinned chats
const

Properties

chatIds → List<int>
chatIds The new list of pinned chats
final
chatList → ChatList
chatList Chat list in which to change the order of pinned chats
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({ChatList? chatList, List<int>? chatIds}) → SetPinnedChats
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String