SetPollAnswer class

Inheritance

Constructors

SetPollAnswer({required int chatId, required int messageId, required List<int> optionIds})
Changes the user answer to a poll. A poll in quiz mode can be answered only once
const

Properties

chatId → int
chatId Identifier of the chat to which the poll belongs
final
hashCode → int
The hash code for this object.
no setterinherited
messageId → int
messageId Identifier of the message containing the poll
final
optionIds → List<int>
optionIds 0-based identifiers of answer options, chosen by the user. User can choose more than 1 answer option only is the poll allows multiple answers
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? messageId, List<int>? optionIds}) → SetPollAnswer
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String