SetProfilePhoto class

Inheritance

Constructors

SetProfilePhoto({required InputChatPhoto photo, required bool isPublic})
Changes a profile photo for the current user
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
isPublic → bool
isPublic Pass true to set a public photo, which will be visible even the main photo is hidden by privacy settings
final
photo → InputChatPhoto
photo Profile photo to set
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({InputChatPhoto? photo, bool? isPublic}) → SetProfilePhoto
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String