SetRecoveryEmailAddress class

Inheritance

Constructors

SetRecoveryEmailAddress({required String password, required String newRecoveryEmailAddress})
Changes the 2-step verification recovery email address of the user. If a new recovery email address is specified, then the change will not be applied until the new recovery email address is confirmed.. If new_recovery_email_address is the same as the email address that is currently set up, this call succeeds immediately and aborts all other requests waiting for an email confirmation
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
newRecoveryEmailAddress → String
newRecoveryEmailAddress New recovery email address
final
password → String
password The 2-step verification password of the current user
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? password, String? newRecoveryEmailAddress}) → SetRecoveryEmailAddress
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String