SetStickerEmojis class

Inheritance

Constructors

SetStickerEmojis({required InputFile sticker, required String emojis})
Changes the list of emoji corresponding to a sticker; for bots only. The sticker must belong to a regular or custom emoji sticker set created by the bot
const

Properties

emojis → String
emojis New string with 1-20 emoji corresponding to the sticker
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sticker → InputFile
sticker Sticker
final

Methods

copyWith({InputFile? sticker, String? emojis}) → SetStickerEmojis
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String