SetStickerKeywords class

Inheritance

Constructors

SetStickerKeywords({required InputFile sticker, required List<String> keywords})
Changes the list of keywords of a sticker; for bots only. The sticker must belong to a regular or custom emoji sticker set created by the bot
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
keywords → List<String>
keywords List of up to 20 keywords with total length up to 64 characters, which can be used to find the sticker
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sticker → InputFile
sticker Sticker
final

Methods

copyWith({InputFile? sticker, List<String>? keywords}) → SetStickerKeywords
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String