SetStickerMaskPosition class

Inheritance

Constructors

SetStickerMaskPosition({required InputFile sticker, MaskPosition? maskPosition})
Changes the mask position of a mask sticker; for bots only. The sticker must belong to a mask sticker set created by the bot
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
maskPosition → MaskPosition?
maskPosition Position where the mask is placed; pass null to remove mask position
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sticker → InputFile
sticker Sticker
final

Methods

copyWith({InputFile? sticker, MaskPosition? maskPosition}) → SetStickerMaskPosition
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String