SetStickerPositionInSet class

Inheritance

Constructors

SetStickerPositionInSet({required InputFile sticker, required int position})
Changes the position of a sticker in the set to which it belongs; for bots only. The sticker set must have been created by the bot
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
position → int
position New position of the sticker in the set, 0-based
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sticker → InputFile
sticker Sticker
final

Methods

copyWith({InputFile? sticker, int? position}) → SetStickerPositionInSet
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String