SetStickerSetThumbnail class

Inheritance

Constructors

SetStickerSetThumbnail({required int userId, required String name, InputFile? thumbnail})
Sets a sticker set thumbnail; for bots only
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
name Sticker set name
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thumbnail → InputFile?
thumbnail Thumbnail to set in PNG, TGS, or WEBM format; pass null to remove the sticker set thumbnail. Thumbnail format must match the format of stickers in the set
final
userId → int
userId Sticker set owner
final

Methods

copyWith({int? userId, String? name, InputFile? thumbnail}) → SetStickerSetThumbnail
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String