SetStoryPrivacySettings class

Inheritance

Constructors

SetStoryPrivacySettings({required int storyId, required StoryPrivacySettings privacySettings})
Changes privacy settings of a previously sent story
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
privacySettings → StoryPrivacySettings
privacySettings The new privacy settigs for the story
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storyId → int
storyId Identifier of the story
final

Methods

copyWith({int? storyId, StoryPrivacySettings? privacySettings}) → SetStoryPrivacySettings
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String