SetSupergroupStickerSet class

Inheritance

Constructors

SetSupergroupStickerSet({required int supergroupId, required int stickerSetId})
Changes the sticker set of a supergroup; requires can_change_info administrator right
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stickerSetId → int
stickerSetId New value of the supergroup sticker set identifier. Use 0 to remove the supergroup sticker set
final
supergroupId → int
supergroupId Identifier of the supergroup
final

Methods

copyWith({int? supergroupId, int? stickerSetId}) → SetSupergroupStickerSet
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String