SetUserPersonalProfilePhoto class

Inheritance

Constructors

SetUserPersonalProfilePhoto({required int userId, InputChatPhoto? photo})
Changes a personal profile photo of a contact user
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
photo → InputChatPhoto?
photo Profile photo to set; pass null to delete the photo; inputChatPhotoPrevious isn't supported in this function
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userId → int
userId User identifier
final

Methods

copyWith({int? userId, InputChatPhoto? photo}) → SetUserPersonalProfilePhoto
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String