SetUserPrivacySettingRules class

Inheritance

Constructors

SetUserPrivacySettingRules({required UserPrivacySetting setting, required UserPrivacySettingRules rules})
Changes user privacy settings
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
rules → UserPrivacySettingRules
rules The new privacy rules
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
setting → UserPrivacySetting
setting The privacy setting
final

Methods

copyWith({UserPrivacySetting? setting, UserPrivacySettingRules? rules}) → SetUserPrivacySettingRules
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String