SetVideoChatDefaultParticipant class

Inheritance

Constructors

SetVideoChatDefaultParticipant({required int chatId, required MessageSender defaultParticipantId})
Changes default participant identifier, on whose behalf a video chat in the chat will be joined
const

Properties

chatId → int
chatId Chat identifier
final
defaultParticipantId → MessageSender
defaultParticipantId Default group call participant identifier to join the video chats
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, MessageSender? defaultParticipantId}) → SetVideoChatDefaultParticipant
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String