ShareUserWithBot class

Inheritance

Constructors

ShareUserWithBot({required int chatId, required int messageId, required int buttonId, required int sharedUserId, required bool onlyCheck})
Shares a user after pressing a keyboardButtonTypeRequestUser button with the bot
const

Properties

buttonId → int
buttonId Identifier of the button
final
chatId → int
chatId Identifier of the chat with the bot
final
hashCode → int
The hash code for this object.
no setterinherited
messageId → int
messageId Identifier of the message with the button
final
onlyCheck → bool
onlyCheck Pass true to check that the user can be shared by the button instead of actually sharing them
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sharedUserId → int
sharedUserId Identifier of the shared user
final

Methods

copyWith({int? chatId, int? messageId, int? buttonId, int? sharedUserId, bool? onlyCheck}) → ShareUserWithBot
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String