StartGroupCallRecording class

Inheritance

Constructors

StartGroupCallRecording({required int groupCallId, required String title, required bool recordVideo, required bool usePortraitOrientation})
Starts recording of an active group call. Requires groupCall.can_be_managed group call flag
const

Properties

groupCallId → int
groupCallId Group call identifier
final
hashCode → int
The hash code for this object.
no setterinherited
recordVideo → bool
recordVideo Pass true to record a video file instead of an audio file
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
title Group call recording title; 0-64 characters
final
usePortraitOrientation → bool
usePortraitOrientation Pass true to use portrait orientation for video instead of landscape one
final

Methods

copyWith({int? groupCallId, String? title, bool? recordVideo, bool? usePortraitOrientation}) → StartGroupCallRecording
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String