StartGroupCallScreenSharing class

Inheritance

Constructors

StartGroupCallScreenSharing({required int groupCallId, required int audioSourceId, required String payload})
Starts screen sharing in a joined group call. Returns join response payload for tgcalls
const

Properties

audioSourceId → int
audioSourceId Screen sharing audio channel synchronization source identifier; received from tgcalls
final
groupCallId → int
groupCallId Group call identifier
final
hashCode → int
The hash code for this object.
no setterinherited
payload → String
payload Group call join payload; received from tgcalls
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? groupCallId, int? audioSourceId, String? payload}) → StartGroupCallScreenSharing
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String