StatisticalGraphData class

Inheritance

Constructors

StatisticalGraphData({required String jsonData, required String zoomToken, dynamic extra, int? clientId})
A graph data
const
StatisticalGraphData.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
jsonData → String
jsonData Graph data in JSON format
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
zoomToken → String
zoomToken If non-empty, a token which can be used to receive a zoomed in graph
final

Methods

copyWith({String? jsonData, String? zoomToken, dynamic extra, int? clientId}) → StatisticalGraphData
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String