Sticker class

Inheritance

Constructors

Sticker({required int id, required int setId, required int width, required int height, required String emoji, required StickerFormat format, required StickerFullType fullType, required List<ClosedVectorPath> outline, Thumbnail? thumbnail, required File sticker, dynamic extra, int? clientId})
Describes a sticker
const
Sticker.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
emoji → String
emoji Emoji corresponding to the sticker
final
extra → dynamic
extra callback sign
final
format → StickerFormat
format Sticker format
final
fullType → StickerFullType
fullType Sticker's full type
final
hashCode → int
The hash code for this object.
no setterinherited
height → int
height Sticker height; as defined by the sender
final
id → int
id Unique sticker identifier within the set; 0 if none
final
outline → List<ClosedVectorPath>
outline Sticker's outline represented as a list of closed vector paths; may be empty. The coordinate system origin is in the upper-left corner
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
setId → int
setId Identifier of the sticker set to which the sticker belongs; 0 if none
final
sticker → File
sticker File containing the sticker
final
thumbnail → Thumbnail?
thumbnail Sticker thumbnail in WEBP or JPEG format; may be null
final
width → int
width Sticker width; as defined by the sender
final

Methods

copyWith({int? id, int? setId, int? width, int? height, String? emoji, StickerFormat? format, StickerFullType? fullType, List<ClosedVectorPath>? outline, Thumbnail? thumbnail, File? sticker, dynamic extra, int? clientId}) → Sticker
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String