StickerFullTypeRegular class

Inheritance

Constructors

StickerFullTypeRegular({File? premiumAnimation})
The sticker is a regular sticker
const
StickerFullTypeRegular.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
premiumAnimation → File?
premiumAnimation Premium animation of the sticker; may be null. If present, only Telegram Premium users can use the sticker
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({File? premiumAnimation}) → StickerFullTypeRegular
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String