StickerSet class

Inheritance

Constructors

StickerSet({required int id, required String title, required String name, Thumbnail? thumbnail, required List<ClosedVectorPath> thumbnailOutline, required bool isInstalled, required bool isArchived, required bool isOfficial, required StickerFormat stickerFormat, required StickerType stickerType, required bool isViewed, required List<Sticker> stickers, required List<Emojis> emojis, dynamic extra, int? clientId})
Represents a sticker set
const
StickerSet.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
emojis → List<Emojis>
emojis A list of emoji corresponding to the stickers in the same order. The list is only for informational purposes, because a sticker is always sent with a fixed emoji from the corresponding Sticker object
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
id → int
id Identifier of the sticker set
final
isArchived → bool
isArchived True, if the sticker set has been archived. A sticker set can't be installed and archived simultaneously
final
isInstalled → bool
isInstalled True, if the sticker set has been installed by the current user
final
isOfficial → bool
isOfficial True, if the sticker set is official
final
isViewed → bool
isViewed True for already viewed trending sticker sets
final
name → String
name Name of the sticker set
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stickerFormat → StickerFormat
stickerFormat Format of the stickers in the set
final
stickers → List<Sticker>
stickers List of stickers in this set
final
stickerType → StickerType
stickerType Type of the stickers in the set
final
thumbnail → Thumbnail?
thumbnail Sticker set thumbnail in WEBP, TGS, or WEBM format with width and height 100; may be null. The file can be downloaded only before the thumbnail is changed
final
thumbnailOutline → List<ClosedVectorPath>
thumbnailOutline Sticker set thumbnail's outline represented as a list of closed vector paths; may be empty. The coordinate system origin is in the upper-left corner
final
title → String
title Title of the sticker set
final

Methods

copyWith({int? id, String? title, String? name, Thumbnail? thumbnail, List<ClosedVectorPath>? thumbnailOutline, bool? isInstalled, bool? isArchived, bool? isOfficial, StickerFormat? stickerFormat, StickerType? stickerType, bool? isViewed, List<Sticker>? stickers, List<Emojis>? emojis, dynamic extra, int? clientId}) → StickerSet
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String