StickerSetInfo class

Inheritance

Constructors

StickerSetInfo({required int id, required String title, required String name, Thumbnail? thumbnail, required List<ClosedVectorPath> thumbnailOutline, required bool isInstalled, required bool isArchived, required bool isOfficial, required StickerFormat stickerFormat, required StickerType stickerType, required bool isViewed, required int size, required List<Sticker> covers})
Represents short information about a sticker set
const
StickerSetInfo.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
covers → List<Sticker>
covers Up to the first 5 stickers from the set, depending on the context. If the application needs more stickers the full sticker set needs to be requested
final
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → int
id Identifier of the sticker set
final
isArchived → bool
isArchived True, if the sticker set has been archived. A sticker set can't be installed and archived simultaneously
final
isInstalled → bool
isInstalled True, if the sticker set has been installed by the current user
final
isOfficial → bool
isOfficial True, if the sticker set is official
final
isViewed → bool
isViewed True for already viewed trending sticker sets
final
name → String
name Name of the sticker set
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → int
size Total number of stickers in the set
final
stickerFormat → StickerFormat
stickerFormat Format of the stickers in the set
final
stickerType → StickerType
stickerType Type of the stickers in the set
final
thumbnail → Thumbnail?
thumbnail Sticker set thumbnail in WEBP, TGS, or WEBM format with width and height 100; may be null
final
thumbnailOutline → List<ClosedVectorPath>
thumbnailOutline Sticker set thumbnail's outline represented as a list of closed vector paths; may be empty. The coordinate system origin is in the upper-left corner
final
title → String
title Title of the sticker set
final

Methods

copyWith({int? id, String? title, String? name, Thumbnail? thumbnail, List<ClosedVectorPath>? thumbnailOutline, bool? isInstalled, bool? isArchived, bool? isOfficial, StickerFormat? stickerFormat, StickerType? stickerType, bool? isViewed, int? size, List<Sticker>? covers}) → StickerSetInfo
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String