StickerSets class

Inheritance

Constructors

StickerSets({required int totalCount, required List<StickerSetInfo> sets, dynamic extra, int? clientId})
Represents a list of sticker sets
const
StickerSets.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sets → List<StickerSetInfo>
sets List of sticker sets
final
totalCount → int
totalCount Approximate total number of sticker sets found
final

Methods

copyWith({int? totalCount, List<StickerSetInfo>? sets, dynamic extra, int? clientId}) → StickerSets
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String