StorageStatistics class

Inheritance

Constructors

StorageStatistics({required int size, required int count, required List<StorageStatisticsByChat> byChat, dynamic extra, int? clientId})
Contains the exact storage usage statistics split by chats and file type
const
StorageStatistics.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

byChat → List<StorageStatisticsByChat>
byChat Statistics split by chats
final
clientId → int?
clientId client identifier
final
count → int
count Total number of files
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → int
size Total size of files, in bytes
final

Methods

copyWith({int? size, int? count, List<StorageStatisticsByChat>? byChat, dynamic extra, int? clientId}) → StorageStatistics
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String