StorageStatisticsByFileType class

Inheritance

Constructors

StorageStatisticsByFileType({required FileType fileType, required int size, required int count})
Contains the storage usage statistics for a specific file type
const
StorageStatisticsByFileType.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
count → int
count Total number of files
final
extra → dynamic
callback sign
no setterinherited
fileType → FileType
fileType File type
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → int
size Total size of the files, in bytes
final

Methods

copyWith({FileType? fileType, int? size, int? count}) → StorageStatisticsByFileType
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String