StorageStatisticsFast class

Inheritance

Constructors

StorageStatisticsFast({required int filesSize, required int fileCount, required int databaseSize, required int languagePackDatabaseSize, required int logSize, dynamic extra, int? clientId})
Contains approximate storage usage statistics, excluding files of unknown file type
const
StorageStatisticsFast.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
databaseSize → int
databaseSize Size of the database
final
extra → dynamic
extra callback sign
final
fileCount → int
fileCount Approximate number of files
final
filesSize → int
filesSize Approximate total size of files, in bytes
final
hashCode → int
The hash code for this object.
no setterinherited
languagePackDatabaseSize → int
languagePackDatabaseSize Size of the language pack database
final
logSize → int
logSize Size of the TDLib internal log
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? filesSize, int? fileCount, int? databaseSize, int? languagePackDatabaseSize, int? logSize, dynamic extra, int? clientId}) → StorageStatisticsFast
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String