StorePaymentPurposeGiftedPremium class

Inheritance

Constructors

StorePaymentPurposeGiftedPremium({required int userId, required String currency, required int amount})
The user gifted Telegram Premium to another user
const
StorePaymentPurposeGiftedPremium.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

amount → int
amount Paid amount, in the smallest units of the currency
final
clientId → int?
client identifier
no setterinherited
currency → String
currency ISO 4217 currency code of the payment currency
final
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userId → int
userId Identifier of the user for which Premium was gifted
final

Methods

copyWith({int? userId, String? currency, int? amount}) → StorePaymentPurposeGiftedPremium
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String