StoryInfo class

Inheritance

Constructors

StoryInfo({required int storyId, required int date, required bool isForCloseFriends})
Contains basic information about a story
const
StoryInfo.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
date → int
date Point in time (Unix timestamp) when the story was published
final
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isForCloseFriends → bool
isForCloseFriends True, if the story is available only to close friends
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storyId → int
storyId Unique story identifier among stories of the given sender
final

Methods

copyWith({int? storyId, int? date, bool? isForCloseFriends}) → StoryInfo
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String