StoryInteractionInfo class

Inheritance

Constructors

StoryInteractionInfo({required int viewCount, required List<int> recentViewerUserIds})
Contains information about interactions with a story
const
StoryInteractionInfo.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
recentViewerUserIds → List<int>
recentViewerUserIds Identifiers of at most 3 recent viewers of the story
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
viewCount → int
viewCount Number of times the story was viewed
final

Methods

copyWith({int? viewCount, List<int>? recentViewerUserIds}) → StoryInteractionInfo
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String