StoryPrivacySettingsSelectedContacts class

Inheritance

Constructors

StoryPrivacySettingsSelectedContacts({required List<int> userIds})
The story can be viewed by certain specified users
const
StoryPrivacySettingsSelectedContacts.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userIds → List<int>
userIds Identifiers of the users; always empty for non-owned stories
final

Methods

copyWith({List<int>? userIds}) → StoryPrivacySettingsSelectedContacts
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String