StoryVideo class

Inheritance

Constructors

StoryVideo({required double duration, required int width, required int height, required bool hasStickers, required bool isAnimation, Minithumbnail? minithumbnail, Thumbnail? thumbnail, required int preloadPrefixSize, required File video})
Describes a video file sent in a story
const
StoryVideo.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
duration → double
duration Duration of the video, in seconds
final
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hasStickers → bool
hasStickers True, if stickers were added to the video. The list of corresponding sticker sets can be received using getAttachedStickerSets
final
height → int
height Video height
final
isAnimation → bool
isAnimation True, if the video has no sound
final
minithumbnail → Minithumbnail?
minithumbnail Video minithumbnail; may be null
final
preloadPrefixSize → int
preloadPrefixSize Size of file prefix, which is supposed to be preloaded, in bytes
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thumbnail → Thumbnail?
thumbnail Video thumbnail in JPEG or MPEG4 format; may be null
final
video → File
video File containing the video
final
width → int
width Video width
final

Methods

copyWith({double? duration, int? width, int? height, bool? hasStickers, bool? isAnimation, Minithumbnail? minithumbnail, Thumbnail? thumbnail, int? preloadPrefixSize, File? video}) → StoryVideo
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String