TargetChatChosen class

Inheritance

Constructors

TargetChatChosen({required bool allowUserChats, required bool allowBotChats, required bool allowGroupChats, required bool allowChannelChats})
The chat needs to be chosen by the user among chats of the specified types
const
TargetChatChosen.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

allowBotChats → bool
allowBotChats True, if private chats with other bots are allowed
final
allowChannelChats → bool
allowChannelChats True, if channel chats are allowed
final
allowGroupChats → bool
allowGroupChats True, if basic group and supergroup chats are allowed
final
allowUserChats → bool
allowUserChats True, if private chats with ordinary users are allowed
final
clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? allowUserChats, bool? allowBotChats, bool? allowGroupChats, bool? allowChannelChats}) → TargetChatChosen
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String