TdObject<T> class abstract

Implementers

Constructors

TdObject()
const
TdObject.fromJson(Map<String, dynamic> json)

Properties

clientId → int?
client identifier
no setter
extra → dynamic
callback sign
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited