TemporaryPasswordState class

Inheritance

Constructors

TemporaryPasswordState({required bool hasPassword, required int validFor, dynamic extra, int? clientId})
Returns information about the availability of a temporary password, which can be used for payments
const
TemporaryPasswordState.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
hasPassword → bool
hasPassword True, if a temporary password is available
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
validFor → int
validFor Time left before the temporary password expires, in seconds
final

Methods

copyWith({bool? hasPassword, int? validFor, dynamic extra, int? clientId}) → TemporaryPasswordState
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String