TermsOfService class

Inheritance

Constructors

TermsOfService({required FormattedText text, required int minUserAge, required bool showPopup})
Contains Telegram terms of service
const
TermsOfService.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
minUserAge → int
minUserAge The minimum age of a user to be able to accept the terms; 0 if age isn't restricted
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showPopup → bool
showPopup True, if a blocking popup with terms of service must be shown to the user
final
text → FormattedText
text Text of the terms of service
final

Methods

copyWith({FormattedText? text, int? minUserAge, bool? showPopup}) → TermsOfService
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String