TestCallVectorStringObject class

Inheritance

Constructors

TestCallVectorStringObject({required List<TestString> x})
Returns the received vector of objects containing a string; for testing only. This is an offline method. Can be called before authorization
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
x → List<TestString>
x Vector of objects to return
final

Methods

copyWith({List<TestString>? x}) → TestCallVectorStringObject
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String