TestProxy class

Inheritance

Constructors

TestProxy({required String server, required int port, required ProxyType type, required int dcId, required double timeout})
Sends a simple network request to the Telegram servers via proxy; for testing only. Can be called before authorization
const

Properties

dcId → int
dcId Identifier of a datacenter with which to test connection
final
hashCode → int
The hash code for this object.
no setterinherited
port → int
port Proxy server port
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
server → String
server Proxy server IP address
final
timeout → double
timeout The maximum overall timeout for the request
final
type → ProxyType
type Proxy type
final

Methods

copyWith({String? server, int? port, ProxyType? type, int? dcId, double? timeout}) → TestProxy
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String