TextEntityTypeCustomEmoji class

Inheritance

Constructors

TextEntityTypeCustomEmoji({required int customEmojiId})
A custom emoji. The text behind a custom emoji must be an emoji. Only premium users can use premium custom emoji
const
TextEntityTypeCustomEmoji.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
customEmojiId → int
customEmojiId Unique identifier of the custom emoji
final
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? customEmojiId}) → TextEntityTypeCustomEmoji
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String