TextEntityTypeTextUrl class

Inheritance

Constructors

TextEntityTypeTextUrl({required String url})
A text description shown instead of a raw URL
const
TextEntityTypeTextUrl.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → String
url HTTP or tg:// URL to be opened when the link is clicked
final

Methods

copyWith({String? url}) → TextEntityTypeTextUrl
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String