ThemeSettings class

Inheritance

Constructors

ThemeSettings({required int accentColor, Background? background, required BackgroundFill outgoingMessageFill, required bool animateOutgoingMessageFill, required int outgoingMessageAccentColor})
Describes theme settings
const
ThemeSettings.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

accentColor → int
accentColor Theme accent color in ARGB format
final
animateOutgoingMessageFill → bool
animateOutgoingMessageFill If true, the freeform gradient fill needs to be animated on every sent message
final
background → Background?
background The background to be used in chats; may be null
final
clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
outgoingMessageAccentColor → int
outgoingMessageAccentColor Accent color of outgoing messages in ARGB format
final
outgoingMessageFill → BackgroundFill
outgoingMessageFill The fill to be used as a background for outgoing messages
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? accentColor, Background? background, BackgroundFill? outgoingMessageFill, bool? animateOutgoingMessageFill, int? outgoingMessageAccentColor}) → ThemeSettings
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String