Thumbnail class

Inheritance

Constructors

Thumbnail({required ThumbnailFormat format, required int width, required int height, required File file})
Represents a thumbnail
const
Thumbnail.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
file → File
file The thumbnail
final
format → ThumbnailFormat
format Thumbnail format
final
hashCode → int
The hash code for this object.
no setterinherited
height → int
height Thumbnail height
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → int
width Thumbnail width
final

Methods

copyWith({ThumbnailFormat? format, int? width, int? height, File? file}) → Thumbnail
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String