ToggleBotIsAddedToAttachmentMenu class

Inheritance

Constructors

ToggleBotIsAddedToAttachmentMenu({required int botUserId, required bool isAdded, required bool allowWriteAccess})
Adds or removes a bot to attachment menu. Bot can be added to attachment menu, only if userTypeBot.can_be_added_to_attachment_menu == true
const

Properties

allowWriteAccess → bool
allowWriteAccess Pass true if the current user allowed the bot to send them messages. Ignored if is_added is false
final
botUserId → int
botUserId Bot's user identifier
final
hashCode → int
The hash code for this object.
no setterinherited
isAdded → bool
isAdded Pass true to add the bot to attachment menu; pass false to remove the bot from attachment menu
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? botUserId, bool? isAdded, bool? allowWriteAccess}) → ToggleBotIsAddedToAttachmentMenu
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String