ToggleBotUsernameIsActive class

Inheritance

Constructors

ToggleBotUsernameIsActive({required int botUserId, required String username, required bool isActive})
Changes active state for a username of a bot. The editable username can't be disabled. May return an error with a message "USERNAMES_ACTIVE_TOO_MUCH" if the maximum number of active usernames has been reached. Can be called only if userTypeBot.can_be_edited == true
const

Properties

botUserId → int
botUserId Identifier of the target bot
final
hashCode → int
The hash code for this object.
no setterinherited
isActive → bool
isActive Pass true to activate the username; pass false to disable it
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
username → String
username The username to change
final

Methods

copyWith({int? botUserId, String? username, bool? isActive}) → ToggleBotUsernameIsActive
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String