ToggleChatHasProtectedContent class

Inheritance

Constructors

ToggleChatHasProtectedContent({required int chatId, required bool hasProtectedContent})
Changes the ability of users to save, forward, or copy chat content. Supported only for basic groups, supergroups and channels. Requires owner privileges
const

Properties

chatId → int
chatId Chat identifier
final
hashCode → int
The hash code for this object.
no setterinherited
hasProtectedContent → bool
hasProtectedContent New value of has_protected_content
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, bool? hasProtectedContent}) → ToggleChatHasProtectedContent
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String