ToggleChatIsTranslatable class

Inheritance

Constructors

ToggleChatIsTranslatable({required int chatId, required bool isTranslatable})
Changes the translatable state of a chat; for Telegram Premium users only
const

Properties

chatId → int
chatId Chat identifier
final
hashCode → int
The hash code for this object.
no setterinherited
isTranslatable → bool
isTranslatable New value of is_translatable
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, bool? isTranslatable}) → ToggleChatIsTranslatable
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String