ToggleForumTopicIsClosed class

Inheritance

Constructors

ToggleForumTopicIsClosed({required int chatId, required int messageThreadId, required bool isClosed})
Toggles whether a topic is closed in a forum supergroup chat; requires can_manage_topics administrator right in the supergroup unless the user is creator of the topic
const

Properties

chatId → int
chatId Identifier of the chat
final
hashCode → int
The hash code for this object.
no setterinherited
isClosed → bool
isClosed Pass true to close the topic; pass false to reopen it
final
messageThreadId → int
messageThreadId Message thread identifier of the forum topic
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? messageThreadId, bool? isClosed}) → ToggleForumTopicIsClosed
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String