ToggleForumTopicIsPinned class

Inheritance

Constructors

ToggleForumTopicIsPinned({required int chatId, required int messageThreadId, required bool isPinned})
Changes the pinned state of a forum topic; requires can_manage_topics administrator right in the supergroup. There can be up to getOption("pinned_forum_topic_count_max") pinned forum topics
const

Properties

chatId → int
chatId Chat identifier
final
hashCode → int
The hash code for this object.
no setterinherited
isPinned → bool
isPinned Pass true to pin the topic; pass false to unpin it
final
messageThreadId → int
messageThreadId Message thread identifier of the forum topic
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? messageThreadId, bool? isPinned}) → ToggleForumTopicIsPinned
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String