ToggleGroupCallEnabledStartNotification class

Inheritance

Constructors

ToggleGroupCallEnabledStartNotification({required int groupCallId, required bool enabledStartNotification})
Toggles whether the current user will receive a notification when the group call will start; scheduled group calls only
const

Properties

enabledStartNotification → bool
enabledStartNotification New value of the enabled_start_notification setting
final
groupCallId → int
groupCallId Group call identifier
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? groupCallId, bool? enabledStartNotification}) → ToggleGroupCallEnabledStartNotification
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String