ToggleGroupCallIsMyVideoEnabled class

Inheritance

Constructors

ToggleGroupCallIsMyVideoEnabled({required int groupCallId, required bool isMyVideoEnabled})
Toggles whether current user's video is enabled
const

Properties

groupCallId → int
groupCallId Group call identifier
final
hashCode → int
The hash code for this object.
no setterinherited
isMyVideoEnabled → bool
isMyVideoEnabled Pass true if the current user's video is enabled
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? groupCallId, bool? isMyVideoEnabled}) → ToggleGroupCallIsMyVideoEnabled
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String