ToggleGroupCallMuteNewParticipants class

Inheritance

Constructors

ToggleGroupCallMuteNewParticipants({required int groupCallId, required bool muteNewParticipants})
Toggles whether new participants of a group call can be unmuted only by administrators of the group call. Requires groupCall.can_toggle_mute_new_participants group call flag
const

Properties

groupCallId → int
groupCallId Group call identifier
final
hashCode → int
The hash code for this object.
no setterinherited
muteNewParticipants → bool
muteNewParticipants New value of the mute_new_participants setting
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? groupCallId, bool? muteNewParticipants}) → ToggleGroupCallMuteNewParticipants
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String