ToggleGroupCallParticipantIsHandRaised class

Inheritance

Constructors

ToggleGroupCallParticipantIsHandRaised({required int groupCallId, required MessageSender participantId, required bool isHandRaised})
Toggles whether a group call participant hand is rased
const

Properties

groupCallId → int
groupCallId Group call identifier
final
hashCode → int
The hash code for this object.
no setterinherited
isHandRaised → bool
isHandRaised Pass true if the user's hand needs to be raised. Only self hand can be raised. Requires groupCall.can_be_managed group call flag to lower other's hand
final
participantId → MessageSender
participantId Participant identifier
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? groupCallId, MessageSender? participantId, bool? isHandRaised}) → ToggleGroupCallParticipantIsHandRaised
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String