ToggleGroupCallParticipantIsMuted class

Inheritance

Constructors

ToggleGroupCallParticipantIsMuted({required int groupCallId, required MessageSender participantId, required bool isMuted})
Toggles whether a participant of an active group call is muted, unmuted, or allowed to unmute themselves
const

Properties

groupCallId → int
groupCallId Group call identifier
final
hashCode → int
The hash code for this object.
no setterinherited
isMuted → bool
isMuted Pass true to mute the user; pass false to unmute them
final
participantId → MessageSender
participantId Participant identifier
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? groupCallId, MessageSender? participantId, bool? isMuted}) → ToggleGroupCallParticipantIsMuted
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String