ToggleGroupCallScreenSharingIsPaused class

Inheritance

Constructors

ToggleGroupCallScreenSharingIsPaused({required int groupCallId, required bool isPaused})
Pauses or unpauses screen sharing in a joined group call
const

Properties

groupCallId → int
groupCallId Group call identifier
final
hashCode → int
The hash code for this object.
no setterinherited
isPaused → bool
isPaused Pass true to pause screen sharing; pass false to unpause it
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? groupCallId, bool? isPaused}) → ToggleGroupCallScreenSharingIsPaused
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String