ToggleMessageSenderIsBlocked class

Inheritance

Constructors

ToggleMessageSenderIsBlocked({required MessageSender senderId, required bool isBlocked})
Changes the block state of a message sender. Currently, only users and supergroup chats can be blocked
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
isBlocked → bool
isBlocked New value of is_blocked
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
senderId → MessageSender
senderId Identifier of a message sender to block/unblock
final

Methods

copyWith({MessageSender? senderId, bool? isBlocked}) → ToggleMessageSenderIsBlocked
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String