ToggleSessionCanAcceptCalls class

Inheritance

Constructors

ToggleSessionCanAcceptCalls({required int sessionId, required bool canAcceptCalls})
Toggles whether a session can accept incoming calls
const

Properties

canAcceptCalls → bool
canAcceptCalls Pass true to allow accepting incoming calls by the session; pass false otherwise
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionId → int
sessionId Session identifier
final

Methods

copyWith({int? sessionId, bool? canAcceptCalls}) → ToggleSessionCanAcceptCalls
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String