ToggleStoryIsPinned class

Inheritance

Constructors

ToggleStoryIsPinned({required int storyId, required bool isPinned})
Toggles whether a story is accessible after expiration
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
isPinned → bool
isPinned Pass true to make the story accessible after expiration; pass false to make it private
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storyId → int
storyId Identifier of the story
final

Methods

copyWith({int? storyId, bool? isPinned}) → ToggleStoryIsPinned
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String