ToggleSupergroupIsBroadcastGroup class

Inheritance

Constructors

ToggleSupergroupIsBroadcastGroup({required int supergroupId})
Upgrades supergroup to a broadcast group; requires owner privileges in the supergroup
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supergroupId → int
supergroupId Identifier of the supergroup
final

Methods

copyWith({int? supergroupId}) → ToggleSupergroupIsBroadcastGroup
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String