ToggleSupergroupJoinByRequest class

Inheritance

Constructors

ToggleSupergroupJoinByRequest({required int supergroupId, required bool joinByRequest})
Toggles whether all users directly joining the supergroup need to be approved by supergroup administrators; requires can_restrict_members administrator right
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
joinByRequest → bool
joinByRequest New value of join_by_request
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supergroupId → int
supergroupId Identifier of the channel
final

Methods

copyWith({int? supergroupId, bool? joinByRequest}) → ToggleSupergroupJoinByRequest
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String