ToggleSupergroupSignMessages class

Inheritance

Constructors

ToggleSupergroupSignMessages({required int supergroupId, required bool signMessages})
Toggles whether sender signature is added to sent messages in a channel; requires can_change_info administrator right
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signMessages → bool
signMessages New value of sign_messages
final
supergroupId → int
supergroupId Identifier of the channel
final

Methods

copyWith({int? supergroupId, bool? signMessages}) → ToggleSupergroupSignMessages
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String