TrendingStickerSets class

Inheritance

Constructors

TrendingStickerSets({required int totalCount, required List<StickerSetInfo> sets, required bool isPremium, dynamic extra, int? clientId})
Represents a list of trending sticker sets
const
TrendingStickerSets.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
isPremium → bool
isPremium True, if the list contains sticker sets with premium stickers
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sets → List<StickerSetInfo>
sets List of trending sticker sets
final
totalCount → int
totalCount Approximate total number of trending sticker sets
final

Methods

copyWith({int? totalCount, List<StickerSetInfo>? sets, bool? isPremium, dynamic extra, int? clientId}) → TrendingStickerSets
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String