UnpinAllMessageThreadMessages class

Inheritance

Constructors

UnpinAllMessageThreadMessages({required int chatId, required int messageThreadId})
Removes all pinned messages from a forum topic; requires can_pin_messages rights in the supergroup
const

Properties

chatId → int
chatId Identifier of the chat
final
hashCode → int
The hash code for this object.
no setterinherited
messageThreadId → int
messageThreadId Message thread identifier in which messages will be unpinned
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? messageThreadId}) → UnpinAllMessageThreadMessages
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String