UnpinChatMessage class

Inheritance

Constructors

UnpinChatMessage({required int chatId, required int messageId})
Removes a pinned message from a chat; requires can_pin_messages rights in the group or can_edit_messages rights in the channel
const

Properties

chatId → int
chatId Identifier of the chat
final
hashCode → int
The hash code for this object.
no setterinherited
messageId → int
messageId Identifier of the removed pinned message
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? messageId}) → UnpinChatMessage
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String