UnreadReaction class

Inheritance

Constructors

UnreadReaction({required ReactionType type, required MessageSender senderId, required bool isBig})
Contains information about an unread reaction to a message
const
UnreadReaction.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isBig → bool
isBig True, if the reaction was added with a big animation
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
senderId → MessageSender
senderId Identifier of the sender, added the reaction
final
type → ReactionType
type Type of the reaction
final

Methods

copyWith({ReactionType? type, MessageSender? senderId, bool? isBig}) → UnreadReaction
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String