UpdateBasicGroup class

Inheritance

Constructors

UpdateBasicGroup({required BasicGroup basicGroup, dynamic extra, int? clientId})
Some data of a basic group has changed. This update is guaranteed to come before the basic group identifier is returned to the application
const
UpdateBasicGroup.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

basicGroup → BasicGroup
basicGroup New data about the group
final
clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({BasicGroup? basicGroup, dynamic extra, int? clientId}) → UpdateBasicGroup
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String