UpdateBasicGroupFullInfo class

Inheritance

Constructors

UpdateBasicGroupFullInfo({required int basicGroupId, required BasicGroupFullInfo basicGroupFullInfo, dynamic extra, int? clientId})
Some data in basicGroupFullInfo has been changed
const
UpdateBasicGroupFullInfo.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

basicGroupFullInfo → BasicGroupFullInfo
basicGroupFullInfo New full information about the group
final
basicGroupId → int
basicGroupId Identifier of a basic group
final
clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? basicGroupId, BasicGroupFullInfo? basicGroupFullInfo, dynamic extra, int? clientId}) → UpdateBasicGroupFullInfo
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String