UpdateCall class

Inheritance

Constructors

UpdateCall({required Call call, dynamic extra, int? clientId})
New call was created or information about a call was updated
const
UpdateCall.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

call → Call
call New data about a call
final
clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Call? call, dynamic extra, int? clientId}) → UpdateCall
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String