UpdateChatAction class

Inheritance

Constructors

UpdateChatAction({required int chatId, required int messageThreadId, required MessageSender senderId, required ChatAction action, dynamic extra, int? clientId})
A message sender activity in the chat has changed
const
UpdateChatAction.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

action → ChatAction
action The action
final
chatId → int
chatId Chat identifier
final
clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
messageThreadId → int
messageThreadId If not 0, a message thread identifier in which the action was performed
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
senderId → MessageSender
senderId Identifier of a message sender performing the action
final

Methods

copyWith({int? chatId, int? messageThreadId, MessageSender? senderId, ChatAction? action, dynamic extra, int? clientId}) → UpdateChatAction
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String