UpdateChatHasProtectedContent class

Inheritance

Constructors

UpdateChatHasProtectedContent({required int chatId, required bool hasProtectedContent, dynamic extra, int? clientId})
A chat content was allowed or restricted for saving
const
UpdateChatHasProtectedContent.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

chatId → int
chatId Chat identifier
final
clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
hasProtectedContent → bool
hasProtectedContent New value of has_protected_content
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, bool? hasProtectedContent, dynamic extra, int? clientId}) → UpdateChatHasProtectedContent
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String