UpdateChatHasScheduledMessages class

Inheritance

Constructors

UpdateChatHasScheduledMessages({required int chatId, required bool hasScheduledMessages, dynamic extra, int? clientId})
A chat's has_scheduled_messages field has changed
const
UpdateChatHasScheduledMessages.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

chatId → int
chatId Chat identifier
final
clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
hasScheduledMessages → bool
hasScheduledMessages New value of has_scheduled_messages
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, bool? hasScheduledMessages, dynamic extra, int? clientId}) → UpdateChatHasScheduledMessages
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String