UpdateChatIsMarkedAsUnread class

Inheritance

Constructors

UpdateChatIsMarkedAsUnread({required int chatId, required bool isMarkedAsUnread, dynamic extra, int? clientId})
A chat was marked as unread or was read
const
UpdateChatIsMarkedAsUnread.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

chatId → int
chatId Chat identifier
final
clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
isMarkedAsUnread → bool
isMarkedAsUnread New value of is_marked_as_unread
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, bool? isMarkedAsUnread, dynamic extra, int? clientId}) → UpdateChatIsMarkedAsUnread
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String