UpdateChatIsTranslatable class

Inheritance

Constructors

UpdateChatIsTranslatable({required int chatId, required bool isTranslatable, dynamic extra, int? clientId})
Translation of chat messages was enabled or disabled
const
UpdateChatIsTranslatable.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

chatId → int
chatId Chat identifier
final
clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
isTranslatable → bool
isTranslatable New value of is_translatable
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, bool? isTranslatable, dynamic extra, int? clientId}) → UpdateChatIsTranslatable
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String