UpdateChatLastMessage class

Inheritance

Constructors

UpdateChatLastMessage({required int chatId, Message? lastMessage, required List<ChatPosition> positions, dynamic extra, int? clientId})
The last message of a chat was changed. If last_message is null, then the last message in the chat became unknown. Some new unknown messages might be added to the chat in this case
const
UpdateChatLastMessage.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

chatId → int
chatId Chat identifier
final
clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
lastMessage → Message?
lastMessage The new last message in the chat; may be null
final
positions → List<ChatPosition>
positions The new chat positions in the chat lists
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, Message? lastMessage, List<ChatPosition>? positions, dynamic extra, int? clientId}) → UpdateChatLastMessage
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String