UpdateChatMember class

Inheritance

Constructors

UpdateChatMember({required int chatId, required int actorUserId, required int date, ChatInviteLink? inviteLink, required bool viaChatFolderInviteLink, required ChatMember oldChatMember, required ChatMember newChatMember, dynamic extra, int? clientId})
User rights changed in a chat; for bots only
const
UpdateChatMember.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

actorUserId → int
actorUserId Identifier of the user, changing the rights
final
chatId → int
chatId Chat identifier
final
clientId → int?
clientId client identifier
final
date → int
date Point in time (Unix timestamp) when the user rights was changed
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
inviteLink If user has joined the chat using an invite link, the invite link; may be null
final
newChatMember → ChatMember
newChatMember New chat member
final
oldChatMember → ChatMember
oldChatMember Previous chat member
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
viaChatFolderInviteLink True, if the user has joined the chat using an invite link for a chat folder
final

Methods

copyWith({int? chatId, int? actorUserId, int? date, ChatInviteLink? inviteLink, bool? viaChatFolderInviteLink, ChatMember? oldChatMember, ChatMember? newChatMember, dynamic extra, int? clientId}) → UpdateChatMember
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String