UpdateChatUnreadReactionCount class

Inheritance

Constructors

UpdateChatUnreadReactionCount({required int chatId, required int unreadReactionCount, dynamic extra, int? clientId})
The chat unread_reaction_count has changed
const
UpdateChatUnreadReactionCount.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

chatId → int
chatId Chat identifier
final
clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unreadReactionCount → int
unreadReactionCount The number of messages with unread reactions left in the chat
final

Methods

copyWith({int? chatId, int? unreadReactionCount, dynamic extra, int? clientId}) → UpdateChatUnreadReactionCount
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String