UpdateConnectionState class

Inheritance

Constructors

UpdateConnectionState({required ConnectionState state, dynamic extra, int? clientId})
The connection state has changed. This update must be used only to show a human-readable description of the connection state
const
UpdateConnectionState.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → ConnectionState
state The new connection state
final

Methods

copyWith({ConnectionState? state, dynamic extra, int? clientId}) → UpdateConnectionState
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String