UpdateDeleteMessages class

Inheritance

Constructors

UpdateDeleteMessages({required int chatId, required List<int> messageIds, required bool isPermanent, required bool fromCache, dynamic extra, int? clientId})
Some messages were deleted
const
UpdateDeleteMessages.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

chatId → int
chatId Chat identifier
final
clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
fromCache → bool
fromCache True, if the messages are deleted only from the cache and can possibly be retrieved again in the future
final
hashCode → int
The hash code for this object.
no setterinherited
isPermanent → bool
isPermanent True, if the messages are permanently deleted by a user (as opposed to just becoming inaccessible)
final
messageIds → List<int>
messageIds Identifiers of the deleted messages
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, List<int>? messageIds, bool? isPermanent, bool? fromCache, dynamic extra, int? clientId}) → UpdateDeleteMessages
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String