UpdateFileAddedToDownloads class

Inheritance

Constructors

UpdateFileAddedToDownloads({required FileDownload fileDownload, required DownloadedFileCounts counts, dynamic extra, int? clientId})
A file was added to the file download list. This update is sent only after file download list is loaded for the first time
const
UpdateFileAddedToDownloads.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
counts → DownloadedFileCounts
counts New number of being downloaded and recently downloaded files found
final
extra → dynamic
extra callback sign
final
fileDownload → FileDownload
fileDownload The added file download
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({FileDownload? fileDownload, DownloadedFileCounts? counts, dynamic extra, int? clientId}) → UpdateFileAddedToDownloads
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String