UpdateFileDownload class

Inheritance

Constructors

UpdateFileDownload({required int fileId, required int completeDate, required bool isPaused, required DownloadedFileCounts counts, dynamic extra, int? clientId})
A file download was changed. This update is sent only after file download list is loaded for the first time
const
UpdateFileDownload.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
completeDate → int
completeDate Point in time (Unix timestamp) when the file downloading was completed; 0 if the file downloading isn't completed
final
counts → DownloadedFileCounts
counts New number of being downloaded and recently downloaded files found
final
extra → dynamic
extra callback sign
final
fileId → int
fileId File identifier
final
hashCode → int
The hash code for this object.
no setterinherited
isPaused → bool
isPaused True, if downloading of the file is paused
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? fileId, int? completeDate, bool? isPaused, DownloadedFileCounts? counts, dynamic extra, int? clientId}) → UpdateFileDownload
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String