UpdateFileDownloads class

Inheritance

Constructors

UpdateFileDownloads({required int totalSize, required int totalCount, required int downloadedSize, dynamic extra, int? clientId})
The state of the file download list has changed
const
UpdateFileDownloads.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
downloadedSize → int
downloadedSize Total downloaded size of files in the file download list, in bytes
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalCount → int
totalCount Total number of files in the file download list
final
totalSize → int
totalSize Total size of files in the file download list, in bytes
final

Methods

copyWith({int? totalSize, int? totalCount, int? downloadedSize, dynamic extra, int? clientId}) → UpdateFileDownloads
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String