UpdateFileGenerationStart class

Inheritance

Constructors

UpdateFileGenerationStart({required int generationId, required String originalPath, required String destinationPath, required String conversion, dynamic extra, int? clientId})
The file generation process needs to be started by the application
const
UpdateFileGenerationStart.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
conversion → String
conversion String specifying the conversion applied to the original file. If conversion is "#url#" than original_path contains an HTTP/HTTPS URL of a file, which must be downloaded by the application
final
destinationPath → String
destinationPath The path to a file that must be created and where the new file is generated
final
extra → dynamic
extra callback sign
final
generationId → int
generationId Unique identifier for the generation process
final
hashCode → int
The hash code for this object.
no setterinherited
originalPath → String
originalPath The path to a file from which a new file is generated; may be empty
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? generationId, String? originalPath, String? destinationPath, String? conversion, dynamic extra, int? clientId}) → UpdateFileGenerationStart
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String