UpdateFileGenerationStop class

Inheritance

Constructors

UpdateFileGenerationStop({required int generationId, dynamic extra, int? clientId})
File generation is no longer needed
const
UpdateFileGenerationStop.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
generationId → int
generationId Unique identifier for the generation process
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? generationId, dynamic extra, int? clientId}) → UpdateFileGenerationStop
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String