UpdateHavePendingNotifications class

Inheritance

Constructors

UpdateHavePendingNotifications({required bool haveDelayedNotifications, required bool haveUnreceivedNotifications, dynamic extra, int? clientId})
Describes whether there are some pending notification updates. Can be used to prevent application from killing, while there are some pending notifications
const
UpdateHavePendingNotifications.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
haveDelayedNotifications → bool
haveDelayedNotifications True, if there are some delayed notification updates, which will be sent soon
final
haveUnreceivedNotifications → bool
haveUnreceivedNotifications True, if there can be some yet unreceived notifications, which are being fetched from the server
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? haveDelayedNotifications, bool? haveUnreceivedNotifications, dynamic extra, int? clientId}) → UpdateHavePendingNotifications
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String