UpdateLanguagePackStrings class

Inheritance

Constructors

UpdateLanguagePackStrings({required String localizationTarget, required String languagePackId, required List<LanguagePackString> strings, dynamic extra, int? clientId})
Some language pack strings have been updated
const
UpdateLanguagePackStrings.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
languagePackId → String
languagePackId Identifier of the updated language pack
final
localizationTarget → String
localizationTarget Localization target to which the language pack belongs
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
strings → List<LanguagePackString>
strings List of changed language pack strings; empty if all strings have changed
final

Methods

copyWith({String? localizationTarget, String? languagePackId, List<LanguagePackString>? strings, dynamic extra, int? clientId}) → UpdateLanguagePackStrings
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String