UpdateMessageContent class

Inheritance

Constructors

UpdateMessageContent({required int chatId, required int messageId, required MessageContent newContent, dynamic extra, int? clientId})
The message content has changed
const
UpdateMessageContent.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

chatId → int
chatId Chat identifier
final
clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
messageId → int
messageId Message identifier
final
newContent → MessageContent
newContent New message content
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? messageId, MessageContent? newContent, dynamic extra, int? clientId}) → UpdateMessageContent
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String