UpdateMessageEdited class

Inheritance

Constructors

UpdateMessageEdited({required int chatId, required int messageId, required int editDate, ReplyMarkup? replyMarkup, dynamic extra, int? clientId})
A message was edited. Changes in the message content will come in a separate updateMessageContent
const
UpdateMessageEdited.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

chatId → int
chatId Chat identifier
final
clientId → int?
clientId client identifier
final
editDate → int
editDate Point in time (Unix timestamp) when the message was edited
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
messageId → int
messageId Message identifier
final
replyMarkup → ReplyMarkup?
replyMarkup New message reply markup; may be null
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? messageId, int? editDate, ReplyMarkup? replyMarkup, dynamic extra, int? clientId}) → UpdateMessageEdited
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String