UpdateMessageInteractionInfo class

Inheritance

Constructors

UpdateMessageInteractionInfo({required int chatId, required int messageId, MessageInteractionInfo? interactionInfo, dynamic extra, int? clientId})
The information about interactions with a message has changed
const
UpdateMessageInteractionInfo.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

chatId → int
chatId Chat identifier
final
clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
interactionInfo → MessageInteractionInfo?
interactionInfo New information about interactions with the message; may be null
final
messageId → int
messageId Message identifier
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? messageId, MessageInteractionInfo? interactionInfo, dynamic extra, int? clientId}) → UpdateMessageInteractionInfo
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String