UpdateMessageIsPinned class

Inheritance

Constructors

UpdateMessageIsPinned({required int chatId, required int messageId, required bool isPinned, dynamic extra, int? clientId})
The message pinned state was changed
const
UpdateMessageIsPinned.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

chatId → int
chatId Chat identifier
final
clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
isPinned → bool
isPinned True, if the message is pinned
final
messageId → int
messageId The message identifier
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? messageId, bool? isPinned, dynamic extra, int? clientId}) → UpdateMessageIsPinned
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String