UpdateMessageMentionRead class

Inheritance

Constructors

UpdateMessageMentionRead({required int chatId, required int messageId, required int unreadMentionCount, dynamic extra, int? clientId})
A message with an unread mention was read
const
UpdateMessageMentionRead.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

chatId → int
chatId Chat identifier
final
clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
messageId → int
messageId Message identifier
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unreadMentionCount → int
unreadMentionCount The new number of unread mention messages left in the chat
final

Methods

copyWith({int? chatId, int? messageId, int? unreadMentionCount, dynamic extra, int? clientId}) → UpdateMessageMentionRead
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String