UpdateMessageSendFailed class

Inheritance

Constructors

UpdateMessageSendFailed({required Message message, required int oldMessageId, required int errorCode, required String errorMessage, dynamic extra, int? clientId})
A message failed to send. Be aware that some messages being sent can be irrecoverably deleted, in which case updateDeleteMessages will be received instead of this update
const
UpdateMessageSendFailed.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
errorCode → int
errorCode An error code
final
errorMessage → String
errorMessage Error message
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
message → Message
message The failed to send message
final
oldMessageId → int
oldMessageId The previous temporary message identifier
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Message? message, int? oldMessageId, int? errorCode, String? errorMessage, dynamic extra, int? clientId}) → UpdateMessageSendFailed
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String