UpdateMessageSendSucceeded class

Inheritance

Constructors

UpdateMessageSendSucceeded({required Message message, required int oldMessageId, dynamic extra, int? clientId})
A message has been successfully sent
const
UpdateMessageSendSucceeded.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
message → Message
message The sent message. Usually only the message identifier, date, and content are changed, but almost all other fields can also change
final
oldMessageId → int
oldMessageId The previous temporary message identifier
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Message? message, int? oldMessageId, dynamic extra, int? clientId}) → UpdateMessageSendSucceeded
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String