UpdateMessageUnreadReactions class

Inheritance

Constructors

UpdateMessageUnreadReactions({required int chatId, required int messageId, required List<UnreadReaction> unreadReactions, required int unreadReactionCount, dynamic extra, int? clientId})
The list of unread reactions added to a message was changed
const
UpdateMessageUnreadReactions.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

chatId → int
chatId Chat identifier
final
clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
messageId → int
messageId Message identifier
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unreadReactionCount → int
unreadReactionCount The new number of messages with unread reactions left in the chat
final
unreadReactions → List<UnreadReaction>
unreadReactions The new list of unread reactions
final

Methods

copyWith({int? chatId, int? messageId, List<UnreadReaction>? unreadReactions, int? unreadReactionCount, dynamic extra, int? clientId}) → UpdateMessageUnreadReactions
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String