UpdateNewCallSignalingData class

Inheritance

Constructors

UpdateNewCallSignalingData({required int callId, required String data, dynamic extra, int? clientId})
New call signaling data arrived
const
UpdateNewCallSignalingData.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

callId → int
callId The call identifier
final
clientId → int?
clientId client identifier
final
data → String
data The data
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? callId, String? data, dynamic extra, int? clientId}) → UpdateNewCallSignalingData
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String