UpdateNewCallbackQuery class

Inheritance

Constructors

UpdateNewCallbackQuery({required int id, required int senderUserId, required int chatId, required int messageId, required int chatInstance, required CallbackQueryPayload payload, dynamic extra, int? clientId})
A new incoming callback query; for bots only
const
UpdateNewCallbackQuery.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

chatId → int
chatId Identifier of the chat where the query was sent
final
chatInstance → int
chatInstance Identifier that uniquely corresponds to the chat to which the message was sent
final
clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
id → int
id Unique query identifier
final
messageId → int
messageId Identifier of the message from which the query originated
final
payload → CallbackQueryPayload
payload Query payload
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
senderUserId → int
senderUserId Identifier of the user who sent the query
final

Methods

copyWith({int? id, int? senderUserId, int? chatId, int? messageId, int? chatInstance, CallbackQueryPayload? payload, dynamic extra, int? clientId}) → UpdateNewCallbackQuery
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String