UpdateNewChatJoinRequest class

Inheritance

Constructors

UpdateNewChatJoinRequest({required int chatId, required ChatJoinRequest request, required int userChatId, ChatInviteLink? inviteLink, dynamic extra, int? clientId})
A user sent a join request to a chat; for bots only
const
UpdateNewChatJoinRequest.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

chatId → int
chatId Chat identifier
final
clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
inviteLink The invite link, which was used to send join request; may be null
final
request → ChatJoinRequest
request Join request
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userChatId → int
userChatId Chat identifier of the private chat with the user
final

Methods

copyWith({int? chatId, ChatJoinRequest? request, int? userChatId, ChatInviteLink? inviteLink, dynamic extra, int? clientId}) → UpdateNewChatJoinRequest
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String