UpdateNewChosenInlineResult class

Inheritance

Constructors

UpdateNewChosenInlineResult({required int senderUserId, Location? userLocation, required String query, required String resultId, required String inlineMessageId, dynamic extra, int? clientId})
The user has chosen a result of an inline query; for bots only
const
UpdateNewChosenInlineResult.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
inlineMessageId → String
inlineMessageId Identifier of the sent inline message, if known
final
query → String
query Text of the query
final
resultId → String
resultId Identifier of the chosen result
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
senderUserId → int
senderUserId Identifier of the user who sent the query
final
userLocation → Location?
userLocation User location; may be null
final

Methods

copyWith({int? senderUserId, Location? userLocation, String? query, String? resultId, String? inlineMessageId, dynamic extra, int? clientId}) → UpdateNewChosenInlineResult
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String