UpdateNewCustomQuery class

Inheritance

Constructors

UpdateNewCustomQuery({required int id, required String data, required int timeout, dynamic extra, int? clientId})
A new incoming query; for bots only
const
UpdateNewCustomQuery.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
data → String
data JSON-serialized query data
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
id → int
id The query identifier
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeout → int
timeout Query timeout
final

Methods

copyWith({int? id, String? data, int? timeout, dynamic extra, int? clientId}) → UpdateNewCustomQuery
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String