UpdateNewInlineCallbackQuery class

Inheritance

Constructors

UpdateNewInlineCallbackQuery({required int id, required int senderUserId, required String inlineMessageId, required int chatInstance, required CallbackQueryPayload payload, dynamic extra, int? clientId})
A new incoming callback query from a message sent via a bot; for bots only
const
UpdateNewInlineCallbackQuery.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

chatInstance → int
chatInstance An identifier uniquely corresponding to the chat a message was sent to
final
clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
id → int
id Unique query identifier
final
inlineMessageId → String
inlineMessageId Identifier of the inline message from which the query originated
final
payload → CallbackQueryPayload
payload Query payload
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
senderUserId → int
senderUserId Identifier of the user who sent the query
final

Methods

copyWith({int? id, int? senderUserId, String? inlineMessageId, int? chatInstance, CallbackQueryPayload? payload, dynamic extra, int? clientId}) → UpdateNewInlineCallbackQuery
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String