UpdateNewInlineQuery class

Inheritance

Constructors

UpdateNewInlineQuery({required int id, required int senderUserId, Location? userLocation, ChatType? chatType, required String query, required String offset, dynamic extra, int? clientId})
A new incoming inline query; for bots only
const
UpdateNewInlineQuery.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

chatType → ChatType?
chatType The type of the chat from which the query originated; may be null if unknown
final
clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
id → int
id Unique query identifier
final
offset → String
offset Offset of the first entry to return
final
query → String
query Text of the query
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
senderUserId → int
senderUserId Identifier of the user who sent the query
final
userLocation → Location?
userLocation User location; may be null
final

Methods

copyWith({int? id, int? senderUserId, Location? userLocation, ChatType? chatType, String? query, String? offset, dynamic extra, int? clientId}) → UpdateNewInlineQuery
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String