UpdateNewPreCheckoutQuery class

Inheritance

Constructors

UpdateNewPreCheckoutQuery({required int id, required int senderUserId, required String currency, required int totalAmount, required String invoicePayload, required String shippingOptionId, OrderInfo? orderInfo, dynamic extra, int? clientId})
A new incoming pre-checkout query; for bots only. Contains full information about a checkout
const
UpdateNewPreCheckoutQuery.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
currency → String
currency Currency for the product price
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
id → int
id Unique query identifier
final
invoicePayload → String
invoicePayload Invoice payload
final
orderInfo → OrderInfo?
orderInfo Information about the order; may be null
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
senderUserId → int
senderUserId Identifier of the user who sent the query
final
shippingOptionId → String
shippingOptionId Identifier of a shipping option chosen by the user; may be empty if not applicable
final
totalAmount → int
totalAmount Total price for the product, in the smallest units of the currency
final

Methods

copyWith({int? id, int? senderUserId, String? currency, int? totalAmount, String? invoicePayload, String? shippingOptionId, OrderInfo? orderInfo, dynamic extra, int? clientId}) → UpdateNewPreCheckoutQuery
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String