UpdateNewShippingQuery class

Inheritance

Constructors

UpdateNewShippingQuery({required int id, required int senderUserId, required String invoicePayload, required Address shippingAddress, dynamic extra, int? clientId})
A new incoming shipping query; for bots only. Only for invoices with flexible price
const
UpdateNewShippingQuery.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
id → int
id Unique query identifier
final
invoicePayload → String
invoicePayload Invoice payload
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
senderUserId → int
senderUserId Identifier of the user who sent the query
final
shippingAddress → Address
shippingAddress User shipping address
final

Methods

copyWith({int? id, int? senderUserId, String? invoicePayload, Address? shippingAddress, dynamic extra, int? clientId}) → UpdateNewShippingQuery
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String