UpdateNotification class

Inheritance

Constructors

UpdateNotification({required int notificationGroupId, required Notification notification, dynamic extra, int? clientId})
A notification was changed
const
UpdateNotification.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
notification → Notification
notification Changed notification
final
notificationGroupId → int
notificationGroupId Unique notification group identifier
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? notificationGroupId, Notification? notification, dynamic extra, int? clientId}) → UpdateNotification
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String