UpdateNotificationGroup class

Inheritance

Constructors

UpdateNotificationGroup({required int notificationGroupId, required NotificationGroupType type, required int chatId, required int notificationSettingsChatId, required int notificationSoundId, required int totalCount, required List<Notification> addedNotifications, required List<int> removedNotificationIds, dynamic extra, int? clientId})
A list of active notifications in a notification group has changed
const
UpdateNotificationGroup.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

addedNotifications → List<Notification>
addedNotifications List of added group notifications, sorted by notification updateNotificationGroup
final
chatId → int
chatId Identifier of a chat to which all notifications in the group belong
final
clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
notificationGroupId → int
notificationGroupId Unique notification group identifier
final
notificationSettingsChatId → int
notificationSettingsChatId Chat identifier, which notification settings must be applied to the added notifications
final
notificationSoundId → int
notificationSoundId Identifier of the notification sound to be played; 0 if sound is disabled
final
removedNotificationIds → List<int>
removedNotificationIds Identifiers of removed group notifications, sorted by notification updateNotificationGroup
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalCount → int
totalCount Total number of unread notifications in the group, can be bigger than number of active notifications
final
type → NotificationGroupType
type New type of the notification group
final

Methods

copyWith({int? notificationGroupId, NotificationGroupType? type, int? chatId, int? notificationSettingsChatId, int? notificationSoundId, int? totalCount, List<Notification>? addedNotifications, List<int>? removedNotificationIds, dynamic extra, int? clientId}) → UpdateNotificationGroup
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String