UpdateOption class

Inheritance

Constructors

UpdateOption({required String name, required OptionValue value, dynamic extra, int? clientId})
An option changed its value
const
UpdateOption.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
name The option name
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → OptionValue
value The new option value
final

Methods

copyWith({String? name, OptionValue? value, dynamic extra, int? clientId}) → UpdateOption
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String