UpdatePollAnswer class

Inheritance

Constructors

UpdatePollAnswer({required int pollId, required MessageSender voterId, required List<int> optionIds, dynamic extra, int? clientId})
A user changed the answer to a poll; for bots only
const
UpdatePollAnswer.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
optionIds → List<int>
optionIds 0-based identifiers of answer options, chosen by the user
final
pollId → int
pollId Unique poll identifier
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
voterId → MessageSender
voterId Identifier of the message sender that changed the answer to the poll
final

Methods

copyWith({int? pollId, MessageSender? voterId, List<int>? optionIds, dynamic extra, int? clientId}) → UpdatePollAnswer
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String