UpdateRecentStickers class

Inheritance

Constructors

UpdateRecentStickers({required bool isAttached, required List<int> stickerIds, dynamic extra, int? clientId})
The list of recently used stickers was updated
const
UpdateRecentStickers.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
isAttached → bool
isAttached True, if the list of stickers attached to photo or video files was updated; otherwise, the list of sent stickers is updated
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stickerIds → List<int>
stickerIds The new list of file identifiers of recently used stickers
final

Methods

copyWith({bool? isAttached, List<int>? stickerIds, dynamic extra, int? clientId}) → UpdateRecentStickers
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String