UpdateSavedNotificationSounds class

Inheritance

Constructors

UpdateSavedNotificationSounds({required List<int> notificationSoundIds, dynamic extra, int? clientId})
The list of saved notifications sounds was updated. This update may not be sent until information about a notification sound was requested for the first time
const
UpdateSavedNotificationSounds.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
notificationSoundIds → List<int>
notificationSoundIds The new list of identifiers of saved notification sounds
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<int>? notificationSoundIds, dynamic extra, int? clientId}) → UpdateSavedNotificationSounds
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String