UpdateSecretChat class

Inheritance

Constructors

UpdateSecretChat({required SecretChat secretChat, dynamic extra, int? clientId})
Some data of a secret chat has changed. This update is guaranteed to come before the secret chat identifier is returned to the application
const
UpdateSecretChat.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secretChat → SecretChat
secretChat New data about the secret chat
final

Methods

copyWith({SecretChat? secretChat, dynamic extra, int? clientId}) → UpdateSecretChat
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String