UpdateSelectedBackground class

Inheritance

Constructors

UpdateSelectedBackground({required bool forDarkTheme, Background? background, dynamic extra, int? clientId})
The selected background has changed
const
UpdateSelectedBackground.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

background → Background?
background The new selected background; may be null
final
clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
forDarkTheme → bool
forDarkTheme True, if background for dark theme has changed
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? forDarkTheme, Background? background, dynamic extra, int? clientId}) → UpdateSelectedBackground
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String