UpdateStoryListChatCount class

Inheritance

Constructors

UpdateStoryListChatCount({required StoryList storyList, required int chatCount, dynamic extra, int? clientId})
Number of chats in a story list has changed
const
UpdateStoryListChatCount.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

chatCount → int
chatCount Approximate total number of chats with active stories in the list
final
clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storyList → StoryList
storyList The story list
final

Methods

copyWith({StoryList? storyList, int? chatCount, dynamic extra, int? clientId}) → UpdateStoryListChatCount
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String