UpdateSupergroupFullInfo class

Inheritance

Constructors

UpdateSupergroupFullInfo({required int supergroupId, required SupergroupFullInfo supergroupFullInfo, dynamic extra, int? clientId})
Some data in supergroupFullInfo has been changed
const
UpdateSupergroupFullInfo.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supergroupFullInfo → SupergroupFullInfo
supergroupFullInfo New full information about the supergroup
final
supergroupId → int
supergroupId Identifier of the supergroup or channel
final

Methods

copyWith({int? supergroupId, SupergroupFullInfo? supergroupFullInfo, dynamic extra, int? clientId}) → UpdateSupergroupFullInfo
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String