UpdateUnreadChatCount class

Inheritance

Constructors

UpdateUnreadChatCount({required ChatList chatList, required int totalCount, required int unreadCount, required int unreadUnmutedCount, required int markedAsUnreadCount, required int markedAsUnreadUnmutedCount, dynamic extra, int? clientId})
Number of unread chats, i.e. with unread messages or marked as unread, has changed. This update is sent only if the message database is used
const
UpdateUnreadChatCount.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

chatList → ChatList
chatList The chat list with changed number of unread messages
final
clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
markedAsUnreadCount → int
markedAsUnreadCount Total number of chats marked as unread
final
markedAsUnreadUnmutedCount → int
markedAsUnreadUnmutedCount Total number of unmuted chats marked as unread
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalCount → int
totalCount Approximate total number of chats in the chat list
final
unreadCount → int
unreadCount Total number of unread chats
final
unreadUnmutedCount → int
unreadUnmutedCount Total number of unread unmuted chats
final

Methods

copyWith({ChatList? chatList, int? totalCount, int? unreadCount, int? unreadUnmutedCount, int? markedAsUnreadCount, int? markedAsUnreadUnmutedCount, dynamic extra, int? clientId}) → UpdateUnreadChatCount
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String