UpdateUnreadMessageCount class

Inheritance

Constructors

UpdateUnreadMessageCount({required ChatList chatList, required int unreadCount, required int unreadUnmutedCount, dynamic extra, int? clientId})
Number of unread messages in a chat list has changed. This update is sent only if the message database is used
const
UpdateUnreadMessageCount.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

chatList → ChatList
chatList The chat list with changed number of unread messages
final
clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unreadCount → int
unreadCount Total number of unread messages
final
unreadUnmutedCount → int
unreadUnmutedCount Total number of unread messages in unmuted chats
final

Methods

copyWith({ChatList? chatList, int? unreadCount, int? unreadUnmutedCount, dynamic extra, int? clientId}) → UpdateUnreadMessageCount
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String