UpdateUser class

Inheritance

Constructors

UpdateUser({required User user, dynamic extra, int? clientId})
Some data of a user has changed. This update is guaranteed to come before the user identifier is returned to the application
const
UpdateUser.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
user → User
user New data about the user
final

Methods

copyWith({User? user, dynamic extra, int? clientId}) → UpdateUser
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String