UpdateUsersNearby class

Inheritance

Constructors

UpdateUsersNearby({required List<ChatNearby> usersNearby, dynamic extra, int? clientId})
The list of users nearby has changed. The update is guaranteed to be sent only 60 seconds after a successful searchChatsNearby request
const
UpdateUsersNearby.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
usersNearby → List<ChatNearby>
usersNearby The new list of users nearby
final

Methods

copyWith({List<ChatNearby>? usersNearby, dynamic extra, int? clientId}) → UpdateUsersNearby
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String