UpdateWebAppMessageSent class

Inheritance

Constructors

UpdateWebAppMessageSent({required int webAppLaunchId, dynamic extra, int? clientId})
A message was sent by an opened Web App, so the Web App needs to be closed
const
UpdateWebAppMessageSent.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
webAppLaunchId → int
webAppLaunchId Identifier of Web App launch
final

Methods

copyWith({int? webAppLaunchId, dynamic extra, int? clientId}) → UpdateWebAppMessageSent
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String