UserFullInfo class

Inheritance

Constructors

UserFullInfo({ChatPhoto? personalPhoto, ChatPhoto? photo, ChatPhoto? publicPhoto, required bool isBlocked, required bool canBeCalled, required bool supportsVideoCalls, required bool hasPrivateCalls, required bool hasPrivateForwards, required bool hasRestrictedVoiceAndVideoNoteMessages, required bool hasPinnedStories, required bool needPhoneNumberPrivacyException, FormattedText? bio, required List<PremiumPaymentOption> premiumGiftOptions, required int groupInCommonCount, BotInfo? botInfo, dynamic extra, int? clientId})
Contains full information about a user
const
UserFullInfo.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

bio → FormattedText?
bio A short user bio; may be null for bots
final
botInfo → BotInfo?
botInfo For bots, information about the bot; may be null if the user isn't a bot
final
canBeCalled → bool
canBeCalled True, if the user can be called
final
clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
groupInCommonCount → int
groupInCommonCount Number of group chats where both the other user and the current user are a member; 0 for the current user
final
hashCode → int
The hash code for this object.
no setterinherited
hasPinnedStories → bool
hasPinnedStories True, if the user has pinned stories
final
hasPrivateCalls → bool
hasPrivateCalls True, if the user can't be called due to their privacy settings
final
hasPrivateForwards → bool
hasPrivateForwards True, if the user can't be linked in forwarded messages due to their privacy settings
final
hasRestrictedVoiceAndVideoNoteMessages → bool
hasRestrictedVoiceAndVideoNoteMessages True, if voice and video notes can't be sent or forwarded to the user
final
isBlocked → bool
isBlocked True, if the user is blocked by the current user
final
needPhoneNumberPrivacyException → bool
needPhoneNumberPrivacyException True, if the current user needs to explicitly allow to share their phone number with the user when the method addContact is used
final
personalPhoto → ChatPhoto?
personalPhoto User profile photo set by the current user for the contact; may be null. If null and user.profile_photo is null, then the photo is empty; otherwise, it is unknown.. If non-null, then it is the same photo as in user.profile_photo and chat.photo. This photo isn't returned in the list of user photos
final
photo → ChatPhoto?
photo User profile photo; may be null. If null and user.profile_photo is null, then the photo is empty; otherwise, it is unknown.. If non-null and personal_photo is null, then it is the same photo as in user.profile_photo and chat.photo
final
premiumGiftOptions → List<PremiumPaymentOption>
premiumGiftOptions The list of available options for gifting Telegram Premium to the user
final
publicPhoto → ChatPhoto?
publicPhoto User profile photo visible if the main photo is hidden by privacy settings; may be null. If null and user.profile_photo is null, then the photo is empty; otherwise, it is unknown.. If non-null and both photo and personal_photo are null, then it is the same photo as in user.profile_photo and chat.photo. This photo isn't returned in the list of user photos
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supportsVideoCalls → bool
supportsVideoCalls True, if a video call can be created with the user
final

Methods

copyWith({ChatPhoto? personalPhoto, ChatPhoto? photo, ChatPhoto? publicPhoto, bool? isBlocked, bool? canBeCalled, bool? supportsVideoCalls, bool? hasPrivateCalls, bool? hasPrivateForwards, bool? hasRestrictedVoiceAndVideoNoteMessages, bool? hasPinnedStories, bool? needPhoneNumberPrivacyException, FormattedText? bio, List<PremiumPaymentOption>? premiumGiftOptions, int? groupInCommonCount, BotInfo? botInfo, dynamic extra, int? clientId}) → UserFullInfo
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String