UserLink class

Inheritance

Constructors

UserLink({required String url, required int expiresIn, dynamic extra, int? clientId})
Contains an HTTPS URL, which can be used to get information about a user
const
UserLink.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
expiresIn → int
expiresIn Left time for which the link is valid, in seconds; 0 if the link is a public username link
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → String
url The URL
final

Methods

copyWith({String? url, int? expiresIn, dynamic extra, int? clientId}) → UserLink
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String