UserPrivacySettingRuleAllowChatMembers class

Inheritance

Constructors

UserPrivacySettingRuleAllowChatMembers({required List<int> chatIds})
A rule to allow all members of certain specified basic groups and supergroups to doing something
const
UserPrivacySettingRuleAllowChatMembers.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

chatIds → List<int>
chatIds The chat identifiers, total number of chats in all rules must not exceed 20
final
clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<int>? chatIds}) → UserPrivacySettingRuleAllowChatMembers
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String