UserPrivacySettingRules class

Inheritance

Constructors

UserPrivacySettingRules({required List<UserPrivacySettingRule> rules, dynamic extra, int? clientId})
A list of privacy rules. Rules are matched in the specified order. The first matched rule defines the privacy setting for a given user. If no rule matches, the action is not allowed
const
UserPrivacySettingRules.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
rules → List<UserPrivacySettingRule>
rules A list of rules
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<UserPrivacySettingRule>? rules, dynamic extra, int? clientId}) → UserPrivacySettingRules
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String