UserTypeBot class

Inheritance

Constructors

UserTypeBot({required bool canBeEdited, required bool canJoinGroups, required bool canReadAllGroupMessages, required bool isInline, required String inlineQueryPlaceholder, required bool needLocation, required bool canBeAddedToAttachmentMenu})
A bot (see https://core.telegram.org/bots)
const
UserTypeBot.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

canBeAddedToAttachmentMenu → bool
canBeAddedToAttachmentMenu True, if the bot can be added to attachment menu
final
canBeEdited → bool
canBeEdited True, if the bot is owned by the current user and can be edited using the methods toggleBotUsernameIsActive, reorderBotActiveUsernames, setBotProfilePhoto, setBotName, setBotInfoDescription, and setBotInfoShortDescription
final
canJoinGroups → bool
canJoinGroups True, if the bot can be invited to basic group and supergroup chats
final
canReadAllGroupMessages → bool
canReadAllGroupMessages True, if the bot can read all messages in basic group or supergroup chats and not just those addressed to the bot. In private and channel chats a bot can always read all messages
final
clientId → int?
client identifier
no setterinherited
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
inlineQueryPlaceholder → String
inlineQueryPlaceholder Placeholder for inline queries (displayed on the application input field)
final
isInline → bool
isInline True, if the bot supports inline queries
final
needLocation → bool
needLocation True, if the location of the user is expected to be sent with every inline query to this bot
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? canBeEdited, bool? canJoinGroups, bool? canReadAllGroupMessages, bool? isInline, String? inlineQueryPlaceholder, bool? needLocation, bool? canBeAddedToAttachmentMenu}) → UserTypeBot
override
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String