Usernames class

Inheritance

Constructors

Usernames({required List<String> activeUsernames, required List<String> disabledUsernames, required String editableUsername})
Describes usernames assigned to a user, a supergroup, or a channel
const
Usernames.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

activeUsernames → List<String>
activeUsernames List of active usernames; the first one must be shown as the primary username. The order of active usernames can be changed with reorderActiveUsernames, reorderBotActiveUsernames or reorderSupergroupActiveUsernames
final
clientId → int?
client identifier
no setterinherited
disabledUsernames → List<String>
disabledUsernames List of currently disabled usernames; the username can be activated with toggleUsernameIsActive, toggleBotUsernameIsActive, or toggleSupergroupUsernameIsActive
final
editableUsername → String
editableUsername The active username, which can be changed with setUsername or setSupergroupUsername
final
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<String>? activeUsernames, List<String>? disabledUsernames, String? editableUsername}) → Usernames
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String