ValidatedOrderInfo class

Inheritance

Constructors

ValidatedOrderInfo({required String orderInfoId, required List<ShippingOption> shippingOptions, dynamic extra, int? clientId})
Contains a temporary identifier of validated order information, which is stored for one hour, and the available shipping options
const
ValidatedOrderInfo.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
orderInfoId → String
orderInfoId Temporary identifier of the order information
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shippingOptions → List<ShippingOption>
shippingOptions Available shipping options
final

Methods

copyWith({String? orderInfoId, List<ShippingOption>? shippingOptions, dynamic extra, int? clientId}) → ValidatedOrderInfo
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String