Video class

Inheritance

Constructors

Video({required int duration, required int width, required int height, required String fileName, required String mimeType, required bool hasStickers, required bool supportsStreaming, Minithumbnail? minithumbnail, Thumbnail? thumbnail, required File video})
Describes a video file
const
Video.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
duration → int
duration Duration of the video, in seconds; as defined by the sender
final
extra → dynamic
callback sign
no setterinherited
fileName → String
fileName Original name of the file; as defined by the sender
final
hashCode → int
The hash code for this object.
no setterinherited
hasStickers → bool
hasStickers True, if stickers were added to the video. The list of corresponding sticker sets can be received using getAttachedStickerSets
final
height → int
height Video height; as defined by the sender
final
mimeType → String
mimeType MIME type of the file; as defined by the sender
final
minithumbnail → Minithumbnail?
minithumbnail Video minithumbnail; may be null
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supportsStreaming → bool
supportsStreaming True, if the video is supposed to be streamed
final
thumbnail → Thumbnail?
thumbnail Video thumbnail in JPEG or MPEG4 format; as defined by the sender; may be null
final
video → File
video File containing the video
final
width → int
width Video width; as defined by the sender
final

Methods

copyWith({int? duration, int? width, int? height, String? fileName, String? mimeType, bool? hasStickers, bool? supportsStreaming, Minithumbnail? minithumbnail, Thumbnail? thumbnail, File? video}) → Video
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String