VideoChat class

Inheritance

Constructors

VideoChat({required int groupCallId, required bool hasParticipants, MessageSender? defaultParticipantId})
Describes a video chat
const
VideoChat.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
defaultParticipantId → MessageSender?
defaultParticipantId Default group call participant identifier to join the video chat; may be null
final
extra → dynamic
callback sign
no setterinherited
groupCallId → int
groupCallId Group call identifier of an active video chat; 0 if none. Full information about the video chat can be received through the method getGroupCall
final
hashCode → int
The hash code for this object.
no setterinherited
hasParticipants → bool
hasParticipants True, if the video chat has participants
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? groupCallId, bool? hasParticipants, MessageSender? defaultParticipantId}) → VideoChat
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String