ViewPremiumFeature class

Inheritance

Constructors

ViewPremiumFeature({required PremiumFeature feature})
Informs TDLib that the user viewed detailed information about a Premium feature on the Premium features screen
const

Properties

feature → PremiumFeature
feature The viewed premium feature
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({PremiumFeature? feature}) → ViewPremiumFeature
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String