VoiceNote class

Inheritance

Constructors

VoiceNote({required int duration, required String waveform, required String mimeType, SpeechRecognitionResult? speechRecognitionResult, required File voice})
Describes a voice note. The voice note must be encoded with the Opus codec, and stored inside an OGG container. Voice notes can have only a single audio channel
const
VoiceNote.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
client identifier
no setterinherited
duration → int
duration Duration of the voice note, in seconds; as defined by the sender
final
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
mimeType → String
mimeType MIME type of the file; as defined by the sender
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
speechRecognitionResult → SpeechRecognitionResult?
speechRecognitionResult Result of speech recognition in the voice note; may be null
final
voice → File
voice File containing the voice note
final
waveform → String
waveform A waveform representation of the voice note in 5-bit format
final

Methods

copyWith({int? duration, String? waveform, String? mimeType, SpeechRecognitionResult? speechRecognitionResult, File? voice}) → VoiceNote
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String