WebApp class

Inheritance

Constructors

WebApp({required String shortName, required String title, required String description, required Photo photo, Animation? animation})
Describes a Web App. Use getInternalLink with internalLinkTypeWebApp to share the Web App
const
WebApp.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

animation → Animation?
animation Web App animation; may be null
final
clientId → int?
client identifier
no setterinherited
description → String
description Web App description
final
extra → dynamic
callback sign
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
photo → Photo
photo Web App photo
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shortName → String
shortName Web App short name
final
title → String
title Web App title
final

Methods

copyWith({String? shortName, String? title, String? description, Photo? photo, Animation? animation}) → WebApp
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String