WebPageInstantView class

Inheritance

Constructors

WebPageInstantView({required List<PageBlock> pageBlocks, required int viewCount, required int version, required bool isRtl, required bool isFull, required InternalLinkType feedbackLink, dynamic extra, int? clientId})
Describes an instant view page for a web page
const
WebPageInstantView.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId → int?
clientId client identifier
final
extra → dynamic
extra callback sign
final
feedbackLink An internal link to be opened to leave feedback about the instant view
final
hashCode → int
The hash code for this object.
no setterinherited
isFull → bool
isFull True, if the instant view contains the full page. A network request might be needed to get the full web page instant view
final
isRtl → bool
isRtl True, if the instant view must be shown from right to left
final
pageBlocks → List<PageBlock>
pageBlocks Content of the web page
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version → int
version Version of the instant view; currently, can be 1 or 2
final
viewCount → int
viewCount Number of the instant view views; 0 if unknown
final

Methods

copyWith({List<PageBlock>? pageBlocks, int? viewCount, int? version, bool? isRtl, bool? isFull, InternalLinkType? feedbackLink, dynamic extra, int? clientId}) → WebPageInstantView
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String