WriteGeneratedFilePart class

Inheritance

Constructors

WriteGeneratedFilePart({required int generationId, required int offset, required String data})
Writes a part of a generated file. This method is intended to be used only if the application has no direct access to TDLib's file system, because it is usually slower than a direct write to the destination file
const

Properties

data → String
data The data to write
final
generationId → int
generationId The identifier of the generation process
final
hashCode → int
The hash code for this object.
no setterinherited
offset → int
offset The offset from which to write the data to the file
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? generationId, int? offset, String? data}) → WriteGeneratedFilePart
getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONSTRUCTOR → const String